"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Copyright 2022 BytePlus Pte. Ltd.
 * SPDX-License-Identifier: MIT
 */
const events_1 = require("events");
const NativeSDK = require("../../build/Release/byteplus-electron-sdk.node");
const types_1 = require("../types");
const data_1 = __importStar(require("../data"));
const utils_1 = require("../utils");
function checkRoomInstance(target, propertyName, projectDescriptor) {
    const method = projectDescriptor.value;
    projectDescriptor.value = function (...args) {
        let result = 0;
        try {
            if (!this.instance) {
                throw "room instance is null";
            }
            result = method.apply(this, args);
        }
        catch (err) {
            console.error(`Call ${propertyName} with (${args}) results: ${result}, error: `, err);
            result = -1;
        }
        return result;
    };
    return projectDescriptor;
}
/**
 * @list 85530
 * @detail 85532
 */
class veRTCRoom extends events_1.EventEmitter {
    constructor() {
        super();
        this.instance = null;
        this.roomId = "";
        this.localUser = { userId: "" };
        this.remoteUsers = new Map();
    }
    /**
     * @brief Create a room instance.
     * @param room_id A non-empty string within 128 bytes. Each room created by calling this API requires a unique roomId. So that the room can be distinguished from each other.
     * The following character sets are supported:
     * + 26 uppercase letters: A ~ Z,
     * + 26 lowercase letters: a ~ z,
     * + 10 numbers: 0 ~ 9,
     * + Underscore "_", at sign "@", and minus sign "-".
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + This API only returns a room instance. You still need to call [joinRoom](#joinroom) to actually create/join the room.
     * + Each call of this API creates one RTCRoom instance. Call this API as many times as the number of rooms you need, and then call [joinRoom](#joinroom) of each RTCRoom instance to join multiple rooms at the same time.
     * + In multi-room mode, a user can subscribe to media streams in the joined rooms at the same time.
     * + If the room that you wish to join already exists, you still need to call this API first to create the RTCRoom instance, and then call [joinRoom](#joinroom).
     * + In multi-room mode, you need to use different roomId to create multiple rooms.
     * + To forward streams to the other rooms, call [startForwardStreamToRooms](#startforwardstreamtorooms) instead of enabling Multi-room mode.
     */
    createRTCRoom(room_id) {
        if (this.instance) {
            return 0;
        }
        const reg = /^[0-9a-zA-Z@_\-]{1,128}$/;
        if (!reg.test(room_id)) {
            console.error("roomId is not right, please change: roomId不合规");
            return -1;
        }
        this.instance = new NativeSDK.veRTCRoom(room_id, this.cbRoom.bind(this));
        this.roomId = room_id;
        data_1.createdRooms.set(room_id, this);
        return 0;
    }
    //**************************************api
    /**
     * @brief Get room ID
     * @returns Room ID
     */
    getRoomId() {
        const roomId = this.instance.getRoomId();
        return roomId;
    }
    /**
     * @brief Leave and destroy the room.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes Refter to [createRTCRoom](#creatertcroom) for more inforamtion on how to create a room.
     */
    destroy() {
        var _a, _b;
        if (!this.instance) {
            return 0;
        }
        const ret = this.instance.destroy();
        if (ret === 0) {
            this.instance = null;
            (_a = this.localUser.videoRender) === null || _a === void 0 ? void 0 : _a.destroy();
            (_b = this.localUser.screenRender) === null || _b === void 0 ? void 0 : _b.destroy();
            this.localUser.screenRender = null;
            this.localUser.videoRender = null;
            this.remoteUsers.forEach((userInfo, userId) => {
                this.removeRemoteUser(userId);
            });
            data_1.default.delete(this.roomId);
            return 0;
        }
        else {
            console.error("销毁房间失败,请重试");
            return -1;
        }
    }
    /**
     * @brief Create/join a room: create a room when the room does not exist; when the room exists, users who have not joined the room can join the room.   Users in the same room can talk to each other.
     * @param token Dynamic key for authenticating the logged-in user.
     *         You need to bring Token to enter the room. When testing, you can use the console to generate temporary tokens. The official launch requires the use of the key SDK to generate and issue tokens at your server level.
     * + Apps with different App IDs cannot communicate with each other.
     * + Make sure that the App ID used to generate the Token is the same as the App ID used to create the engine, otherwise it will cause the join room to fail.
     * @param user_info User information
     * @param config Room parameter configuration, set the room mode and whether to automatically publish or subscribe to the flow.
     * @returns + 0: Success
     * + -1: Room_id/user_info.uid contains invalid parameters.
     * + -2: Already in the room. After the interface call is successful, as long as the return value of 0 is received and [leaveRoom](#leaveroom) is not called successfully, this return value is triggered when the room entry interface is called again, regardless of whether the filled room ID and user ID are duplicated.
     * @notes
     * + In the same room with the same App ID, the user ID of each user must be unique. If two users have the same user ID, the user who entered the room later will kick the user who entered the room out of the room, and the user who entered the room will receive the [onStreamStateChanged](85533#onstreamstatechanged) callback notification. For the error type. See kErrorCodeDuplicateLogin in [ErrorCode](85534#errorcode).
     * + Local users will receive [onRoomStateChanged](85533#onroomstatechanged) callback notification after calling this method to join the room successfully.
     * + Local users call [setUserVisibility](#setuservisibility) to make themselves visible and then join the room, and remote users will receive [onUserJoined](85533#onuserjoined).
     * + After the user successfully joins the room, the SDK may lose connection to the server in case of poor local network conditions, and the SDK will automatically reconnect at this time. After a successful reconnection, you will receive a local [onRoomStateChanged](85533#onroomstatechanged) callback notification.
     */
    joinRoom(token, user_info, config) {
        if (utils_1.isNull(token) || !user_info || !user_info.uid) {
            return utils_1.errorFeedback("joinRoom");
        }
        const reg = /^[0-9a-zA-Z@_\-]{1,128}$/;
        if (!reg.test(user_info.uid)) {
            console.error("userId is not right, please change: uesrId不合规");
            return -1;
        }
        this.localUser.userId = user_info.uid;
        if (!this.remoteUsers) {
            this.remoteUsers = new Map();
        }
        if (!data_1.default.get(this.roomId)) {
            data_1.default.set(this.roomId, {
                localUser: this.localUser,
                remoteUsers: this.remoteUsers,
            });
        }
        const tempUserInfo = {
            uid: "",
            extra_info: "",
        };
        const tempConfig = {
            room_profile_type: types_1.RoomProfileType.kRoomProfileTypeCommunication,
            is_auto_publish: true,
            is_auto_subscribe_audio: true,
            is_auto_subscribe_video: true,
            remote_video_config: {
                framerate: 0,
                resolution_height: 0,
                resolution_width: 0,
            },
        };
        const utralUserInfo = {
            ...tempUserInfo,
            ...(user_info || {}),
        };
        const utralConfig = {
            ...tempConfig,
            ...(config || {}),
        };
        return this.instance.joinRoom(token, utralUserInfo, utralConfig);
    }
    /**
     * @brief  Leave RTC room.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + The user calls this method to leave the RTC room, end the call process, and release all call-related resources.
     * + It is an asynchronous operation, and the call returns without actually exiting the room. When actually exiting the room, you will receive [onLeaveRoom](85533#onleaveroom).
     * + When visible users leave the room, others in the room will receive [onUserLeave](85533#onuserleave).
     * + If the engine is destroyed immediately after this method is called, you will not receive [onLeaveRoom](85533#onleaveroom).
     */
    leaveRoom() {
        return this.instance.leaveRoom();
    }
    /**
     * @brief Set the visibility of the user in the room. Visible by default.
     * @param enable Visibility of the user in the room:
     * + True: The user can publish media streams. And the other users in the room get informed of the behaviors of the user, such as Joining room, starting video capture, and Leaving room.
     * + False: The user cannot publish media streams. And the other users in the room do not get informed of the behaviors of the user, such as joining, starting video capture, or leaving.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes
     * + You can call this API whether the user is in a room or not.
     * + When you call this API, the other users in the room will be informed via the related callback:
     *            - Switch from `false` to `true`: [onUserJoined](85533#onuserjoined)
     *            - Switch from `true` to `false`: [onUserLeave](85533#onuserleave)
     * + The invisible user will receive the warning code, `kWarningCodePublishStreamForbiden`, when trying to publish media streams.
     */
    setUserVisibility(enable) {
        if (utils_1.isNull(enable)) {
            return utils_1.errorFeedback("setUserVisibility");
        }
        return this.instance.setUserVisibility(enable);
    }
    /**
     * @brief Synchronizes published audio and video.
     * @param audio_user_id The ID of audio publisher. You can stop the current A/V synchronization by setting this parameter to null.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + When the same user simultaneously uses separate devices to capture and publish audio and video, there is a possibility that the streams are out of sync due to the network disparity. In this case, you can call this API on the video publisher side and the SDK will automatically line the video stream up according to the timestamp of the audio stream, ensuring that the audio the receiver hears corresponds to the video the receiver watches.
     * + You can call this API anytime before or after entering the room.
     * + The source user IDs of the audio and video stream to be synchronized must be in the same RTC room.
     * + When the A/V synchronization state changes, you will receive [onAVSyncStateChange](#onavsyncstatechange).
     * + More than one pair of audio and video can be synchronized simultaneously in the same RTC room, but you should note that one single audio source cannot be synchronized with multiple video sources at the same time.
     * + If you want to change the audio source, call this API again with a new `audio_user_id`. If you want to change the video source, you need to stop the current synchronization first, then call this API on the new video publisher side.
     */
    setMultiDeviceAVSync(audio_user_id) {
        if (utils_1.isNull(audio_user_id)) {
            return utils_1.errorFeedback("setMultiDeviceAVSync");
        }
        return this.instance.setMultiDeviceAVSync(audio_user_id);
    }
    /**
     * @brief Update Token.
     * @param token Valid token.
     *        If the Token is invalid, SDK will emit `ERROR_CODE_UPDATE_TOKEN_WITH_INVALID_TOKEN` defined in an [ErrorCode](85534#errorcode).
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + A Token used to join rooms has an expiration time. You will be informed 30 sec before the expiration of the token by [onTokenWillExpire](#ontokenwillexpire). Call this API to renew the Token. Or the user will be removed from the room as the Token expires.
     *        + If you called [joinRoom](#joinroom) to join a room or reconnected into a room with an invalid Token, it would fail. You would get informed by [onStreamStateChanged](85533#onstreamstatechanged). The error code is the `ERROR_CODE_INVALID_TOKEN` in [ErrorCode](85534#errorcode). Reacquire a token and call this API to renew the token.
     * + When the Token expired, the user would be removed from the room. And you would get informed of  `ERROR_CODE_EXPIRED_TOKEN` by [onStreamStateChanged](85533#onstreamstatechanged). Reacquire a token and call [joinRoom](#joinroom) with the token to rejoin the room.
     */
    updateToken(token) {
        if (utils_1.isNull(token)) {
            return utils_1.errorFeedback("updateToken");
        }
        return this.instance.updateToken(token);
    }
    /**
     * @brief Sets your expected configuration of the remote video stream that you want to subscribe to or have subscribed to.
     * @param user_id ID of the target stream publisher
     * @param remote_video_config Your expected configuration
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + This API only works after the publisher calls [enableSimulcastMode](#enablesimulcastmode) to enable publishing multiple video streams, in which case the subscriber will receive the stream from the publisher that is closest to the set configuration;  otherwise the subscriber will only receive one video stream with a resolution of 640px × 360px and a frame rate of 15fps.
     * + If you don't call this API after the publisher enables the function of publishing multiple streams, you will receive by default the video stream with the largest resolution set by the publisher.
     * + You should call this API in the room. If you want to call it before entering the room, you should set the `remote_video_config` in the `room_config` when calling [joinRoom](#joinroom).
     * + SDK will automatically select the stream to be published or subscribed based on the settings of both sides.
     */
    setRemoteVideoConfig(user_id, remote_video_config) {
        if (!user_id) {
            return utils_1.errorFeedback("setRemoteVideoConfig");
        }
        const tempConfig = {
            framerate: 0,
            resolution_height: 0,
            resolution_width: 0,
        };
        return this.instance.setRemoteVideoConfig(user_id, {
            ...tempConfig,
            ...(remote_video_config || {}),
        });
    }
    /**
     * @brief Publishes media streams captured by camera/microphone in the current room.
     * @param type Media stream type, used for specifying whether to publish audio stream or video stream.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes
     * + You don't need to call this API if you set it to Auto-publish when calling [joinRoom](#joinroom).
     * + An invisible user cannot publish media streams. Call [setUserVisibility](#rtcroom#setuservisibility) to change your visibility in the room.
     * + Call [publishScreen](#publishscreen) to start screen sharing.
     * + Call [startForwardStreamToRooms](#startforwardstreamtorooms) to forward the published streams to the other rooms.
     * + After you call this API, the other users in the room will receive [onUserPublishStream](85533#onuserpublishstream). Those who successfully received your streams will receive [onFirstRemoteAudioFrame](85533#onFirstRemoteAudioFrame)/[onFirstRemoteVideoFrameDecoded](#onfirstremotevideoframedecoded) at the same time.
     * + Call [unpublishStream](#unpublishstream) to stop publishing streams.
     */
    publishStream(type) {
        if (utils_1.isNull(type)) {
            return utils_1.errorFeedback("publishStream");
        }
        return this.instance.publishStream(type);
    }
    /**
     * @brief Stops publishing media streams captured by camera/microphone in the current room.
     * @param type Media stream type, used for specifying whether to stop publishing audio stream or video stream.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + After calling [publishStream](#publishstream), call this API to stop publishing streams.
     * + After calling this API, the other users in the room will receive [onUserUnpublishStream](85533#onuserunpublishstream).
     */
    unpublishStream(type) {
        if (utils_1.isNull(type)) {
            return utils_1.errorFeedback("unpublishStream");
        }
        return this.instance.unpublishStream(type);
    }
    /**
     * @brief Publishes local screen sharing streams in the current room.
     * @param type Media stream type, used for specifying whether to publish audio stream or video stream.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + You need to call this API even if you set it to Auto-publish when calling [joinRoom](#joinroom).
     * + An invisible user cannot publish media streams. Call [setUserVisibility](#rtcroom#setuservisibility) to change your visibility in the room.
     * + After you called this API, the other users in the room will receive [onUserPublishScreen](85533#onuserpublishscreen). Those who successfully received your streams will receive [onFirstRemoteAudioFrame](85533#onFirstRemoteAudioFrame)/[onFirstRemoteVideoFrameDecoded](#onfirstremotevideoframedecoded) at the same time.
     * + Call [startForwardStreamToRooms](#startforwardstreamtorooms) to forward the published streams to the other rooms.
     * + Call [unpublishScreen](#unpublishscreen) to stop publishing screen sharing streams.
     * + You can only publish video stream on Linux.
     */
    publishScreen(type) {
        if (utils_1.isNull(type)) {
            return utils_1.errorFeedback("publishScreen");
        }
        return this.instance.publishScreen(type);
    }
    /**
     * @brief Stops publishing local screen sharing streams in the current room.
     * @param type Media stream type, used for specifying whether to stop publishing audio stream or video stream.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + After calling [publishScreen](#publishscreen), call this API to stop publishing streams.
     * + After calling this API, the other users in the room will receive [onUserUnpublishScreen](85533#onUserUnpublishScreen).
     */
    unpublishScreen(type) {
        if (utils_1.isNull(type)) {
            return utils_1.errorFeedback("unpublishScreen");
        }
        return this.instance.unpublishScreen(type);
    }
    /**
     * @brief Subscribes to specific remote media streams captured by camera/microphone.  Or update the options of the subscribed user.
     * @param user_id User ID of the publisher of the subscribed media stream
     * @param type Media stream type to be subscribed to.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + Calling this API to update the subscribe configuration when the user has subscribed the remote user either by calling this API or by auto-subscribe.  <br>
     *        + You must first get the remote stream information through [onUserPublishStream](85533#onuserpublishstream) before calling this API to subscribe to streams accordingly.  <br>
     *        + After calling this API, you will be informed of the calling result with [onStreamSubscribed](85533#onstreamsubscribed).  <br>
     *        + Once the local user subscribes to the stream of a remote user, the subscription to the remote user will sustain until the local user leaves the room or unsubscribe from it by calling [unsubscribeStream](#unsubscribestream).<br>
     *        + Any other exceptions will be included in [onStreamStateChanged](85533#onstreamstatechanged), see [ErrorCode](85534#errorcode) for the reasons.
     */
    subscribeStream(user_id, type) {
        if (!user_id || utils_1.isNull(type)) {
            return utils_1.errorFeedback("subscribeStream");
        }
        return this.instance.subscribeStream(user_id, type);
    }
    /**
     * @brief Unsubscribes from specific remote media streams captured by camera/microphone. You can call this API in both automatic subscription mode and manual subscription mode.
     * @param user_id The ID of the remote user who published the target audio/video stream.
     * @param type Media stream type, used for specifying whether to unsubscribe from the audio stream or the video stream.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + After calling this API, you will be informed of the calling result with [onStreamSubscribed](#onstreamsubscribed).
     * + Any other exceptions will be included in [onStreamStateChanged](85533#onstreamstatechanged), see [ErrorCode](85534#errorcode) for the reasons.
     */
    unsubscribeStream(user_id, type) {
        if (!user_id || utils_1.isNull(type)) {
            return utils_1.errorFeedback("unsubscribeStream");
        }
        return this.instance.unsubscribeStream(user_id, type);
    }
    /**
     * @brief Subscribes to specific screen sharing media stream.   Or update the subscribe options of the subscribed user.
     * @param user_id The ID of the remote user who published the target screen audio/video stream.
     * @param type Media stream type, used for specifying whether to subscribe to the audio stream or the video stream.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + Calling this API to update the subscribe configuration when the user has subscribed the remote user either by calling this API or by auto-subscribe.
     * + You must first get the remote stream information through [onUserPublishScreen](85533#onuserpublishscreen)} before calling this API to subscribe to streams accordingly.
     * + After calling this API, you will be informed of the calling result with [onStreamSubscribed](#onstreamsubscribed).
     * + Once the local user subscribes to the stream of a remote user, the subscription to the remote user will sustain until the local user leaves the room or unsubscribe from it by calling [unsubscribeScreen](#unsubscribescreen).
     * + Any other exceptions will be included in [onStreamStateChanged](85533#onstreamstatechanged), see [ErrorCode](85534#errorcode) for the reasons.
     */
    subscribeScreen(user_id, type) {
        if (!user_id || utils_1.isNull(type)) {
            return utils_1.errorFeedback("subscribeScreen");
        }
        return this.instance.subscribeScreen(user_id, type);
    }
    /**
     * @brief Unsubscribes from specific screen sharing media stream.
     *        You can call this API in both automatic subscription mode and manual subscription mode.
     * @param user_id The ID of the remote user who published the target screen audio/video stream.
     * @param type Media stream type, used for specifying whether to unsubscribe from the audio stream or the video stream.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + After calling this API, you will be informed of the calling result with [onStreamSubscribed](#onstreamsubscribed).
     * + Any other exceptions will be included in [onStreamStateChanged](85533#onstreamstatechanged), see [ErrorCode](85534#errorcode) for the reasons.
     */
    unsubscribeScreen(user_id, type) {
        if (!user_id || utils_1.isNull(type)) {
            return utils_1.errorFeedback("unsubscribeScreen");
        }
        return this.instance.unsubscribeScreen(user_id, type);
    }
    /**
     * @brief Pause receiving remote media streams.
     * @param media_type Media stream type subscribed to.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + Calling this API does not change the capture state and the transmission state of the remote clients.
     * + Calling this API does not cancel the subscription or change any subscription configuration.
     * + To resume, call [resumeAllSubscribedStream](#resumeallsubscribedstream).
     * + In a multi-room scenario, this API only pauses the reception of streams published in the current room.
     */
    pauseAllSubscribedStream(media_type) {
        if (utils_1.isNull(media_type)) {
            return utils_1.errorFeedback("pauseAllSubscribedStream");
        }
        return this.instance.pauseAllSubscribedStream(media_type);
    }
    /**
     * @brief Media stream type subscribed to.
     * @param media_type Media stream type subscribed to.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + Calling this API does not change the capture state and the transmission state of the remote clients.
     * + Calling this API does not change any subscription configuration.
     */
    resumeAllSubscribedStream(media_type) {
        if (utils_1.isNull(media_type)) {
            return utils_1.errorFeedback("resumeAllSubscribedStream");
        }
        return this.instance.resumeAllSubscribedStream(media_type);
    }
    /**
     * @brief Send a text message (P2P) to the specified user in the room
     * @param uid User ID of the message receiver
     * @param message Text message content sent. Message does not exceed 64 KB.
     * @param config Message type
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + Before sending an in-room text message, you must call [joinRoom](#joinroom) to join the room.
     * + After calling this function, you will receive an [onUserMessageSendResult](85533#onUserMessageSendResult) callback to notify the message sender that the sending was successful or failed;
     * + If the text message is sent successfully, the user specified by uid will receive [onUserMessageReceived](85533#onusermessagereceived) callback.
     */
    sendUserMessage(uid, message, config) {
        if (!uid || utils_1.isNull(message) || utils_1.isNull(config)) {
            return utils_1.errorFeedback("sendUserMessage");
        }
        return this.instance.sendUserMessage(uid, message, config);
    }
    /**
     * @brief Sends a binary message (P2P) to the specified user in the room
     * @param uid User ID of the message receiver
     * @param length The length of the binary string.
     * @param message The content of the binary message. The message does not exceed 46KB.
     *         The number of the message sent this time is incremented from
     * @param config Message type
     * @returns + > 0: Success. Serial number of the message, starting form 1.
     * + < 0: Failure.
     * @notes   + Before sending in-room binary messages, you must call [joinRoom](#joinroom) to join the room.
     * + After calling this function, you will receive an [onUserMessageSendResult](85533#onUserMessageSendResult) callback to notify the sender of the success or failure of the message;
     * + If the binary message is sent successfully, the user specified by uid will receive the [onUserBinaryMessageReceived](#onuserbinarymessagereceived) callback.
     */
    sendUserBinaryMessage(uid, length, message, config) {
        if (!uid || utils_1.isNull(length) || utils_1.isNull(message) || utils_1.isNull(config)) {
            return utils_1.errorFeedback("sendUserBinaryMessage");
        }
        return this.instance.sendUserBinaryMessage(uid, length, message, config);
    }
    /**
     * @brief Send broadcast messages to all other users in the room.
     * @param message The broadcast message sent by the user
     *        Message does not exceed 64 KB.
     * @returns + 0: Success. Serial number of the message, starting form 1.
     * + < 0: Failure.
     * @notes
     * + Before sending in-room binary messages, you must call [joinRoom](#joinroom) to join the room.
     * + After calling this function, you get an [onRoomMessageSendResult](85533#onroommessagesendresult) callback.
     * + Other users in the same room receive an [onRoomMessageReceived](85533#onroommessagereceived) callback.
     */
    sendRoomMessage(message) {
        if (utils_1.isNull(message)) {
            return utils_1.errorFeedback("sendRoomMessage");
        }
        return this.instance.sendRoomMessage(message);
    }
    /**
     * @brief Send broadcast messages to all other users in the room.
     * @param size The length of the binary message to be sent
     * @param message The binary broadcast message sent by the user
     *        The message does not exceed 46KB.
     * @returns + 0: Success. Serial number of the message, starting form 1.
     * + < 0: Failure.
     * @notes + Before sending in-room binary messages, you must call [joinRoom](#joinroom) to join the room.
     * + After calling this function, you get an [onRoomMessageSendResult](85533#onroommessagesendresult) callback.
     * + Other users in the same room receive an [onRoomBinaryMessageReceived](85533#onroombinarymessagereceived) callback.
     */
    sendRoomBinaryMessage(size, message) {
        if (utils_1.isNull(size) || utils_1.isNull(message)) {
            return utils_1.errorFeedback("sendRoomBinaryMessage");
        }
        return this.instance.sendRoomBinaryMessage(size, message);
    }
    /**
     * @brief Start relaying media stream across rooms.
     * @param configuration Information of the rooms where you want to relay the media stream to.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + After a user joins a room, you can call this method to publish the media stream to multiple rooms that applies to scenarios such as anOnline talent contest and so on.
     * + Call this method will trigger [onForwardStreamStateChanged](85533#onForwardStreamStateChanged).
     * + After calling this method, listen the events from each room during the relaying by registering [onForwardStreamEvent](#onforwardstreamevent).
     * + Once the relaying begins, the other users in the room will receive callback of [onUserJoined](85533#onuserjoined) and [onUserPublishStream](85533#onuserpublishstream)/[onUserPublishScreen](85533#onuserpublishscreen).
     * + Call [updateForwardStreamToRooms](#updateforwardstreamtorooms) to add or remove the target room(s) after calling this method.
     * + Call [stopForwardStreamToRooms](#stopforwardstreamtorooms) to stop relaying to all rooms after calling this method.
     * + Call [pauseForwardStreamToAllRooms](#pauseforwardstreamtoallrooms) to pause relaying to all rooms after calling this method.
     */
    startForwardStreamToRooms(configuration) {
        if (utils_1.isNull(configuration) ||
            utils_1.isNull(configuration.forward_stream_dests) ||
            !configuration.forward_stream_dests.length) {
            return utils_1.errorFeedback("startForwardStreamToRooms");
        }
        const tempConfigurarion = {
            forward_stream_dests: [
                {
                    token: "",
                    room_id: "",
                },
            ],
            dest_count: 0,
        };
        const finalConfig = {
            ...tempConfigurarion,
            ...(configuration || {}),
        };
        return this.instance.startForwardStreamToRooms(finalConfig);
    }
    /**
     * @brief Update information of the rooms where you want to relay the media stream to.
     * @param configuration Information of the rooms where you want to relay the media stream to.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + Update information of the rooms where you want to relay the media stream to after calling [startForwardStreamToRooms](#startforwardstreamtorooms).
     * + Adding and removing rooms by calling this method will trigger [onForwardStreamStateChanged](85533#onForwardStreamStateChanged) on the local.
     * + Users in the room which is added by calling this method will receive [onUserJoined](85533#onuserjoined) and [onUserPublishStream](85533#onuserpublishstream)/[onUserPublishScreen](85533#onuserpublishscreen).
     * + Users in the room which is removed by calling this method will receive [onUserUnpublishStream](85533#onuserunpublishstream)/[onUserUnpublishScreen](85533#onUserUnpublishScreen) and [onUserLeave](85533#onuserleave).
     */
    updateForwardStreamToRooms(configuration) {
        if (utils_1.isNull(configuration) ||
            utils_1.isNull(configuration.forward_stream_dests) ||
            !configuration.forward_stream_dests.length) {
            return utils_1.errorFeedback("updateForwardStreamToRooms");
        }
        const tempConfigurarion = {
            forward_stream_dests: [
                {
                    token: "",
                    room_id: "",
                },
            ],
            dest_count: 0,
        };
        return this.instance.updateForwardStreamToRooms({
            ...tempConfigurarion,
            ...(configuration || {}),
        });
    }
    /**
     * @brief Stop relaying media streams to all rooms.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + Call to this method to stop relaying media stream to all rooms after calling [startForwardStreamToRooms](#startforwardstreamtorooms).
     * + Call this method will trigger [onForwardStreamStateChanged](85533#onForwardStreamStateChanged).
     * + The other users in the room will receive callback of [onUserJoined](85533#onuserjoined) and [onUserPublishStream](85533#onuserpublishstream)/[onUserPublishScreen](85533#onuserpublishscreen) when you stop relaying.
     * + To stop relaying media stream to specific rooms, call [updateForwardStreamToRooms](#updateforwardstreamtorooms) instead.
     * + To resume the relaying in a short time, call [pauseForwardStreamToAllRooms](#pauseforwardstreamtoallrooms) instead and then call resumeForwardStreamToAllRooms(#resumeforwardstreamtoallrooms) to recsume after that.
     */
    stopForwardStreamToRooms() {
        return this.instance.stopForwardStreamToRooms();
    }
    /**
     * @brief Pause relaying media streams to all rooms.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + Call this method to pause relaying media stream to all rooms after calling [startForwardStreamToRooms](#startforwardstreamtorooms).
     * + After that, call resumeForwardStreamToAllRooms(#resumeforwardstreamtoallrooms) to resume.
     * + The other users in the room will receive callback of [onUserUnpublishStream](85533#onuserunpublishstream)/[onUserUnpublishScreen](85533#onUserUnpublishScreen) and [onUserLeave](85533#onuserleave) when you pause relaying.
     */
    pauseForwardStreamToAllRooms() {
        return this.instance.pauseForwardStreamToAllRooms();
    }
    /**
     * @brief Resume relaying media streams to all rooms.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + Call this method to resume relaying to all rooms from the pause by calling [pauseForwardStreamToAllRooms](#pauseforwardstreamtoallrooms).
     * + The other users in the room will receive callback of [onUserJoined](85533#onuserjoined) and [onUserPublishStream](85533#onuserpublishstream)/[onUserPublishScreen](85533#onuserpublishscreen) when you resume relaying.
     */
    resumeForwardStreamToAllRooms() {
        return this.instance.resumeForwardStreamToAllRooms();
    }
    /**
     * @brief Enable/disable the range audio function.
     * @param enable Whether to enable audio range funcion：
     * + true: Enable
     * + false: Disable（Defaulting setting）
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + Range audio means that within a certain range in a same RTC room, the audio volume of the remote user received by the local user will be amplified/attenuated as the remote user moves closer/away. The audio coming from out of the range cannot be heard. See [updateReceiveRange](#updatereceiverange) to set audio receiving range.
     * + You can call this API anytime before or after entering a room. To ensure a smooth switch to the range audio mode after entering the room, you need to call [updateRangePosition](#updaterangeposition) before this API to set your own position coordinates, and then enable the range audio function.
     */
    enableRangeAudio(enable) {
        if (utils_1.isNull(enable)) {
            return utils_1.errorFeedback("enableRangeAudio");
        }
        return this.instance.enableRangeAudio(enable);
    }
    /**
     * @brief Updates the audio receiving range for the local user.
     * @param range Audio receiving range
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes If you have previously called [registerRangeAudioObserver](#registerrangeaudioobserver) to set an observer monitoring attenuation coefficient, you will receive [onRangeAudioInfo](85533#onrangeaudioinfo) when any user in the room calls this API to update the audio receiving range.
     */
    updateReceiveRange(range) {
        if (utils_1.isNull(range) || utils_1.isNull(range.min) || utils_1.isNull(range.max)) {
            return utils_1.errorFeedback("updateReceiveRange");
        }
        return this.instance.updateReceiveRange(range);
    }
    /**
     * @brief Updates the coordinate of the local user's position in the rectangular coordinate system in the current room.
     * @param pos 三维坐标的值，默认为 [0, 0, 0]
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes
     * + After calling this API, you should call [enableRangeAudio](#enablerangeaudio) to enable range audio function to actually enjoy the range audio effect.
     * + If you have previously called [registerRangeAudioObserver](#registerrangeaudioobserver) to set an observer monitoring attenuation coefficient, you will receive [onRangeAudioInfo](85533#onrangeaudioinfo) when any user in the room calls this API to update their coordinates.
     */
    updateRangePosition(pos) {
        if (utils_1.isNull(pos) || utils_1.isNull(pos.x) || utils_1.isNull(pos.y) || utils_1.isNull(pos.z)) {
            return utils_1.errorFeedback("updateRangePosition");
        }
        return this.instance.updateRangePosition(pos);
    }
    /**
     * @brief Sets the attenuation coefficient observer
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes You should only call this API in manual subscription mode.
     */
    registerRangeAudioObserver() {
        return this.instance.registerRangeAudioObserver();
    }
    /**
     * @brief Set the volume roll-off mode that a 3D sound has in an audio source when using the Range Audio feature.
     * @param type Volume roll-off mode. It is linear roll-off mode by default.
     * @param coefficient Coefficient for the exponential roll-off mode. The default value is 1. It ranges [0.1,100]. We recommended to set it to `50`. The volume roll-off speed gets faster as this value increases.
     * @returns + 0: Success
     * + < 0: Failure because of calling this API before the user has joined a room or before enabling the Range Audio feature by calling [enableRangeAudio](#enablerangeaudio).
     * @notes + You can get informed of the volume roll-off scale of each remote client via [onRangeAudioInfo](85533#onrangeaudioinfo).
     * + Call [updateReceiveRange](#updatereceiverange) to set the range outside which the volume of the sound does not attenuate.
     */
    setAttenuationModel(type, coefficient) {
        if (utils_1.isNull(type) || utils_1.isNull(coefficient)) {
            return utils_1.errorFeedback("setAttenuationModel");
        }
        return this.instance.setAttenuationModel(type, coefficient);
    }
    /**
     * @brief Enable/disable spatial audio function.
     * @param enable Whether to enable spatial audio function:
     * + true：Enable
     * + false：Disable(Default setting)
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes You need to call [updateSpatialPosition](#updatespatialposition) as well to really enjoy the spatial audio effect.
     */
    enableSpatialAudio(enable) {
        if (utils_1.isNull(enable)) {
            return utils_1.errorFeedback("enableSpatialAudio");
        }
        return this.instance.enableSpatialAudio(enable);
    }
    /**
     * @brief Updates the coordinate of the local user's position in the rectangular coordinate system in the current room.
     * @param pos 3D coordinate values, the default value is [0, 0, 0]
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes Before calling this API, you should call [enableSpatialAudio](#enablespatialaudio) first to enable spatial audio function.
     */
    updateSpatialPosition(pos) {
        if (utils_1.isNull(pos) || utils_1.isNull(pos.x) || utils_1.isNull(pos.y) || utils_1.isNull(pos.z)) {
            return utils_1.errorFeedback("updateSpatialPosition");
        }
        return this.instance.updateSpatialPosition(pos);
    }
    /**
     * @brief After the local user joins the room, call this API to update the orientation of the local user in the 3D coordinates for the spatial audio.
     * @param orientation Your head orientation.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes +  Before calling this API, you should call [enableSpatialAudio](#enablespatialaudio) first to enable spatial audio function, and then call [updateSpatialPosition](#updatespatialposition) to update the position of the local user.
     * +  Call [disableRemoteOrientation](#disableremoteorientation) to neglect the orientation of the remote users.
     */
    updateSelfOrientation(orientation) {
        /**
         * @brief Three-dimensional orientation information, each pair of vectors need to be perpendicular.
         */
        const tempOrientation = {
            /**
             * @brief Forward orientation, the default value is {1,0,0}, i.e., the forward orientation is in the positive direction of x-axis.
             */
            forward: { x: 1, y: 0, z: 0 },
            /**
             * @brief Rightward orientation, the default value is {0,1,0}, i.e., the rightward orientation is in the positive direction of y-axis.
             */
            right: { x: 0, y: 1, z: 0 },
            /**
             * @brief Upward orientation, the default value is {0,0,1}, i.e., the upward orientation is in the positive direction of z-axis.
             */
            up: { x: 0, y: 0, z: 1 },
        };
        return this.instance.updateSelfOrientation({
            ...tempOrientation,
            ...(orientation || {}),
        });
    }
    /**
     * @brief Calling this API in each client to neglect the orientation of the remote speakers. From the local user's perspective, all the remote users will be facing him/her.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + Once the orientation is disabled by calling this API, calling [updateSelfOrientation](#updateselforientation) will notify none of the remote users. However, as a listener, the local user can experience the sound effect varies with the change of one's orientation.
     * + You can call this API before or after the local user joins the room.
     * + Once the orientation is disabled by calling this API, you cannot enable it again within the lifetime of the `SpatialAudio` instance.
     */
    disableRemoteOrientation() {
        return this.instance.disableRemoteOrientation();
    }
    /**
     * @private
     */
    fire(event, ...args) {
        setImmediate(() => {
            this.emit(event, ...args);
        });
    }
    removeRemoteUser(userId) {
        let user = this.remoteUsers.get(userId);
        if (user) {
            user.videoRender && user.videoRender.destroy();
            user.screenRender && user.screenRender.destroy();
            user.screenRender = null;
            user.videoRender = null;
            this.remoteUsers.delete(userId);
        }
    }
    //************************************** api end
    //--------------------------------------- callback start
    /**
     * @hidden
     */
    //离开房间的回调中删除视图
    onLeaveRoom() {
        var _a, _b;
        (_a = this.localUser.videoRender) === null || _a === void 0 ? void 0 : _a.destroy();
        (_b = this.localUser.screenRender) === null || _b === void 0 ? void 0 : _b.destroy();
        this.localUser.screenRender = null;
        this.localUser.videoRender = null;
        this.remoteUsers.forEach((userInfo, userId) => {
            this.removeRemoteUser(userId);
        });
        data_1.default.delete(this.roomId);
    }
    /**
     * @hidden
     */
    onUserJoined(userId) {
        this.removeRemoteUser(userId);
        const newUser = { userId };
        this.remoteUsers.set(userId, newUser);
    }
    /**
     * @hidden
     */
    //远端用户离开房间时删除其视图
    onUserLeave(userId) {
        this.removeRemoteUser(userId);
    }
    /**
     * @hidden
     */
    cbRoom(event) {
        this.processCallback(event);
    }
    /**
     * @hidden
     */
    processCallback(event) {
        const { Type: type, Object: data } = event;
        switch (type) {
            case "onRoomStateChanged":
                {
                    const { room_id, uid, state, extra_info } = data;
                    this.fire(type, room_id, uid, state, extra_info);
                }
                break;
            case "onStreamStateChanged":
                {
                    const { room_id, uid, state, extra_info } = data;
                    this.fire(type, room_id, uid, state, extra_info);
                }
                break;
            case "onLeaveRoom":
                {
                    this.onLeaveRoom();
                    this.fire(type, data);
                }
                break;
            case "onUserJoined":
                {
                    const { user_info, elapsed } = data;
                    this.onUserJoined(user_info.uid);
                    this.fire(type, user_info, elapsed);
                }
                break;
            case "onUserLeave":
                {
                    const { uid, reason } = data;
                    this.onUserLeave(uid);
                    this.fire(type, uid, reason);
                }
                break;
            case "onTokenWillExpire":
                {
                    this.fire(type);
                }
                break;
            case "onAVSyncStateChange":
                {
                    const { state } = data;
                    this.fire(type, state);
                }
                break;
            case "onRoomStats":
                {
                    this.fire(type, data);
                }
                break;
            case "onLocalStreamStats":
                {
                    this.fire(type, data);
                }
                break;
            case "onRemoteStreamStats":
                {
                    this.fire(type, data);
                }
                break;
            case "onUserPublishStream":
                {
                    const { uid, type: mediaStreamType } = data;
                    this.fire(type, uid, mediaStreamType);
                }
                break;
            case "onUserUnpublishStream":
                {
                    const { uid, type: mediaStreamType, reason } = data;
                    this.fire(type, uid, mediaStreamType, reason);
                }
                break;
            case "onUserPublishScreen":
                {
                    const { uid, type: mediaStreamType } = data;
                    this.fire(type, uid, mediaStreamType);
                }
                break;
            case "onUserUnpublishScreen":
                {
                    const { uid, type: mediaStreamType, reason } = data;
                    this.fire(type, uid, mediaStreamType, reason);
                }
                break;
            case "onStreamSubscribed":
                {
                    const { state_code, user_id, info } = data;
                    this.fire(type, state_code, user_id, info);
                }
                break;
            case "onVideoStreamBanned":
                {
                    const { uid, banned } = data;
                    this.fire(type, uid, banned);
                }
                break;
            case "onAudioStreamBanned":
                {
                    const { uid, banned } = data;
                    this.fire(type, uid, banned);
                }
                break;
            case "onRoomMessageReceived":
                {
                    const { uid, message } = data;
                    this.fire(type, uid, message);
                }
                break;
            case "onRoomBinaryMessageReceived":
                {
                    const { uid, message } = data;
                    this.fire(type, uid, message);
                }
                break;
            case "onUserMessageReceived":
                {
                    const { uid, message } = data;
                    this.fire(type, uid, message);
                }
                break;
            case "onUserBinaryMessageReceived":
                {
                    const { uid, message } = data;
                    this.fire(type, uid, message);
                }
                break;
            case "onUserMessageSendResult":
                {
                    const { msgid, error } = data;
                    this.fire(type, msgid, error);
                }
                break;
            case "onRoomMessageSendResult":
                {
                    const { msgid, error } = data;
                    this.fire(type, msgid, error);
                }
                break;
            case "onForwardStreamStateChanged":
                {
                    const { infos, info_count } = data;
                    this.fire(type, infos, info_count);
                }
                break;
            case "onForwardStreamEvent": {
                const { infos, info_count } = data;
                this.fire(type, infos, info_count);
            }
            case "onRangeAudioInfo": {
                const { range_audio_info, len } = data;
                this.fire(type, range_audio_info, len);
            }
            case "onNetworkQuality":
                {
                    const { localQuality, remoteQualities } = data;
                    this.fire(type, localQuality, remoteQualities);
                }
                break;
            default:
                {
                }
                break;
        }
    }
}
__decorate([
    checkRoomInstance
], veRTCRoom.prototype, "getRoomId", null);
__decorate([
    checkRoomInstance
], veRTCRoom.prototype, "joinRoom", null);
__decorate([
    checkRoomInstance
], veRTCRoom.prototype, "leaveRoom", null);
__decorate([
    checkRoomInstance
], veRTCRoom.prototype, "setUserVisibility", null);
__decorate([
    checkRoomInstance
], veRTCRoom.prototype, "setMultiDeviceAVSync", null);
__decorate([
    checkRoomInstance
], veRTCRoom.prototype, "updateToken", null);
__decorate([
    checkRoomInstance
], veRTCRoom.prototype, "setRemoteVideoConfig", null);
__decorate([
    checkRoomInstance
], veRTCRoom.prototype, "publishStream", null);
__decorate([
    checkRoomInstance
], veRTCRoom.prototype, "unpublishStream", null);
__decorate([
    checkRoomInstance
], veRTCRoom.prototype, "publishScreen", null);
__decorate([
    checkRoomInstance
], veRTCRoom.prototype, "unpublishScreen", null);
__decorate([
    checkRoomInstance
], veRTCRoom.prototype, "subscribeStream", null);
__decorate([
    checkRoomInstance
], veRTCRoom.prototype, "unsubscribeStream", null);
__decorate([
    checkRoomInstance
], veRTCRoom.prototype, "subscribeScreen", null);
__decorate([
    checkRoomInstance
], veRTCRoom.prototype, "unsubscribeScreen", null);
__decorate([
    checkRoomInstance
], veRTCRoom.prototype, "pauseAllSubscribedStream", null);
__decorate([
    checkRoomInstance
], veRTCRoom.prototype, "resumeAllSubscribedStream", null);
__decorate([
    checkRoomInstance
], veRTCRoom.prototype, "sendUserMessage", null);
__decorate([
    checkRoomInstance
], veRTCRoom.prototype, "sendUserBinaryMessage", null);
__decorate([
    checkRoomInstance
], veRTCRoom.prototype, "sendRoomMessage", null);
__decorate([
    checkRoomInstance
], veRTCRoom.prototype, "sendRoomBinaryMessage", null);
__decorate([
    checkRoomInstance
], veRTCRoom.prototype, "startForwardStreamToRooms", null);
__decorate([
    checkRoomInstance
], veRTCRoom.prototype, "updateForwardStreamToRooms", null);
__decorate([
    checkRoomInstance
], veRTCRoom.prototype, "stopForwardStreamToRooms", null);
__decorate([
    checkRoomInstance
], veRTCRoom.prototype, "pauseForwardStreamToAllRooms", null);
__decorate([
    checkRoomInstance
], veRTCRoom.prototype, "resumeForwardStreamToAllRooms", null);
__decorate([
    checkRoomInstance
], veRTCRoom.prototype, "enableRangeAudio", null);
__decorate([
    checkRoomInstance
], veRTCRoom.prototype, "updateReceiveRange", null);
__decorate([
    checkRoomInstance
], veRTCRoom.prototype, "updateRangePosition", null);
__decorate([
    checkRoomInstance
], veRTCRoom.prototype, "registerRangeAudioObserver", null);
__decorate([
    checkRoomInstance
], veRTCRoom.prototype, "setAttenuationModel", null);
__decorate([
    checkRoomInstance
], veRTCRoom.prototype, "enableSpatialAudio", null);
__decorate([
    checkRoomInstance
], veRTCRoom.prototype, "updateSpatialPosition", null);
__decorate([
    checkRoomInstance
], veRTCRoom.prototype, "updateSelfOrientation", null);
__decorate([
    checkRoomInstance
], veRTCRoom.prototype, "disableRemoteOrientation", null);
exports.default = veRTCRoom;
//# sourceMappingURL=room.js.map