"use strict";
/*
* Copyright 2022 BytePlus Pte. Ltd.
* SPDX-License-Identifier: MIT
*/
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const events_1 = require("events");
const NativeSDK = require("../../build/Release/byteplus-electron-sdk.node");
const { logger } = require("../utils/logger");
const yuv_render_1 = require("../utils/yuv_render");
const data_1 = __importStar(require("../data"));
const utils_1 = require("../utils");
const types_1 = require("../types");
const room_1 = __importDefault(require("./room"));
var fs = require("fs");
var path = require("path");
const mkdirsSync = (dirname) => {
    if (fs.existsSync(dirname)) {
        return true;
    }
    else {
        if (mkdirsSync(path.dirname(dirname))) {
            fs.mkdirSync(dirname);
            return true;
        }
    }
};
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// veRTCVideo
function checkInit(target, propertyName, projectDescriptor) {
    const method = projectDescriptor.value;
    projectDescriptor.value = function (...args) {
        let result = 0;
        try {
            if (!this.instance) {
                throw "instance is null";
            }
            result = method.apply(this, args);
        }
        catch (err) {
            console.error(`Call ${propertyName} with (${args}) results: ${result}, error: `, err);
            result = -1;
        }
        return result;
    };
    return projectDescriptor;
}
/////////////////////////////////////////////////////////////////////////////////
/**
 * @list 85530
 * @detail 85532
 */
class veRTCVideo extends events_1.EventEmitter {
    constructor() {
        super();
        this.instance = null;
        this.publicStreamViews = new Map();
        this.previewUser = {
            userId: "preview",
        };
    }
    /**
     * @brief Create an engine instance.
     * @param app_id A unique identifier for each App, randomly generated by the RTC console. Only instances created with the same app_id are able to communicate with each other.
     * @param document_path Path to save logs
     * @param parameters JSON string containing parameters
     * @return + `0`: Success
     * + `-1`: Failure
     * @notes + This is the very first API that you must call if you want to use all the RTC capabilities.
     * + If there is no engine instance in current thread, calling this API will create one. If an engine instance has been created, calling this API again will have the created engine instance returned.
     */
    createRTCVideo(app_id, document_path, parameters) {
        let ret = -1;
        do {
            if (this.instance) {
                console.warn("Call Init, but the instance is init yet");
                break;
            }
            this.instance = new NativeSDK.veRTCVideo();
            if (utils_1.isNull(app_id)) {
                return utils_1.errorFeedback("createRTCVideo");
            }
            const tempParams = JSON.parse(parameters);
            //新增上报参数
            const newParams = {
                ...tempParams,
                "rtc.platform": 7,
            };
            this.instance.createRTCVideo(app_id, document_path, this.cbEngine.bind(this), JSON.stringify(newParams));
            ret = 0;
        } while (false);
        return ret;
    }
    /**
     * @brief Create a room for the call
     * @param room_id roomId is an non-empty string within 128 bytes. Each room created by calling this API requires a unique roomid. So that the room can be distinguished from each other.
     *        The following character sets are supported:
     * + 26 uppercase letters A~ Z
     * + 26 lowercase letters a~ z
     * + 10 numbers: 0~ 9
     * + Underscore "_", at sign "@" , and minus sign "-"
     * @return + `0`: Success
     * + `-1`: Failure
     * @notes + Each call of this API creates one `veRTCRoom` instance. Call this API as many times as the number of rooms you need.  And then call [joinRoom](#joinroom) of each `IRTCRoom` instance to join multiple rooms at the same time.  These enable Multi-room mode. In Multi-room mode, a user can subscribe to media streams in the joined rooms at the same time.
     * + To forward streams to the other rooms, call [startForwardStreamToRooms](#startforwardstreamtorooms) instead of enabling Multi-room mode.
     */
    createRTCRoom(room_id) {
        let instance = data_1.createdRooms.get(room_id);
        if (!instance) {
            instance = new room_1.default();
        }
        instance.createRTCRoom(room_id);
        return instance;
    }
    /**
     * @brief Destroy the engine instance created by `createRTCVideo`, and release all related resources.
     * @notes + Call this API after all business scenarios related to the engine instance are destroyed. In a multi-thread scenario, you must not call `veRTCVideo` related APIs after calling this interface, or the SDK may crash. When the API is called, RTC SDK destroys all memory associated with the engine instance and stops any interaction with the media server.
     * + Calling this API will start the SDK exit logic. The engine thread is held until the exit logic is complete. The engine thread is retained until the exit logic is complete. Therefore, do not call this API directly in the callback thread, or wait for the execution of the main thread in the callback and call this API in the main thread at the same time. Otherwise, it will cause a deadlock.
     */
    destroyRTCVideo() {
        data_1.createdRooms.forEach((roomInstance, roomId) => {
            if (roomInstance) {
                roomInstance.destroy();
            }
            data_1.createdRooms.delete(roomId);
        });
        this.instance.destroyRTCVideo();
        this.instance = null;
        return 0;
    }
    /**
     * @brief  Get the current SDK version information.
     * @return Current SDK version information.
     */
    static getSDKVersion() {
        return NativeSDK.getSDKVersion();
    }
    /**
     * @brief Report the user feedback to RTC.
     * @param types List of preset problems.
     * @param problem_desc Specific description of other problems other than the preset problem.
     * @return +  0: Success
     * + `-1`: Failed to report, not yet joined the room
     * + `-2`: Failed to report, data analysis error
     * + `-3`: Failed to report, missing fields
     * @notes + If the user is in the room when reporting, the report leads to the room / rooms where the user is currently located;
     * + If the user is not in the room when reporting, the report leads to the previously exited Room.
     */
    feedback(types, problem_desc) {
        if (utils_1.isNull(problem_desc) || !problem_desc) {
            problem_desc = "";
        }
        return this.instance.feedback(types, problem_desc);
    }
    /**
     * @brief  Get the description of the error code
     * @param code Needs to get the description of the error code
     * @returns The description of the error code
     * @notes This interface is a general function and does not need to rely on the engine object when calling.
     */
    getErrorDescription(code) {
        return this.instance.getErrorDescription(code);
    }
    /**
     * @brief  Sets the business ID
     * @param business_id Your customized businessId
     *         BusinessId is a tag, and you can customize its granularity.
     * @returns + 0: Success
     * + < 0: Failure.
     * + -6001: The user is already in the room.
     * + -6002: The input is invalid. Legal characters include all lowercase letters, uppercase letters, numbers, and four other symbols, including '.', '-','_', and '@'.
     * @notes + You can use businessId to distinguish different business scenarios. You can customize your businessId to serve as a sub AppId, which can share and refine the function of the AppId, but it does not need authentication.
     * + You must call this API before the [joinRoom](#joinroom) API, otherwise it will be invalid.
     */
    setBusinessId(business_id) {
        if (utils_1.isNull(business_id)) {
            return utils_1.errorFeedback("setBusinessId");
        }
        const reg = /^[0-9a-zA-Z@_\-]{1,128}$/;
        if (!reg.test(business_id)) {
            console.error("business_id is not right, please change: business_id不合规");
            return -1;
        }
        return this.instance.setBusinessId(business_id);
    }
    /**
     * @private
     * @brief Set runtime parameters.
     * @param json_string JSON string
     * @returns + 0: Success
     * + < 0: Failure.
     */
    setRuntimeParameters(json_string) {
        if (!json_string) {
            return utils_1.errorFeedback("setRuntimeParameters");
        }
        return this.instance.setRuntimeParameters(json_string);
    }
    /**
     * @brief Get process ID of the engine for commissioning
     * @returns Process ID
     */
    static getCurrentProcessId() {
        return NativeSDK.getCurrentProcessId();
    }
    /**
     * @brief Set the way to use built-in encryption when transmitting
     * @param encrypt_type Built-in encryption algorithm.
     * @param key Encryption key, the length is limited to 36 bits, and the excess will be Truncate
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + Use this method when using the built-in encryption on transfer; if you need to use custom encryption on transfer.  Built-in encryption and custom encryption are mutually exclusive, and the transmission is determined to be encrypted according to the last method called.
     * + This method must be called before entering the room, and can be called repeatedly, taking the last called parameter as the effective parameter.
     */
    setEncryptInfo(encrypt_type, key) {
        if (utils_1.isNull(encrypt_type) || utils_1.isNull(key)) {
            return utils_1.errorFeedback("setEncryptInfo");
        }
        return this.instance.setEncryptInfo(encrypt_type, key);
    }
    /**
     * @brief Start internal audio capture. The default is off.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + The local client will be informed via onAudioDeviceStateChanged after starting audio capture by calling this API.
     * + To enable a microphone without the user's permission will trigger onWarning.
     * + Call stopAudioCapture to stop the internal audio capture. Otherwise, the internal audio capture will sustain until you destroy the engine instance.
     * +  To mute and unmute microphones, we recommend using publishStream and unpublishStream, other than stopAudioCapture and this API. Because starting and stopping capture devices often need some time waiting for the response of the device, that may lead to a short silence during the communication.
     * + Once you create the engine instance, you can start internal audio capture regardless of the audio publishing state. The audio stream will start publishing only after the audio capture starts.
     */
    startAudioCapture() {
        return this.instance.startAudioCapture();
    }
    /**
     * @brief Stop internal audio capture. The default is off.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + The local client will be informed via  onAudioDeviceStateChanged after stopping audio capture by calling this API.
     * + The remote clients in the room will be informed of the state change via onUserStopAudioCapture after the visible client stops audio capture by calling this API.
     * + Call startAudioCapture to enable the internal audio capture.
     * + Without calling this API the internal audio capture will sustain until you destroy the engine instance.
     */
    stopAudioCapture() {
        return this.instance.stopAudioCapture();
    }
    /**
     * @brief  Get a list of the audio playback device. When the audio playback device changes, you will receive the `onAudioDeviceStateChanged`, and you need to call this API again to get the new device list.
     * @returns A list of all audio playback devices
     */
    enumerateAudioPlaybackDevices() {
        return this.instance.enumerateAudioPlaybackDevices();
    }
    /**
     * @brief  Get a list of audio acquisition devices in the current system. If there are subsequent device changes, you need to call this interface again to get a new device list.
     * @return An object that contains a list of all audio capture devices in the system.
     */
    enumerateAudioCaptureDevices() {
        return this.instance.enumerateAudioCaptureDevices();
    }
    /**
     * @brief Sets the audio playback device.
     * @param device_id  Audio playback device's ID. You can get the ID by calling enumerateAudioPlaybackDevices
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes After you call followSystemPlaybackDevice to set the audio playback device to follow the system setting, you cannot call this API to set the audio playback device.
     */
    setAudioPlaybackDevice(device_id) {
        if (utils_1.isNull(device_id)) {
            return utils_1.errorFeedback("setAudioPlaybackDevice");
        }
        let ret = this.instance.setAudioPlaybackDevice(device_id);
        return ret;
    }
    /**
     * @brief Set up audio capture devices
     * @param device_id Audio capture device ID, available through enumerateAudioCaptureDevices
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes After you call followSystemCaptureDevice to set the audio playback device to follow the system setting, you cannot call this API to set the audio capture device.
     */
    setAudioCaptureDevice(device_id) {
        if (utils_1.isNull(device_id)) {
            return utils_1.errorFeedback("setAudioCaptureDevice");
        }
        let ret = this.instance.setAudioCaptureDevice(device_id);
        return ret;
    }
    /**
     * @brief Gets the current audio playback device ID.
     * @returns Audio playback device ID
     */
    getAudioPlaybackDevice() {
        return this.instance.getAudioPlaybackDevice();
    }
    /**
     * @brief Gets the current audio capture device ID.
     * @return Audio capture device ID
     */
    getAudioCaptureDevice() {
        return this.instance.getAudioCaptureDevice();
    }
    /**
     * @brief Set the current audio playback device volume
     * @param volume Audio playback device volume, the value range is [0,255], the setting beyond this range is invalid.
     * + [0,25] Is nearly silent;
     * + [25,75] Is low volume;
     * + [76,204] Is medium volume;
     * + [205,255] Is high volume.
     * @returns + 0: Success
     * + < 0: Failure.
     */
    setAudioPlaybackDeviceVolume(volume) {
        if (utils_1.isNull(volume)) {
            return utils_1.errorFeedback("setAudioPlaybackDeviceVolume");
        }
        return this.instance.setAudioPlaybackDeviceVolume(volume);
    }
    /**
     * @brief Get the current audio playback device volume.
     * @returns Audio playback device volume, the range should be within [0,255].
     * + [0,25] Is nearly silent;
     * + [25,75] Is low volume;
     * + [76,204] Is medium volume;
     * + [205,255] Is high volume.
     */
    getAudioPlaybackDeviceVolume() {
        return this.instance.getAudioPlaybackDeviceVolume();
    }
    /**
     * @brief Set the current audio capture volume
     * @param volume Audio capture volume, the value range is [0,255], the setting beyond this range is invalid.
     * + [0,25] Is nearly silent;
     * + [25,75] Is low volume;
     * + [76,204] Is medium volume;
     * + [205,255] Is high volume.
     * @returns + 0: Success
     * + < 0: Failure.
     */
    setAudioCaptureDeviceVolume(volume) {
        if (utils_1.isNull(volume)) {
            return utils_1.errorFeedback("setAudioCaptureDeviceVolume");
        }
        return this.instance.setAudioCaptureDeviceVolume(volume);
    }
    /**
     * @brief Get the current audio capture volume
     * @returns Audio capture volume, the range is within [0,255].
     * + [0,25] Is nearly silent;
     * + [25,75] Is low volume;
     * + [76,204] Is medium volume;
     * + [205,255] Is high volume.
     */
    getAudioCaptureDeviceVolume() {
        return this.instance.getAudioCaptureDeviceVolume();
    }
    /**
     * @brief Mute or Unmute the current audio playback device. The default state is speaking.
     * @param mute + True: mute
     * + False: non-mute
     * @returns + 0: Success
     * + < 0: Failure.
     */
    setAudioPlaybackDeviceMute(mute) {
        if (utils_1.isNull(mute)) {
            return utils_1.errorFeedback("setAudioPlaybackDeviceMute");
        }
        return this.instance.setAudioPlaybackDeviceMute(mute);
    }
    /**
     * @brief Get state of the audio playback device.
     * @returns + True: Mute
     * + False: Speaking
     */
    getAudioPlaybackDeviceMute() {
        return this.instance.getAudioPlaybackDeviceMute();
    }
    /**
     * @brief Mute or Unmute the current audio capture device. The default state is speaking.
     * @param mute + True: Mute
     * + False: Speaking
     * @returns + 0: Success
     * + < 0: Failure.
     */
    setAudioCaptureDeviceMute(mute) {
        if (utils_1.isNull(mute)) {
            return utils_1.errorFeedback("setAudioCaptureDeviceMute");
        }
        return this.instance.setAudioCaptureDeviceMute(mute);
    }
    /**
     * @brief Get state of the audio capture device.
     * @returns + True: Mute
     * + False: Speaking
     */
    getAudioCaptureDeviceMute() {
        return this.instance.getAudioCaptureDeviceMute();
    }
    /**
     * @brief Adjust the audio capture volume.
     * @param index Index of the stream, whose volume needs to be adjusted.
     * @param volume Ratio of capture volume to original volume. Ranging: [0,400]. Unit: %
     * + 0: Mute
     * + 100: Original volume. To ensure the audio quality, we recommend [0, 100].
     * + 400: Four times the original volume with signal-clipping protection.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes Call this API to set the volume of the audio capture before or during the audio capture.
     */
    setCaptureVolume(index, volume) {
        if (utils_1.isNull(index)) {
            return utils_1.errorFeedback("setCaptureVolume");
        }
        return this.instance.setCaptureVolume(index, volume);
    }
    /**
     * @brief Adjust the playback volume of the mixed remote audios.  You can call this API before or during the playback.
     * @param volume Ratio(%) of playback volume to original volume, in the range [0, 400], with overflow protection.
     *        To ensure the audio quality, we recommend setting the volume within `100`.
     * + 0: mute
     * + 100: original volume
     * + 400: Four times the original volume with signal-clipping protection.
     * @returns + 0: Success
     * + < 0: Failure.
     */
    setPlaybackVolume(volume) {
        return this.instance.setPlaybackVolume(volume);
    }
    /**
     * @brief Adjust the audio playback volume of the remote user
     * @param room_id ID of the room from which the remote audio source is published
     * @param user_id  Remote user ID of the audio source
     * @param volume Ratio(%) of playback volume to original volume, in the range [0, 400], with overflow protection.
     *               To ensure the audio quality, we recommend setting the volume within `100`.
     *               + 0: mute
     *               + 100: original volume. Default value.
     *               + 400: Up to 4 times the original volume (with overflow protection)
     * @returns + 0: Success
     * + < 0: Failure.
     */
    setRemoteAudioPlaybackVolume(room_id, user_id, volume) {
        return this.instance.setRemoteAudioPlaybackVolume(room_id, user_id, volume);
    }
    /**
     * @brief Play/Stop the local audio stream.
     * @param mute_state Playinging status to identify whether to play the local audio stream
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes This method controls the local audio stream but does not affect the local audio playback device.
     */
    muteAudioPlayback(mute_state) {
        return this.instance.muteAudioPlayback(mute_state);
    }
    /**
     * @brief Stop the playback test for the local audio device.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes Call this API to stop the playback test started by calling [startAudioPlaybackDeviceTest](#startaudioplaybackdevicetest) before moving on to the other device tests.
     */
    stopAudioPlaybackDeviceTest() {
        return this.instance.stopAudioPlaybackDeviceTest();
    }
    /**
     * @brief Set the sound effect type
     * @param change_type Sound effect type
     * + `0`:	Unchanged
     * + `1`:	Giant
     * + `2`:	Chipmunk
     * + `3`:	Minions
     * + `4`:	Vibrato
     * + `5`:	Robot
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + You can call it before and after entering the room.
     * + Effective for both internal and external audio source.
     * + Only valid for mono-channel audio.
     * + Only valid in SDKs that include the ability of sound effects.
     * + Mutually exclusive with setVoiceReverbType, and the effects set later will override the effects set first.
     */
    // @checkInit
    // public setVoiceChangerType(change_type: number): number {
    //   return this.instance.setVoiceChangerType(change_type);
    // }
    /**
     * @brief Set the reverb effect type
     * @param voice_reverb_type Reverb effect type
     * + `0`:	Unchanged
     * + `1`:	Echo
     * + `2`:	Music concert
     * + `3`:	Ethereal
     * + `4`:	Karaoke
     * + `5`:	Recording studio
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + You can call it before and after entering the room.
     * + Effective for both internal and external audio source.
     * + Only valid for mono-channel audio.
     * + Only valid in SDKs that include the ability of sound effects.
     * + Mutually exclusive with setVoiceChangerType, and the effects set later will override the effects set first.
     */
    // @checkInit
    // public setVoiceReverbType(voice_reverb_type: number): number {
    //   return this.instance.setVoiceReverbType(voice_reverb_type);
    // }
    /**
     * @brief Sets the sound quality
     * @param audio_profile Sound quality
     * + `0`:	Default sound quality. The sound quality configuration of RoomProfileType set by the server or client.
     * + `1`: Fluent. Sample rate: 16 KHz. Mono-channel. Encoding bitrate: 32 Kpbs. Low resource consumption, and small network packets guarantees a smooth call. It is suitable for most game scenarios, such as team-wide voice chat, group-wide voice chat, nation-wide voice chat.
     * + `2`: Mono-channel standard. Sample rate: 24 KHz. Encoding bitrate: 48 Kpbs. For scenarios requiring distinct voice, you can choose this mode, which achieves balanced latency, consumption, and network packets. It is suitable for educational Apps and the online Mafia Games.
     * + `3`:	Dual-channel music. Sample rate: 48 KHz. Encoding bitrate: 128 Kpbs. This mode provides high-resolution audio at a cost of high latency, consumption, and large network packets. It is suitable for music Apps such as co-hosting and online talent contests. Not recommended for game Apps.
     * + `4`:	Dual-channel standard. Sample rate: 48 KHz. Encoding bitrate: 80 Kpbs
     * + `5`:	Mono-channel music. Sample rate: 48 KHz. Encoding bitrate: 64 Kpbs
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + Call this API to change the sound quality if the audio settings in the current RoomProfileType can not meet your requirements.
     * + You can call this API before and after entering the room.
     * + Support dynamic switching of sound quality during a call.
     */
    setAudioProfile(audio_profile) {
        return this.instance.setAudioProfile(audio_profile);
    }
    /**
     * @brief Start the playback test for the local audio device. RTC will start playing the audio file specified. And RTC will notify the audio volume via the `onAudioPlaybackDeviceTestVolume` periodically.
     * @param test_audio_file_path Specify the path of the audio file for the playback test, including *.mp3, *.aac, *.m4a, *.3gp, and *.wav.
     * @param interval The time interval between each callback in milliseconds. We recommend setting it to 200 ms. The minimal value is 10 ms.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + You can call this API whether the user is in the room.
     * + Call [stopAudioPlaybackDeviceTest](#stopaudioplaybackdevicetest) to stop the playback test before moving on to the other device tests.
     */
    startAudioPlaybackDeviceTest(test_audio_file_path, interval) {
        if (utils_1.isNull(test_audio_file_path) || utils_1.isNull(interval)) {
            return utils_1.errorFeedback("startAudioPlaybackDeviceTest");
        }
        return this.instance.startAudioPlaybackDeviceTest(test_audio_file_path, interval);
    }
    /**
     * @brief Starts a call test.
     * @param config Test configurations
     * @param play_delay_time Delayed audio/video playback time specifying how long you expect to receive the playback after starting the. The range of the value is [2,10] in seconds and the default value is 2.
     * @returns + 0: Success
     * + -1: Failure, testing in progress
     * + -2: Failure, you are in the room
     * + -3: Failure, neither video nor audio is captured
     * + -4: Failure, Parameter exception
     * + -5: Failure, the roomID is already used
     * @notes + Before entering the room, you can call this API to test whether your local audio/video equipment as well as the upstream and downstream networks are working correctly.
     * + Once the test starts, SDK will record your sound or video. If you receive the playback within the delay range you set, the test is considered normal.+ Once you start the test, you can either call [stopEchoTest](#stopechotest) or wait until the test stops automatically after 60s, to start the next test or enter the room.
     * + All APIs related to device control and stream control called before this API are invalidated during the test and are restored after the test.
     * + All APIs related to device control, stream control, and room entry called during the test do not take effect, and you will receive [onWarning](85533#onwarning) with the warning code `kWarningCodeInEchoTestMode`.
     * + You will receive the test result from [onEchoTestResult](85533#onechotestresult).
     */
    startEchoTest(config, play_delay_time) {
        if (utils_1.isNull(config)) {
            return utils_1.errorFeedback("startEchoTest");
        }
        if (utils_1.isNull(play_delay_time)) {
            return utils_1.errorFeedback("startEchoTest");
        }
        return this.instance.startEchoTest(config, play_delay_time);
    }
    /**
     * @brief Stop the current call test.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + After calling [startEchoTest](#startechotest), you must call this API to stop the test.
     * + After stopping the test with this API, all the system devices and streams are restored to the state they were in before the test.
     */
    stopEchoTest() {
        return this.instance.stopEchoTest();
    }
    /**
     * @brief Try to initialize the audio playback device for device test.
     * @param device_id Device ID
     * @returns + 0: Status normal.
     * + -1: Test not executed.
     * + -2: Init failed due to lack of permission.
     * + -3: The device does not exist. No device or device removed.
     * + -4: The audio format is not supported.
     * + -5: Error for other reasons
     * @notes + Call this API before the user joins the room.
     * + You may still fail to enable the device even you passed the test. Occupation by other application or shortage of CPU / memory may cause the failure.
     */
    initAudioPlaybackDeviceForTest(device_id) {
        if (utils_1.isNull(device_id)) {
            return utils_1.errorFeedback("");
        }
        return this.instance.initAudioPlaybackDeviceForTest(device_id);
    }
    /**
     * @brief Try to initialize the audio capture device for device test.
     * @param device_id Device ID
     * @returns + 0: Status normal.
     * + -1: Test not executed.
     * + -2: Init failed due to lack of permission.
     * + -3: The device does not exist. No device or device removed.
     * + -4: The audio format is not supported.
     * + -5: Error for other reasons
     * @notes + Call this API before the user joins the room.
     * + You may still fail to enable the device even you passed the test. Occupation by other application or shortage of CPU / memory may cause the failure.
     */
    initAudioCaptureDeviceForTest(device_id) {
        if (utils_1.isNull(device_id)) {
            return utils_1.errorFeedback("");
        }
        return this.instance.initAudioCaptureDeviceForTest(device_id);
    }
    /**
     * @brief Enable audio information prompts.
     * @param interval Prompt interval in ms
     * + `<= 0`: Turn off prompt
     * + `(0,100]`: Invalid interval value, and will be automatically reset to 100ms.
     * + `> 100`: the actual value of interval
     * @param enable_spectrum Whether to enable audio spectrum detection
     * @param enable_vad Whether to enable Voice Activity Detection
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + After enable the prompt, you can:
     * + Get the information of the audio stream collected by the local microphone and screen audio stream through onLocalAudioPropertiesReport;
     * + Get the information of the subscribed remote audio streams through onRemoteAudioPropertiesReport.
     * + Get the information of the active speaker through onActiveSpeaker.
     */
    enableAudioPropertiesReport(interval, enable_spectrum, enable_vad) {
        if (utils_1.isNull(interval) || utils_1.isNull(enable_spectrum) || utils_1.isNull(enable_vad)) {
            return utils_1.errorFeedback("enableAudioPropertiesReport");
        }
        return this.instance.enableAudioPropertiesReport(interval, enable_spectrum, enable_vad);
    }
    /**
     * @brief Enables/disables the loudness equalization function.
     * @param enable_vad Whether to enable loudness equalization function:
     * + True: Yes
     * + False: No
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + If you call this API with the parameter set to True, the loudness of user's voice will be adjusted to -16lufs. If then you also call setAudioMixingLoudness and import the original loudness of the audio data used in audio mixing, the loudness will be adjusted to -20lufs when the audio data starts to play.
     * + You must call this API before starting to play the audio file with startAudioMixing.
     */
    enableVocalInstrumentBalance(enable_vad) {
        if (utils_1.isNull(enable_vad)) {
            return utils_1.errorFeedback("enableVocalInstrumentBalance");
        }
        return this.instance.enableVocalInstrumentBalance(enable_vad);
    }
    /**
     * @hidden
     * @brief Set an alternative image when the local internal video capture is not enabled.
     *        You can repeatedly call this API to update the image.
     *        You can set the path to null or open the camera to stop publishing the image.
     * @param filePath Set the path of the static image.
     *        You can use the absolute path (file://xxx). The maximum size for the path is 512 bytes.
     *        You can upload a .JPG, .JPEG, .PNG, or .BMP file.
     *        When the aspect ratio of the image is inconsistent with the video encoder configuration, the image will be proportionally resized, with the remaining pixels rendered black. The framerate and the bitrate are consistent with the video encoder configuration.
     * @return + 0: Success.
     *        + -1: Failure.
     * @notes + The API is only effective when publishing an internally captured video.
     *        + You cannot locally preview the image.
     *        + You can call this API before and after joining an RTC room. In the multi-room mode, the image can be only displayed in the room you publish the stream.
     *        + You cannot apply effects like filters and mirroring to the image, while you can watermark the image.
     *        + The image is not effective for a screen-sharing stream.
     *        + When you enable the simulcast mode, the image will be added to all video streams, and it will be proportionally scaled down to smaller encoding configurations.
     */
    // @checkInit
    // public setDummyCaptureImagePath(filePath: string) {
    //   if (isNull(filePath)) {
    //     return errorFeedback("setDummyCaptureImagePath");
    //   }
    //   return this.instance.setDummyCaptureImagePath(filePath);
    // }
    /**
     * @brief Enable internal video capture immediately. The default is off.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + Internal video capture refers to: use the RTC SDK built-in video capture module to capture.
     * + The local client will be informed via onVideoDeviceStateChanged after starting video capture by calling this API.
     * + The remote clients in the room will be informed of the state change via onUserStartVideoCapture after the visible client starts video capture by calling this API.
     * + Call stopVideoCapture to stop the internal video capture. Otherwise, the internal video capture will sustain until you destroy the engine instance.
     * + Once you create the engine instance, you can start internal video capture regardless of the video publishing state. The video stream will start publishing only after the video capture starts.
     * + To switch from custom to internal video capture, stop publishing before disabling the custom video capture module and then call this API to enable the internal video capture.
     */
    startVideoCapture() {
        return this.instance.startVideoCapture();
    }
    /**
     * @brief Disable internal video capture immediately. The default is off.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + Internal video capture refers to: use the RTC SDK built-in video capture module to capture.
     * + The local client will be informed via onVideoDeviceStateChanged after stopping video capture by calling this API.
     * + The remote clients in the room will be informed of the state change via onUserStopVideoCapture after the visible client stops video capture by calling this API.
     * + Call startVideoCapture to enable the internal video capture.
     * + Without calling this API the internal video capture will sustain until you destroy the engine instance.
     */
    stopVideoCapture() {
        return this.instance.stopVideoCapture();
    }
    /**
     * @brief Get a list of video capture devices in the current system.
     * @returns Contains a list of all video capture devices in the system.
     */
    enumerateVideoCaptureDevices() {
        return this.instance.enumerateVideoCaptureDevices();
    }
    /**
     * @brief Set the audio playback device to follow the OS default setting or not.
     * @param followed
     * + true: follow the os default setting. You can not call [setAudioPlaybackDevice](#setaudioplaybackdevice) at the same time.
     * + false: do not follow the os default setting. You can call [setAudioPlaybackDevice](#setaudioplaybackdevice) to set the audio playback device.
     * @returns + 0: Success
     * + < 0: Failure.
     */
    followSystemPlaybackDevice(followed) {
        if (utils_1.isNull(followed)) {
            return utils_1.errorFeedback("followSystemPlaybackDevice");
        }
        return this.instance.followSystemPlaybackDevice(followed);
    }
    /**
     * @brief Set the audio capture device to follow the OS default setting or not.
     * @param followed
     * + true: follow the os default setting. You can not call [setAudioCaptureDevice](#setaudiocapturedevice) at the same time.
     * + false: do not follow the os default setting. You can call [setAudioCaptureDevice](#setaudiocapturedevice) to set the audio capture device.
     * @returns + 0: Success
     * + < 0: Failure.
     */
    followSystemCaptureDevice(followed) {
        if (utils_1.isNull(followed)) {
            return utils_1.errorFeedback("followSystemCaptureDevice");
        }
        return this.instance.followSystemCaptureDevice(followed);
    }
    /**
     * @brief  Set the current video capture device
     * @param device_id Video device ID, which can be obtained through [EnumerateVideoCaptureDevices](#enumeratevideocapturedevices)
     * @returns + 0: Success
     * + < 0: Failure.
     */
    setVideoCaptureDevice(device_id) {
        if (utils_1.isNull(device_id)) {
            return utils_1.errorFeedback("setVideoCaptureDevice");
        }
        return this.instance.setVideoCaptureDevice(device_id);
    }
    /**
     * @brief Get the video capture device information currently used by the SDK
     * @returns Device ID
     */
    getVideoCaptureDevice() {
        return this.instance.getVideoCaptureDevice();
    }
    /**
     * @brief Video publisher call this API to set the configurations of each stream published, including resolution, frame rate, bitrate, scale mode, and fallback strategy in poor network conditions.
     * @param solutions List of configurations for multiple streams. You can set parameters for up to 3 streams, SDK will always take the value of the first 3 streams when parameters for more streams are set.
     *        The resolution you set is the maximum resolution of each stream, and must be arranged in descending order. The frame rates must be arranged in descending order.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + If you call this API after enabling the mode of publishing multiple streams with [enableSimulcastMode](#enablesimulcastmode), SDK will publish streams as you set, otherwise only the stream with the largest resolution you set will be published.
     * + Without calling this API to set parameters for multiple video streams, the SDK only publishes one video stream with a resolution of 640px × 360px and a frame rate of 15fps.
     * + After setting parameters for multiple video streams, SDK will automatically match the streams to be published based on the desired subscription parameters set by subscribers, see [Publish Multiple Streams](https://www.volcengine.com/docs/6348/70139) for details.
     * + This API is applicable to the video stream captured by the camera, see [setScreenVideoEncoderConfig](#setscreenvideoencoderconfig) for setting parameters for screen sharing video stream.
     */
    setVideoEncoderConfig(solutions) {
        if (utils_1.isNull(solutions)) {
            return utils_1.errorFeedback("setVideoEncoderConfig");
        }
        // set default value
        for (let i = 0; i < solutions.length; i++) {
            solutions[i].width = solutions[i].width || 360;
            solutions[i].height = solutions[i].height || 640;
            solutions[i].maxBitrate = solutions[i].maxBitrate || 500;
            solutions[i].encoderPreference =
                solutions[i].encoderPreference ||
                    types_1.VideoEncodePreference.kVideoEncodePreferenceDisabled;
        }
        return this.instance.setVideoEncoderConfig(solutions);
    }
    /**
     * @brief Video publisher call this API to set the parameters of the maximum resolution video stream that is expected to be published, including resolution, frame rate, bitrate, scale mode, and fallback strategy in poor network conditions.
     * @param max_solution The maximum video encoding parameter.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + If you call this API after enabling the mode of publishing multiple streams with [enableSimulcastMode](#enablesimulcastmode), SDK will automatically adjust the number of streams published and the parameters of each published stream according to the settings of subscribers. Up to 4 streams will be published, and the resolution you set in this API will be considered as the largest resolution among these 4 streams, see [Publish Multiple Streams](https://www.volcengine.com/docs/6348/70139) for details. Until you enable the mode of publishing multiple streams, SDK will only publish the stream you set.
     * + Without calling this API, SDK will only publish one stream for you with a resolution of 640px × 360px and a frame rate of 15fps.
     * + This API is applicable to the video stream captured by the camera, see [setScreenVideoEncoderConfig](#setscreenvideoencoderconfig) for setting parameters for screen sharing video stream.
     */
    setMaxVideoEncoderConfig(max_solution) {
        if (utils_1.isNull(max_solution)) {
            return utils_1.errorFeedback("setMaxVideoEncoderConfig");
        }
        // Default
        const tempSolution = {
            frameRate: 0,
            height: 0,
            width: 0,
            maxBitrate: -1,
            encoderPreference: types_1.VideoEncodePreference.kVideoEncodePreferenceFramerate,
        };
        return this.instance.setMaxVideoEncoderConfig({
            ...tempSolution,
            ...max_solution,
        });
    }
    /**
     * @brief Sets the mirror mode for the captured video stream.
     * @param room_id Room ID
     * @param mirror_type Mirror type
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + Switching video streams does not affect the settings of the mirror type.
     * + This API is not applicable to screen-sharing streams.
     * + Before you call this API, the initial states of each video stream are as follows:
     *         <table>
     *            <tr><th></th><th>Front-facing camera</th><th>Back-facing camera</th><th>Custom capturing</th><th>Built-in camera</th></tr>
     *            <tr><td>Mobile device</td><td>The preview is mirrored. The published video stream is not mirrored.</td><td>The preview and the published video stream are not mirrored.</td><td>The preview and the published video stream are not mirrored.</td><td>/</td></tr>
     *            <tr><td>PC</td><td>/</td><td>/</td><td>The preview and the published video stream are not mirrored.</td><td>The preview is mirrored. The published video stream is not mirrored.</td></tr>
     *         </table>
     */
    setLocalVideoMirrorType(room_id, mirror_type) {
        var _a, _b, _c;
        if (utils_1.isNull(room_id)) {
            return utils_1.errorFeedback("setLocalVideoMirrorType");
        }
        let user = (_a = data_1.default.get(room_id)) === null || _a === void 0 ? void 0 : _a.localUser;
        if (user) {
            if (mirror_type === types_1.MirrorType.kMirrorTypeRender) {
                user.renderOptions.mirror = true;
                (_b = user.videoRender) === null || _b === void 0 ? void 0 : _b.setMirrorType(true);
            }
            else {
                user.renderOptions.mirror = false;
                (_c = user.videoRender) === null || _c === void 0 ? void 0 : _c.setMirrorType(false);
            }
        }
        return this.instance.setLocalVideoMirrorType(mirror_type);
    }
    /**
     * @hidden
     * @brief Toggle the front/postcondition camera used for internal video capture
     * @param camera_id Camera ID
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + After calling this interface, [onVideoDeviceStateChanged](85533#onvideodevicestatechanged) will be triggered locally.
     * + Default uses front-facing camera.
     * + If you are using the camera for video capture, the toggle operation will take effect immediately; if the camera is not activated, the set camera will be turned on when the internal capture is turned on later.
     */
    // @checkInit
    // public switchCamera(camera_id: number): number {
    //   return this.instance.switchCamera(camera_id);
    // }
    /**
     * @brief Enables/Disables the mode of publishing multiple video streams with different encoding configuration.
     * @param enabled Whether to enable the mode of publishing multiple video streams:
     * + True: Yes
     * + False: No(Default setting)
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes You can call this API
     *  - Before entering the room, or
     *  - After entering the room but before publishing streams.
     * + After setting this API to "True", you can call [SetVideoEncoderConfig](#IRTCVideo-setvideoencoderconfig-1) to set encoding configuration for each stream.
     * + If this function is off, or if this function is on but you don't set the configuration of any stream, only one stream will be sent with a resolution of 640px × 360px and a frame rate of 15fps.
     */
    enableSimulcastMode(enabled) {
        if (utils_1.isNull(enabled)) {
            return utils_1.errorFeedback("enableSimulcastMode");
        }
        return this.instance.enableSimulcastMode(enabled);
    }
    /**
     * @brief  Video effects license check
     * @param license_path Absolute path of license file from platforms
     * @returns + 0: call succeeded
     * + 1000: not integrated cv sdk
     * + 1001: cv function is not supported in this RTC version
     * + < 0: Failure Please refer to [error codes](https://www.volcengine.com/docs/5889/61813).
     * @notes Before you start using video effects, you must first call this method for license verification
     */
    checkLicense(license_path) {
        if (utils_1.isNull(license_path)) {
            return utils_1.errorFeedback("checkLicense");
        }
        return this.instance.checkLicense(license_path);
    }
    /**
     * @brief Get authorization messages from the Effect SDK to obtain online licenses.
     * @returns Authorization message string address
     * @notes + You must obtain an online license for the Effect SDK before using the CV functions.
     * + After obtaining authorization messages through this API, you must refer to [Online Authorization Instructions](https://www.volcengine.com/docs/6705/102012) to implement the business logic of obtaining online licenses by yourself.
     * + After obtaining the license, you must call [checkLicense](#checklicense) to confirm that the license is valid. Then you can use the CV function.
     */
    getAuthMessage() {
        return this.instance.getAuthMessage();
    }
    /**
     * @brief  Turn on and off video effects
     * @param enabled  Whether to turn on effects, true: on, false: off
     * @returns + 0: Success
     * + 1000: Effect SDK is not integrated
     * + 1001: CV functionality is not supported in the current RTC version
     * + <0: Other errors, see [error codes](https://www.volcengine.com/docs/5889/61813)
     * @notes Call [checkLicense](#checklicense) and [setAlgoModelPath](#setaigomodelpath)
     */
    enableEffect(enabled) {
        if (utils_1.isNull(enabled)) {
            return utils_1.errorFeedback("enableEffect");
        }
        return this.instance.enableEffect(enabled);
    }
    /**
     * @brief Enables/Disables basic beauty effects.
     * @param enabled Whether to enable basic beauty effects.
     * + true: Enables basic beauty effects.
     * + false: (Default) Disables basic beauty effects.
     * @returns + 0: Success
     * + 1000: The Effect SDK is not integrated.
     * + 1001: This API is not available for your current RTC SDK.
     * + 1002: This API is not available for your current Effect SDK. You can upgrade your Effect SDK to V4.3.1+.
     * + 1003: Contact our technical support team for further instructions.
     * + 1004: Downloading related resources. The beauty effects will take effect after downloading.
     * + <0: Failure. Effect SDK internal error. For specific error code, see [error codes](https://docs.byteplus.com/effects/docs/error-code-table).
     * @notes + You cannot use the basic beauty effects and the advanced effect features at the same time. Call [enableVideoEffect](#enablevideoeffect) to use advanced effect features.
     * + You need to integrate Effect SDK before calling this API. Effect SDK V4.3.1+ is recommended.
     * + Call [setBeautyIntensity](#setbeautyintensity) to set the beauty effect intensity. If you do not set the intensity, the brightness, smoothness, and sharpness intensity will default to 0.5.
     * + This API is not applicable to screen capturing.
     */
    enableEffectBeauty(enabled) {
        if (utils_1.isNull(enabled)) {
            return utils_1.errorFeedback("");
        }
        return this.instance.enableEffectBeauty(enabled);
    }
    /**
     * @brief Sets the beauty effect intensity.
     * @param beauty_mode Basic beauty effect
     * @param intensity Beauty effect intensity in range of [0,1], default to 0.5. When you set it to 0, the beauty effect will be turned off.
     * @returns + 0: Success
     * + < 0: Failure.
     * + 1000: The Effect SDK is not integrated.
     * + 1001: This API is not available for your current RTC SDK.
     * + <0: Failure. Effect SDK internal error. For specific error code, see [error codes](https://docs.byteplus.com/effects/docs/error-code-table).
     * @notes + We recommend to call [checkLicense](#checklicense) to validate the license before using video effect enhancement.
     * + If you call this API before calling [enableEffectBeauty](#enableeffectbeauty), the default settings of beauty effect intensity will adjust accordingly.
     * + If you destroy the engine, the beauty effect settings will be invalid.
     */
    setBeautyIntensity(beauty_mode, intensity) {
        if (utils_1.isNull(beauty_mode) || utils_1.isNull(intensity)) {
            return utils_1.errorFeedback("");
        }
        return this.instance.setBeautyIntensity(beauty_mode, intensity);
    }
    /**
     * @brief  Set the video effects algorithm model path
     * @param model_path Model path
     * @returns + 0: Success
     * + < 0: Failure.
     */
    setAlgoModelPath(model_path) {
        if (utils_1.isNull(model_path)) {
            return utils_1.errorFeedback("setAlgoModelPath");
        }
        return this.instance.setAlgoModelPath(model_path);
    }
    /**
     * @brief Set video effects material package.
     * @param effect_node_paths Array of effect material package paths. To remove the current video effect, set it to null.
     * @returns + 0: Success
     * + 1000: The Effect SDK is not integrated.
     * + 1001: This API is not available for your Effect SDK.
     * + < 0: Failure. For specific error codes
     */
    setEffectNodes(effect_node_paths) {
        return this.instance.setEffectNodes(effect_node_paths);
    }
    /**
     * @brief  Set the effect intensity
     * @param node_path Special effects material package path
     * @param node_key The name of the material key to be set.
     * @param node_value The intensity value that needs to be set, the value range [0,1], and the setting is invalid when it exceeds the range.
     * @returns + 0: Success
     * + < 0: Failure.
     * + 1000: The Effect SDK is not integrated.
     * + 1001: This API is not available for your Effect SDK.
     * + < 0: Failure.
     */
    updateNode(node_path, node_key, node_value) {
        if (utils_1.isNull(node_path) || utils_1.isNull(node_key) || utils_1.isNull(node_value)) {
            return utils_1.errorFeedback("updateNode");
        }
        return this.instance.updateNode(node_path, node_key, node_value);
    }
    /**
     * @brief Set the color filter.
     * @param res_path Filter effects package absolute path.
     * @returns + 0: Success
     * + < 0: Failure.
     * + 1000: The Effect SDK is not integrated.
     * + 1001: This API is not available for your Effect SDK.
     * + <0: Other errors.
     */
    setColorFilter(res_path) {
        if (utils_1.isNull(res_path)) {
            return utils_1.errorFeedback("setColorFilter");
        }
        return this.instance.setColorFilter(res_path);
    }
    /**
     * @brief Set the intensity of the color filter enabled
     * @param intensity  Filter intensity. The value range [0,1] is set to be invalid when the range is exceeded.
     * @returns + 0: Success
     * + 1000: The Effect SDK is not integrated.
     * + 1001: This API is not available for your Effect SDK.
     * + < 0: Failure.
     */
    setColorFilterIntensity(intensity) {
        if (utils_1.isNull(intensity)) {
            return utils_1.errorFeedback("setColorFilterIntensity");
        }
        return this.instance.setColorFilterIntensity(intensity);
    }
    /**
     * @brief Create a new task of pushing media streams to CDN and sets the relevant configurations.
     * @param task_id Task ID. You may want to push more than one mixed stream to CDN from the same room. When you do that, use different ID for corresponding tasks; if you will start only one task, use an empty string.
     * @param param  Configurations to be set when pushing streams to CDN.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + When pushing more than one live streams in the same task, SDK will first mix those streams into one single stream and then push it to CDN.
     * + After calling this API, you will be informed of the result and errors during the pushing process via the onStreamMixingEvent(85533#onstreammixingevent) callback.
     * + Call [stopLiveTranscoding](#stoplivetranscoding) to stop pushing streams to CDN.
     */
    startLiveTranscoding(task_id, param) {
        if (!task_id || utils_1.isNull(param) || !param.room_id || !param.user_id) {
            return utils_1.errorFeedback("startLiveTranscoding");
        }
        //Default
        const tempParam = {
            app_data: "",
            background_color: "0x000000",
            room_id: "",
            user_id: "",
            uri: "",
            audio_param: {
                i32_sample_rate: 48000,
                i32_channel_num: 2,
                i32_bitrate_kbps: 128,
                audio_codec_profile: 0,
            },
            video_param: {
                i32_width: 640,
                i32_height: 360,
                i32_fps: 15,
                i32_gop: 60,
                i32_bitrate_kbps: 500,
                video_codec_profile: 0,
                lowLatency: false,
            },
            layout_regions: [],
        };
        return this.instance.startLiveTranscoding(task_id, {
            ...tempParam,
            ...param,
        });
    }
    /**
     * @brief Stops pushing media streams to CDN.
     * @param task_id Task ID. Specifys which pushing task you want to stop.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes You will be informed of the change via the [onStreamMixingEvent](85533#onstreammixingevent).
     */
    stopLiveTranscoding(task_id) {
        if (!task_id) {
            return utils_1.errorFeedback("stopLiveTranscoding");
        }
        return this.instance.stopLiveTranscoding(task_id);
    }
    /**
     * @brief Update parameters needed when pushing media streams to CDN.
     * @param task_id Task ID. Specifys of which pushing task you want to update the parameters.
     * @param param Configurations that you want to update
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + You will be informed of the change via the onStreamMixingEvent(85533#onstreammixingevent).
     * + After calling [startLiveTranscoding](#startlivetranscoding) to enable the function of pushing streams to CDN, you can call this API to update the relevant configurations.
     */
    updateLiveTranscoding(task_id, param) {
        if (utils_1.isNull(task_id) || utils_1.isNull(param) || !param.room_id || !param.user_id) {
            return utils_1.errorFeedback("updateLiveTranscoding");
        }
        ////Default
        const tempParam = {
            app_data: "",
            background_color: "0x000000",
            room_id: "",
            user_id: "",
            uri: "",
            audio_param: {
                i32_sample_rate: 48000,
                i32_channel_num: 2,
                i32_bitrate_kbps: 128,
                audio_codec_profile: 0,
            },
            video_param: {
                i32_width: 640,
                i32_height: 360,
                i32_fps: 15,
                i32_gop: 60,
                i32_bitrate_kbps: 500,
                video_codec_profile: 0,
                lowLatency: false,
            },
            layout_regions: [],
        };
        return this.instance.updateLiveTranscoding(task_id, {
            ...tempParam,
            ...param,
        });
    }
    /**
     * @brief Create a new task of pushing a single media stream to CDN.
     * @param task_id Task ID. You may want to start more than one task to push streams to CDN. When you do that, use different IDs for corresponding tasks; if you will start only one task, use an empty string.
     * @param param  Configurations for pushing a single stream to CDN.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + After calling this API, you will be informed of the result and errors during the pushing process with [`onStreamPushEvent`](85533#onstreampushevent).
     *       + Call [`stopPushStreamToCDN`](85532#stoppushstreamtocdn) to stop the task.
     */
    startPushSingleStreamToCDN(task_id, param) {
        if (utils_1.isNull(task_id) || utils_1.isNull(param) || !param.room_id || !param.user_id) {
            return utils_1.errorFeedback("startPushSingleStreamToCDN");
        }
        return this.instance.startPushSingleStreamToCDN(task_id, param);
    }
    /**
     * @brief Stops the task to push a single media stream to CDN.
     * @param task_id Task ID. Specifys the task to stop.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes To start the task, refer to [`startPushStreamToCDN`](85532#startpushstreamtocdn) and [`startPushSingleStreamToCDN`](85532#startPushSingleStreamToCDN).
     */
    stopPushStreamToCDN(task_id) {
        if (utils_1.isNull(task_id)) {
            return utils_1.errorFeedback("stopPushStreamToCDN");
        }
        return this.instance.stopPushStreamToCDN(task_id);
    }
    /**
     * @brief Assign a custom renderer to the public stream
     * @param stream_id ID of the public stream
     * @param video_sink Do not pass this argument if you want to assign to the external renderer. Set to be `null` when you want to release the renderer.
     * @return + 0: Success
     *        + !0: Failure
     */
    setPublicStreamVideoSink(stream_id, video_sink) {
        if (!stream_id) {
            return utils_1.errorFeedback("setPublicStreamVideoSink");
        }
        if (video_sink === null) {
            return this.instance.unsetPublicStreamVideoSink(stream_id);
        }
        return this.instance.setPublicStreamVideoSink(stream_id);
    }
    /**
     * @brief Start publishing a public media stream.
     * @param stream_id ID of the public stream
     * @param public_stream Properties of the public stream.
     *              A public stream can include a bundle of media streams and appears as the designated layout.
     * @return + 0: Success. And you will be informed by [`onPushPublicStreamResult`](85533#onpushpublicstreamresult).
     *        + !0: Failure because of invalid parameter or empty parameters.
     * @notes + Users within the same `appID` can call [`startPlayPublicStream`](#startplaypublicstream) to subscribe to the public stream regardless the user has joined which room or has not joined any room.
     * + Call [`updatePublicStreamParam`](#updatepublicstreamparam) to update the properties of the public stream which is published by the same user. Calling this API with the same stream ID repeatedly by the same user can not update the existing public stream.
     *        + If Users with different userID call this API with the same stream ID, the public stream will be updated with the parameters passed in the latest call.
     *        + To publish multiple public streams, call this API with different stream ID respectively.
     *        + To stop publishing the public stream, call [`stopPushPublicStream`](#stoppushpublicstream).
     *        + Please contact ts to enable this function before using it.
     */
    startPushPublicStream(stream_id, public_stream) {
        if (!stream_id || utils_1.isNull(public_stream.room_id)) {
            return utils_1.errorFeedback("startPushPublicStream");
        }
        //默认参数
        const tempParam = {
            mode: 0,
            room_id: "",
            background_image_uri: "",
            audio_param: {
                sample_rate: 48000,
                channel_num: 2,
                bitrate_kbps: 32,
            },
            video_param: {
                width: 640,
                height: 360,
                fps: 15,
                bitrate_kpbs: 500,
            },
            layout_regions: [],
        };
        const utralParam = {
            ...tempParam,
            ...public_stream,
        };
        return this.instance.startPushPublicStream(stream_id, utralParam);
    }
    /**
     * @brief Stop the public stream published by the current user.
     * @param stream_id ID of the public stream
     *                  The public stream must be published by the current user.
     * @return + 0: Success
     *        + !0: Failure
     * @notes Refer to [`startPushPublicStream`](#startpushpublicstream) for details about starting publishing a public stream.
     */
    stopPushPublicStream(stream_id) {
        if (!stream_id) {
            return utils_1.errorFeedback("stopPushPublicStream");
        }
        return this.instance.stopPushPublicStream(stream_id);
    }
    /**
     * @brief Update the properties of the public stream published by the current user.
     * @param stream_id ID of the public stream
     *              The stream to be updated must be published by the current user.
     * @param param Properties of the public stream.
     * @return + 0: Success
     *        + !0: Failure
     * @notes Refer to [`startPushPublicStream`](#startpushpublicstream) for details about starting publishing a public stream.
     */
    updatePublicStreamParam(stream_id, param) {
        if (!stream_id || utils_1.isNull(param.room_id)) {
            return utils_1.errorFeedback("updatePublicStreamParam");
        }
        //默认参数
        const tempParam = {
            mode: 0,
            room_id: "",
            background_image_uri: "",
            audio_param: {
                sample_rate: 48000,
                channel_num: 2,
                bitrate_kbps: 32,
            },
            video_param: {
                width: 640,
                height: 360,
                fps: 15,
                bitrate_kpbs: 500,
            },
            layout_regions: [],
        };
        return this.instance.updatePublicStreamParam(stream_id, {
            ...tempParam,
            ...param,
        });
    }
    /**
     * @brief Subscribe the public stream. A user can call this method to subscribe a public stream whether he/she has joined the room or not.
     * @param stream_id ID of the public stream. If the stream has not been published then, the local client will receive the public stream once it starts publishing.
     * @return
     *        + 0: Success. You will also be informed by [`onPlayPublicStreamResult`](85533#onplaypublicstreamresult).
     *        + !0: Failure because of invalid parameter or empty parameters.
     * @notes
     *        + We recommend to bind a view for the public stream before calling this API to subscribe a public stream.
     *              - Internal renderer: By calling [`setupPublicStreamVideo`](#setuppublicstreamvideo) or
     *              - Custom renderer: By calling [`setPublicStreamVideoSink`](#setpublicstreamvideosink)
     *        + After calling this API, you will be informed once the first frame has been decoded successfully by [`onFirstPublicStreamVideoFrameDecoded`](85533#onfirstpublicstreamvideoframedecoded) and [`onFirstPublicStreamAudioFrame`](85533#onfirstpublicstreamaudioframe).
     *        + If the public stream contains SEI information, you will be informed by [`onPublicStreamSEIMessageReceived`](85533#onpublicstreamseimessagereceived).
     *        + Call [`stopPlayPublicStream`](#stopplaypublicstream) to cancel subscribing the public stream.
     */
    startPlayPublicStream(stream_id) {
        if (!stream_id) {
            return utils_1.errorFeedback("startPlayPublicStream");
        }
        return this.instance.startPlayPublicStream(stream_id);
    }
    /**
     * @brief Cancel subscribing the public stream.
     * @param stream_id public_stream_id ID of the public stream
     * @return
     *        + 0: Success
     *        + !0: Failure
     * @notes Call this method to cancel subscribing to the public stream by calling [`startPlayPublicStream`](#startplaypublicstream).
     */
    stopPlayPublicStream(stream_id) {
        if (!stream_id) {
            return utils_1.errorFeedback("stopPlayPublicStream");
        }
        return this.instance.stopPlayPublicStream(stream_id);
    }
    ///屏幕共享API
    /**
     * @brief When sharing the screen, start using RTC SDK internal collection method to collect screen audio
     * @param device_id ID of the virtual device. You need to pass the ID to the API only for Mac.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + After collection, you also need to call [publishScreen](#publishscreen) to collect the screen audio Push to the far end.
     * + To turn off screen audio internal capture, call [stopScreenAudioCapture](#stopscreenaudiocapture).
     */
    startScreenAudioCapture(device_id) {
        if (!device_id) {
            return this.instance.startScreenAudioCapture();
        }
        else {
            return this.instance.startMacScreenAudioCapture(device_id);
        }
    }
    /**
     * @brief When sharing the screen, start using RTC SDK internal collection method to collect screen audio on Mac.
     * @param device_id ID of the virtual device. You need to pass the ID to the API only for Mac.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + After collection, you also need to call [publishScreen](#publishscreen) to collect the screen audio Push to the far end.
     * + To turn off screen audio internal capture, call [stopScreenVideoCapture](#stopscreenvideocapture).
     */
    startMacScreenAudioCapture(device_id) {
        return this.instance.startMacScreenAudioCapture(device_id);
    }
    /**
     * @brief  Capture screen video stream for sharing. Screen video stream includes: content displayed on the screen, in the application window, or in the virtual screen.
     * @param info Screen capture source information. Call [getScreenCaptureSourceList](#getscreencapturesourcelist) to get all the screen sources that can be shared.
     * @param params Screen capture parameters
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + Displaying contents in virtual screens is only available on Windows.
     * + This API only starts screen capturing but does not publish the captured video. Call [publishScreen](#publishscreen) to publish the captured video.
     * + To turn off screen video capture, call stopScreenVideoCapture.
     * + Local users will receive [onVideoDeviceStateChanged](85533#onvideodevicestatechanged) on the state of screen capturing such as start, pause, resume, and error.
     * + After successfully calling this API, local users will receive [onFirstLocalVideoFrameCaptured](85533#onfirstlocalvideoframecaptured).
     * + Before calling this API, you can call [setVideoEncoderConfig](#setvideoencoderconfig) to set the frame rate and encoding resolution of the screen video stream.
     * + After receiving [onFirstLocalVideoFrameCaptured](85533#onfirstlocalvideoframecaptured), you can set the local screen sharing view by calling [setupLocalScreen](#setuplocalscreen).
     */
    startScreenVideoCapture(info, params) {
        let newInfo = { ...info };
        if (!newInfo.source_name) {
            newInfo.source_name = "";
        }
        return this.instance.startScreenVideoCapture(newInfo, params);
    }
    /**
     * @brief Stop recording device audio.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes To start the device audio recording, call [startScreenAudioCapture](#startscreenaudiocapture).
     */
    stopScreenAudioCapture() {
        return this.instance.stopScreenAudioCapture();
    }
    /**
     * @brief Stop screen video streaming.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + To turn on screen video stream capture, calling [startScreenVideoCapture](#startscreenvideocapture)
     * + Local users will receive the [onVideoDeviceStateChanged](85533#onvideodevicestatechanged) callback.
     * + Calling this interface does not affect screen video stream publishing.
     */
    stopScreenVideoCapture() {
        return this.instance.stopScreenVideoCapture();
    }
    /**
     * @brief Update the capture area when capturing screen video streams through the capture module provided by the RTC SDK.
     * @param region_rect Region to be shared. This parameter describes the acquisition area after calling this interface, and the relative relationship between the 'source_info' setting area in [startScreenVideoCapture](#startscreenvideocapture).
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes Before calling this interface, internal screen stream capture must have been turned on by calling [startScreenVideoCapture](#startscreenvideocapture).
     */
    updateScreenCaptureRegion(region_rect) {
        if (utils_1.isNull(region_rect)) {
            return utils_1.errorFeedback("updateScreenCaptureRegion");
        }
        return this.instance.updateScreenCaptureRegion(region_rect);
    }
    /**
     * @brief Update border highlighting settings when capturing screen video streams through the capture module provided by the RTC SDK. The default display table box.
     * @param highlight_config Border highlighting settings.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes Before calling this interface, you must have turned on internal screen flow collection by calling [startScreenVideoCapture](#startscreenvideocapture).
     */
    updateScreenCaptureHighlightConfig(highlight_config) {
        if (utils_1.isNull(highlight_config)) {
            return utils_1.errorFeedback("updateScreenCaptureHighlightConfig");
        }
        return this.instance.updateScreenCaptureHighlightConfig(highlight_config);
    }
    /**
     * @brief Update the processing settings for the mouse when capturing screen video streams through the capture module provided by the RTC SDK. Default acquisition mouse.
     * @param state
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes Before calling this interface, internal screen stream capture must have been turned on by calling [startScreenVideoCapture](#startscreenvideocapture).
     */
    updateScreenCaptureMouseCursor(state) {
        if (utils_1.isNull(state)) {
            return utils_1.errorFeedback("updateScreenCaptureMouseCursor");
        }
        return this.instance.updateScreenCaptureMouseCursor(state);
    }
    /**
     * @brief When capturing screen video streams through the capture module provided by the RTC SDK, set the window that needs to be filtered.
     * @param screen_filter_config Window filtering settings
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + Before calling this interface, internal screen stream capture must have been turned on by calling [startScreenVideoCapture](#startscreenvideocapture).
     * + This function only works when the screen source category is a screen rather than an application form.
     */
    updateScreenCaptureFilterConfig(screen_filter_config) {
        if (utils_1.isNull(screen_filter_config)) {
            return utils_1.errorFeedback("updateScreenCaptureFilterConfig");
        }
        return this.instance.updateScreenCaptureFilterConfig(screen_filter_config);
    }
    /**
     * @brief Get the item list for screen sharing.
     * @returns List of the screen-sharing objects, including application window and screens. After the user has decided which item to be shared, pass the object to RTC as an argument of [startScreenVideoCapture](#startscreenvideocapture).
     * @notes Whether to include the minimized windows is different based on platforms:
     * + The minimized windows are included in the return value for Windows;
     * + The minimized windows are not included in the return value for macOS or Linux.
     */
    getScreenCaptureSourceList() {
        return this.instance.getScreenCaptureSourceList();
    }
    // share screen
    /**
     * @brief Get the preview thumbnail of the screen-sharing object
     * @param type Type of the screen capture object
     * @param source_id ID of the screen-shared object
     * @param max_width Maximum width of the preview thumbnail
     * @param max_height Maximum height of the preview thumbnail
     * @returns + 0: Success
     * + < 0: Failure.
     */
    getThumbnail(type, source_id, max_width, max_height) {
        let obj = this.instance.getThumbnail(type, source_id, max_width, max_height);
        if (obj.data) {
            obj.data = "data:image/png;base64," + obj.data;
        }
        return obj;
    }
    /**
     * @brief Get application window preview thumbnail for screen sharing.
     * @param source_id ID of the screen-sharing object. You can get the ID by calling [getScreenCaptureSourceList](#getscreencapturesourcelist).
     * @param max_width Maximum width of the App icon. The width is always equal to the height. SDK will set the height and width to the smaller value if the given values are unequal. RTC will return nullptr if you set the value with a number out of the valid range, [32, 256]. The default size is 100 x 100.
     * @param max_height Maximum height of the app icon. Refer to the note for  `max_width`
     * @return You can get the icon when the item to be shared is an application and the application is assigned with an icon. If not, the return value will be nullptr.
     */
    getWindowAppIcon(source_id, max_width, max_height) {
        let obj = this.instance.getWindowAppIcon(source_id, max_width, max_height);
        if (obj.data) {
            obj.data = "data:image/png;base64," + obj.data;
        }
        return obj;
    }
    /**
     * @brief Set the mixing mode of the screen audio stream and the audio stream collected by the microphone when the screen is shared
     * @param index The mixing mode.
     * + 'kStreamIndexMain': Mix the audio stream collected by the screen audio stream and the microphone
     * + 'KStreamIndexScreen ': By default, it divides  the screen audio stream and the audio stream collected by the microphone into two audio streams
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes You should call this method before [publishScreen](#publishscreen). Otherwise, you will receive an error from [onWarning](85533#onwarning) : `kWarningCodeSetScreenAudioStreamIndexFailed`
     */
    setScreenAudioStreamIndex(index) {
        return this.instance.setScreenAudioStreamIndex(index);
    }
    /**
     * @brief Video publisher call this API to set the expected configurations for the screen sharing video stream, including resolution, frame rate, bitrate, and fallback strategy in poor network conditions.
     * @param screen_solution You expected configurations for screen sharing video stream.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes Without calling this API, the default encoding parameters for screen sharing video streams are: resolution 1920px × 1080px, frame rate 15fps.
     */
    setScreenVideoEncoderConfig(screen_solution) {
        if (utils_1.isNull(screen_solution)) {
            return utils_1.errorFeedback("setScreenVideoEncoderConfig");
        }
        //Default
        const tempSolution = {
            frameRate: 0,
            height: 0,
            width: 0,
            maxBitrate: -1,
            encoderPreference: types_1.VideoEncodePreference.kVideoEncodePreferenceFramerate,
        };
        return this.instance.setScreenVideoEncoderConfig({
            ...tempSolution,
            ...screen_solution,
        });
    }
    ///RTS
    /**
     * @brief Log in to send P2P messages or send messages to a server without joining the RTC room.
     * @param token Token is required during login for authentication.
     *        This Token is different from that required by calling joinRoom. You can assign any value even null to `roomId` to generate a login token. During developing and testing, you can use temporary tokens generated on the console. Deploy the token generating application on your server.
     * @param uid User ID which is unique within one appid.
     * @returns + `0`: Success
     * + `-1`: Failure due to invalid parameter
     * + `-2`: Invalid call. RTC will return this value when you call this API after the user has been logged in to the server.
     * @notes + To log out, call [Logout](#logout).
     * + You will receive [onLoginResult](85533#onloginresult) after calling this API and log in successfully. But remote users will not receive notification about that.
     */
    login(token, uid) {
        if (utils_1.isNull(token) || utils_1.isNull(uid)) {
            return utils_1.errorFeedback("login");
        }
        return this.instance.login(token, uid);
    }
    /**
     * @brief  Calls this interface to log out, it is impossible to call methods related to out-of-room messages and end-to-server messages or receive related callbacks.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + Before calling this interface to log out, you must call [login](85532#login) to log in.
     * + After local users call this method to log out, they will receive the result of the [onLogout](85533#onlogout) callback notification, and remote users will not receive the notification.
     */
    logout() {
        return this.instance.logout();
    }
    /**
     * @brief Update the Token
     * @param token Token used by the user to log in has a certain valid period. When the Token expires, you need to call this method to update the login Token information.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + When calling the [login](#login) method to log in, if an expired token is used, the login will fail and you will receive an [onLoginResult](85533#onloginresult) notification with an error code of kLoginErrorCodeInvalidToken. You need to reacquire the token and call this method to update the token.
     * + If the token is invalid and the login fails, call this method. After updating the token, the SDK will automatically log back in, and the user does not need to call the [login](#login) method.
     * + Token expires, if you have successfully logged in, it will not be affected. An expired Token error will be notified to the user the next time you log in with an expired Token, or when you log in again due to a disconnection due to poor local network conditions.
     */
    updateLoginToken(token) {
        if (utils_1.isNull(token)) {
            return utils_1.errorFeedback("updateLoginToken");
        }
        return this.instance.updateLoginToken(token);
    }
    /**
     * @brief Set application server parameters
     * @param signature Dynamic signature. The service server uses this signature to authenticate the request.
     * @param url The address of the application server
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + Client side calls [sendServerMessage](#sendservermessage) or [sendServerBinaryMessage](#sendserverbinarymessage) Before sending a message to the application server, a valid signature and application server address must be set.
     * + The user must call [login](#login) to log in before calling this interface.
     * + After calling this interface, the SDK will use [onServerParamsSetResult](85533#onserverparamssetresult) to return the corresponding result.
     */
    setServerParams(signature, url) {
        if (utils_1.isNull(signature) || utils_1.isNull(url)) {
            return utils_1.errorFeedback("setServerParams");
        }
        return this.instance.setServerParams(signature, url);
    }
    /**
     * @brief Query the login status of the opposite or local user
     * @param peer_user_id User ID to be queried
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes * + [login](#login) must be called before this interface can be called.
     * + After calling this interface, the SDK notifies the query result using the [onGetPeerOnlineStatus](85533#ongetpeeronlinestatus) callback.
     * + Before sending an out-of-room message, the user can know whether the peer user is logged in through this interface to decide whether to send a message. You can also check your login status through this interface.
     */
    getPeerOnlineStatus(peer_user_id) {
        if (!peer_user_id) {
            return utils_1.errorFeedback("getPeerOnlineStatus");
        }
        return this.instance.getPeerOnlineStatus(peer_user_id);
    }
    /**
     * @brief Send a text message (P2P) to a specified user outside the room
     * @param uid Message receiving user's ID
     * @param message Text message content sent. Message does not exceed 64 KB.
     * @param config Message type
     * @returns + > 0: Sent successfully, return the number of the sent message, increment from 1
     * + -1: Sent failed, IRTCVideo instance not created
     * + -2: Sent failed, uid is empty
     * @notes + You must call [login](#login) to complete the login before you can send a message in a foreign text of the room.
     * + After the user calls this interface to send a text message, he will receive an [onUserMessageSendResultOutsideRoom](85533#onusermessagesendresultoutsideroom) callback to know whether the message was successfully sent.
     * + If the text message is sent successfully, the user specified by uid receives the message via the [onUserMessageReceivedOutsideRoom](85533#onusermessagereceivedoutsideroom) callback.
     */
    sendUserMessageOutsideRoom(uid, message, config) {
        if (utils_1.isNull(uid) || utils_1.isNull(message)) {
            return utils_1.errorFeedback("sendUserMessageOutsideRoom");
        }
        return this.instance.sendUserMessageOutsideRoom(uid, message, config);
    }
    /**
     * @brief Send binary messages (P2P) to a specified user outside the room
     * @param uid ID of the user receiving the message
     * @param length Length of the binary string
     * @param message Content of the binary message sent. Message does not exceed 64 KB.
     * @param config Message type
     * @returns + > 0: sent successfully, return the number of the sent message, increment from 1
     * + -1: Sent failed, IRTCVideo instance not created
     * + -2: Sent failed, uid is empty
     * @notes + [login](#login) must be called before sending out-of-room binary messages.
     * + After the user calls this interface to send a binary message, he will receive an [onUserMessageSendResultOutsideRoom](85533#onusermessagesendresultoutsideroom) callback to notify whether the message was sent successfully.
     * + If the binary message is sent successfully, the user specified by uid will receive the message through the [onUserMessageReceivedOutsideRoom](85533#onusermessagereceivedoutsideroom) callback.
     */
    sendUserBinaryMessageOutsideRoom(uid, length, message, config) {
        if (utils_1.isNull(uid) || utils_1.isNull(length) || utils_1.isNull(message)) {
            return utils_1.errorFeedback("sendUserBinaryMessageOutsideRoom");
        }
        return this.instance.sendUserBinaryMessageOutsideRoom(uid, length, message, config);
    }
    /**
     * @brief The client side sends a text message to the application server (P2Server)
     * @param message The content of the text message sent. The message does not exceed 64 KB.
     * @returns + > 0: Sent successfully, return the number of the sent message, increment from 1
     * + -1: Sent failed, IRTCVideo instance not created
     * @notes * + Before sending a text message to the application server, you must first call [login](#login) to complete the login, and then call [setServerParams](85532#setserverparams)) Set up the application server.
     * + After calling this interface, you will receive an [onServerMessageSendResult](85533#onservermessagesendresult) callback to inform the message sender whether the message was sent successfully.
     * + If the text message is sent successfully, the application server that previously called [setServerParams](85532#setserverparams) will receive the message.
     */
    sendServerMessage(message) {
        if (utils_1.isNull(message)) {
            return utils_1.errorFeedback("sendServerMessage");
        }
        return this.instance.sendServerMessage(message);
    }
    /**
     * @brief Client side sends binary messages to the application server (P2Server)
     * @param length Length of binary string
     * @param message Binary message content sent
     *        Message does not exceed 46KB.
     * @returns + > 0: Sent successfully, return the number of the sent message, increment from 1
     * + -1: Sent failed, IRTCVideo instance not created
     * @notes
     * + Before sending a binary message to the application server, you must first call [login](#login) to complete the login, and then call [setServerParams](85532#setserverparams) Set up the application server.
     * + After calling this interface, you will receive an [onServerMessageSendResult](85533#onservermessagesendresult) callback to inform the message sender that the sending succeeded or failed.
     * + If the binary message is sent successfully, the application server that previously called [setServerParams](85532#setserverparams) will receive the message.
     */
    sendServerBinaryMessage(length, message) {
        if (utils_1.isNull(length) || utils_1.isNull(message)) {
            return utils_1.errorFeedback("sendServerBinaryMessage");
        }
        return this.instance.sendServerBinaryMessage(length, message);
    }
    /**
     * @brief Sends SEI data.
     * @param stream_index Specifys the type of media stream that carries SEI data.
     *        In a voice call, you should set this parameter to `kStreamIndexMain`, otherwise the SEI data is discarded and cannot be sent to the remote user.
     * @param message SEI data
     * @param repeat_count SEI data length, no more than 4 KB.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + In a video call scenario, SEI is sent with the video frame, while in a voice call scenario, SDK will automatically publish a black frame with a resolution of 16px × 16px to carry SEI data.
     * + In a voice call scenario, this API can be called to send SEI data only in internal capture mode and with a frequency of 15/repeat_count FPS.
     * + Each video frame carrys only the SEI data received within 2s before and after. In a voice call scenario, if no SEI data is sent within 1min after calling this API, SDK will automatically cancel publishing black frames.
     * + After the message is sent successfully, the remote user who subscribed your video stream will receive [onSEIMessageReceived](85533#onseimessagereceived).
     * + When you switch from a voice call to a video call, SEI data transmission will stop and you will need to call this API again to resume the transmission.
     */
    sendSEIMessage(stream_index, message, repeat_count) {
        return this.instance.sendSEIMessage(stream_index, message, repeat_count);
    }
    /**
     * @brief  Set the video capture parameters for internal capture of the RTC SDK.
     * @param config Video capture parameters.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes
     *  + This interface can be called after the engine is created and takes effect immediately after being called. It is recommended to call this interface before calling [startVideoCapture](85532#startvideocapture).
     *  + It is recommended that different Engines on the same device use the same video capture parameters.
     *  + If you used the internal module to start video capture before calling this interface, the capture parameters default to Auto.
     */
    setVideoCaptureConfig(config) {
        if (utils_1.isNull(config)) {
            return utils_1.errorFeedback("setVideoCaptureConfig");
        }
        //Default
        const tempConfig = {
            capturePreference: types_1.CapturePreference.KAuto,
            width: 0,
            height: 0,
            frameRate: 0,
        };
        return this.instance.setVideoCaptureConfig({
            ...tempConfig,
            ...config,
        });
    }
    /**
     * @brief Start mixing audio files.
     * @param id ID of the mixing task. Used to identify the mixing task.
     *         If this method is repeatedly called with the same ID, the previous mixing task will be stopped and a new task will start. When the previous task is stopped, you will receive `onAudioMixingStateChanged`.
     *         To mixing multiple audio files at the same time, you can call this method with different mixIDs.
     * @param file_path The path of the mixing audio file.
     *        You can use the URL of the online file, and the absolute path of the local file. For the URL of the online file, only https protocol is supported.
     * @param mixing_config Mixing configuration
     *         You can set the number of times the file is played, whether the file is played locally or remotely.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + If you have already loaded the file in memory with [preloadAudioMixing](#preloadaudiomixing), ensure that the mixID is the same.
     * + After calling this method, you will receive `onAudioMixingStateChanged` about the current mixing status.
     * + Call [stopAudioMixing](#stopaudiomixing) to stop the mixing task.
     */
    startAudioMixing(id, file_path, mixing_config) {
        if (utils_1.isNull(id)) {
            return utils_1.errorFeedback("startAudioMixing");
        }
        if (utils_1.isNull(file_path)) {
            return utils_1.errorFeedback("startAudioMixing");
        }
        return this.instance.startAudioMixing(id, file_path, mixing_config);
    }
    /**
     * @brief  Stop playing music files and mixes
     * @param id ID of the mixing task
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + After calling the [startAudioMixing](#startaudiomixing) method to start playing music files and mixes, you can call this method to stop playing music files and mixes.
     * + After calling this method to stop playing the music file, the SDK notifies the local callback that the mixing has been stopped. See `onAudioMixingStateChanged`.
     * + After calling this method to stop playing the music file, the music file will be automatically uninstalled.
     */
    stopAudioMixing(id) {
        if (utils_1.isNull(id)) {
            return utils_1.errorFeedback("stopAudioMixing");
        }
        return this.instance.stopAudioMixing(id);
    }
    /**
     * @brief  Pause playing music files and mixes
     * @param id ID of the mixing task
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes
     * + After calling the [startAudioMixing](#startaudiomixing) method to start playing music files and mixes, you can call this method to pause playing music files and mixes.
     * + After calling this method to pause playing music files and mixing, you can call the [resumeAudioMixing](#resumeaudiomixing) method to resume playing and mixing.
     * + After calling this method to pause playing the music file, the SDK will notify the local callback that the mixing has been suspended.
     */
    pauseAudioMixing(id) {
        if (utils_1.isNull(id)) {
            return utils_1.errorFeedback("pauseAudioMixing");
        }
        return this.instance.pauseAudioMixing(id);
    }
    /**
     * @brief  Resume playing music files and mixing
     * @param id mix_id
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + After calling the [pauseAudioMixing](#pauseaudiomixing) method to pause playing music files and mixing, you can resume playing and mixing by calling this method.
     * + After calling this method to resume playing the music file and mixing, the SDK will notify the local callback that the music file is playing.
     */
    resumeAudioMixing(id) {
        if (utils_1.isNull(id)) {
            return utils_1.errorFeedback("resumeAudioMixing");
        }
        return this.instance.resumeAudioMixing(id);
    }
    /**
     * @brief Preload the audio file into memory to minimize the loading cost of playing repeatedly.
     * @param id ID of the mixing task. Used to identify the mixing task.
     *        If this method is repeatedly called with the same ID, the previous file will be unloaded and the new file will be loaded.
     *         If you call [startAudioMixing](#startaudiomixing) and then call this method with the same ID, the previous mixing task will be stopped, and then the next file will be loaded.
     *         After calling this method to preload A.mp3, if you need to call [startAudioMixing](#startaudiomixing) to play B.mp3 with the same ID, call [unloadAudioMixing](#unloadaudiomixing) to unload A.mp3 first.
     * @param file_path The path of the file to preload.
     *        You can use the URL of the online file, and the absolute path of the local file. For the URL of the online file, only https protocol is supported. You can only perload the audio file of length less than 20s.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + After preloaded, call [startAudioMixing](#startaudiomixing) to play the audio file.
     * + After calling this method, you will receive `onAudioMixingStateChanged` about the current mixing status.
     * + Unload the preloaded file with [unloadAudioMixing](#unloadaudiomixing).
     */
    preloadAudioMixing(id, file_path) {
        if (utils_1.isNull(id)) {
            return utils_1.errorFeedback("preloadAudioMixing");
        }
        if (utils_1.isNull(file_path)) {
            return utils_1.errorFeedback("preloadAudioMixing");
        }
        return this.instance.preloadAudioMixing(id, file_path);
    }
    /**
     * @brief Uninstall the specified music file
     * @param id ID of the mixing task
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes Whether the music file is playing or not, after calling this method to uninstall the file, the SDK will call back to notify that the mix has stopped. See `onAudioMixingStateChanged`.
     */
    unloadAudioMixing(id) {
        if (utils_1.isNull(id)) {
            return utils_1.errorFeedback("unloadAudioMixing");
        }
        return this.instance.unloadAudioMixing(id);
    }
    /**
     * @brief Adjust the volume of audio mixing, including audio files and PCM data.
     * @param id ID of the mixing task
     * @param volume The ratio of the mixing volume to the original volume. The range is `[0, 400]`. The recommended range is `[0, 100]`.
     * + 0: Mute
     * + 100: Original volume
     * + 400: Maximum volume (with overflow protection)
     * @param type Mixing type
     * @returns + 0: Success
     * + < 0: Failure.
     */
    setAudioMixingVolume(id, volume, type) {
        if (utils_1.isNull(id)) {
            return utils_1.errorFeedback("setAudioMixingVolume");
        }
        return this.instance.setAudioMixingVolume(id, volume, type);
    }
    /**
     * @brief Get the duration of the music file
     * @param id ID of the mixing task
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes Before calling this method to get the length of the music file, you need to call [preloadAudioMixing](#preloadaudiomixing) or [startAudioMixing](#startaudiomixing).
     */
    getAudioMixingDuration(id) {
        if (utils_1.isNull(id)) {
            return utils_1.errorFeedback("getAudioMixingDuration");
        }
        return this.instance.getAudioMixingDuration(id);
    }
    /**
     * @brief Get the music file playback progress
     * @param id ID of the mixing task
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes Before calling this method to get the progress of music file playback, you need to call [startAudioMixing](#startaudiomixing) to start playing music files.
     */
    getAudioMixingCurrentPosition(id) {
        if (utils_1.isNull(id)) {
            return utils_1.errorFeedback("getAudioMixingCurrentPosition");
        }
        return this.instance.getAudioMixingCurrentPosition(id);
    }
    /**
     * @brief Set the starting position of the audio file for audio mixing
     * @param id ID of the mixing task
     * @param pos The starting position in ms.
     *        You can get the length of the file with [getAudioMixingDuration](#getaudiomixingduration). The value of the position must be less than the length of the file.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes When mixing online files, calling this API may cause mixing delay.
     */
    setAudioMixingPosition(id, pos) {
        if (utils_1.isNull(id)) {
            return utils_1.errorFeedback("setAudioMixingPosition");
        }
        if (utils_1.isNull(pos)) {
            return utils_1.errorFeedback("setAudioMixingPosition");
        }
        return this.instance.setAudioMixingPosition(id, pos);
    }
    /**
     * @brief Set the channel mode of the current audio file
     * @param id ID of the mixing task
     * @param mode Channel mode. The default channel mode is the same as the source file.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes Before calling this method to set the channel mode of the audio file, you need to call [startAudioMixing](#startaudiomixing) to start playing the audio file.
     */
    setAudioMixingDualMonoMode(id, mode) {
        if (utils_1.isNull(id)) {
            return utils_1.errorFeedback("setAudioMixingDualMonoMode");
        }
        if (utils_1.isNull(mode)) {
            return utils_1.errorFeedback("setAudioMixingDualMonoMode");
        }
        return this.instance.setAudioMixingDualMonoMode(id, mode);
    }
    /**
     * @brief Enables local playback of music files in a different key, mostly used in Karaoke scenarios.  You can adjust the pitch of locally played music files such as ascending or descending with this method.
     * @param id ID of the mixing task
     * @param pitch The value that is higher or lower than the original pitch of the audio file within a range from -12 to 12. The default value is 0, i.e. No adjustment is made.
     *        The difference in pitch between two adjacent values within the value range is a semitone, with positive values indicating an ascending tone and negative values indicating a descending tone, and the larger the absolute value set, the more the pitch is raised or lowered.
     *        Out of the value range, the setting fails and triggers the `onAudioMixingStateChanged` callback, indicating `AUDIO_MIXING_STATE_FAILED` for playback failure with AudioMixingState, and `AUDIO_MIXING_ERROR_ID_TYPE_ INVALID_PITCH` for invalid value setting with AudioMixingError.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes This method needs to be used after calling [startAudioMixing](#startaudiomixing) to start playing the audio file and before calling [`stopAudioMixing`](#stopaudiomixing) to stop playing the audio file, otherwise the `onAudioMixingStateChanged` callback will be triggered.
     */
    setAudioMixingPitch(id, pitch) {
        if (utils_1.isNull(id)) {
            return utils_1.errorFeedback("setAudioMixingPitch");
        }
        if (utils_1.isNull(pitch)) {
            return utils_1.errorFeedback("setAudioMixingPitch");
        }
        return this.instance.setAudioMixingPitch(id, pitch);
    }
    /**
     * @brief Sets the playback speed of the current audio file.
     * @param id Audio mixing task ID
     * @param speed
     * @returns + 0: Success
     * + < 0: Failure.Ratio of playback speed to original speed in percentage. The range is [50,200], the default value is 100.
     *        If the value you set is out of range, the setting fails, and you will receive an `onAudioMixingStateChanged` callback, in which the AudioMixingState is `kAudioMixingStateFailed` and the AudioMixingError is `kAudioMixingErrorInValidPlaybackSpeed`.
     * @notes + You should call this API after calling [startAudioMixing](#startaudiomixing) and receiving an `onAudioMixingStateChanged` callback indicating that the AudioMixingState is `kAudioMixingStatePlaying` and the AudioMixingError is `kAudioMixingErrorOk`.
     * + If you call this API after calling [stopAudioMixing](#stopaudiomixing) or [unloadAudioMixing](#unloadaudiomixing), you will receive an `onAudioMixingStateChanged` callback indicating that the AudioMixingState is `kAudioMixingStateFailed` and the AudioMixingError is `kAudioMixingErrorIdNotFound`.
     */
    setAudioMixingPlaybackSpeed(id, speed) {
        if (utils_1.isNull(id)) {
            return utils_1.errorFeedback("setAudioMixingPlaybackSpeed");
        }
        if (utils_1.isNull(speed)) {
            return utils_1.errorFeedback("setAudioMixingPlaybackSpeed");
        }
        return this.instance.setAudioMixingPlaybackSpeed(id, speed);
    }
    /**
     * @brief If you need to call `enableVocalInstrumentBalance` to adjust the volume of the audio file or PCM data used for audio mixing, you must import the original loudness value of the audio file or PCM data via this API.
     * @param id Audio ID of the mixing task
     * @param loudness Original loudness of the audio file in lufs. The range is [-70.0, 0.0].
     *        If the value is set to be less than -70.0lufs, it is automatically adjusted to -70.0lufs. If the value is set to be greater than 0.0lufs, SDK will not equalize the loudness. The default value is 1.0lufs, i.e. No loudness equalization effect.
     * @notes To avoid sudden volume changes during audio file playback, we recommend that you call this API before starting to play the audio file with [startAudioMixing](#startaudiomixing).
     * @returns + 0: Success
     * + < 0: Failure.
     */
    setAudioMixingLoudness(id, loudness) {
        if (utils_1.isNull(id)) {
            return utils_1.errorFeedback("setAudioMixingLoudness");
        }
        if (utils_1.isNull(loudness)) {
            return utils_1.errorFeedback("setAudioMixingLoudness");
        }
        return this.instance.setAudioMixingLoudness(id, loudness);
    }
    /**
     * @brief Set the interval of audio file playback progress callbacks during audio mixing
     * @param id ID of the mixing task
     *        You can set the interval for multiple IDs by calling this method multiple times and passing in different IDs.
     * @param interval The time interval (ms) of the audio file playback progress callback in milliseconds.
     * + The value of interval is a multiple of 10 greater than 0. When the value set is not divisible by 10, the default is rounded up by 10. For example, if the value is set to 52ms, it will be automatically adjusted to 60ms, then the SDK will trigger `onAudioMixingPlayingProgress` callback at the set interval.
     * + If the value is less than or equals to 0, the callback will not be triggered.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes This method needs to be used after calling [startAudioMixing](#startaudiomixing) to start playing the audio file, and before calling [stopAudioMixing](#stopaudiomixing) to stop playing the audio file, otherwise an error callback `onAudioMixingStateChanged` will be triggered.
     *        If you want to set the interval of playback progress callbacks before the music file starts playing, you need to call [startAudioMixing](#startaudiomixing) to set the interval in AudioMixingConfig, and you can update the callback interval through this method after the audio file starts playing.
     */
    setAudioMixingProgressInterval(id, interval) {
        if (utils_1.isNull(id)) {
            return utils_1.errorFeedback("setAudioMixingProgressInterval");
        }
        if (utils_1.isNull(interval)) {
            return utils_1.errorFeedback("setAudioMixingProgressInterval");
        }
        return this.instance.setAudioMixingProgressInterval(id, interval);
    }
    /**
     * @brief Get the track index of the current audio file
     * @param id Mixding ID
     * @returns + >=0: Succeeded, the SDK will return the track index of the current audio file.
     * + < 0: Failed
     * @notes Before using this method, you should call [startAudioMixing](#startaudiomixing) to start playing the audio file.
     */
    getAudioTrackCount(id) {
        if (utils_1.isNull(id)) {
            return utils_1.errorFeedback("getAudioTrackCount");
        }
        return this.instance.getAudioTrackCount(id);
    }
    /**
     * @brief Specify the playback track of the current audio file
     * @param id ID of the mixing task
     * @param audio_track_index The specified playback track.
     *        The set parameter value needs to be less than or equal to the return value of [getAudioTrackCount](#getaudiotrackcount).
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes Before using this method, you should call [startAudioMixing](#startaudiomixing) to start playing the audio file.
     */
    selectAudioTrack(id, audio_track_index) {
        if (utils_1.isNull(id)) {
            return utils_1.errorFeedback("selectAudioTrack");
        }
        if (utils_1.isNull(audio_track_index)) {
            return utils_1.errorFeedback("selectAudioTrack");
        }
        return this.instance.selectAudioTrack(id, audio_track_index);
    }
    /**
     * @brief Change local voice to a different key, mostly used in Karaoke scenarios.  You can adjust the pitch of local voice such as ascending or descending with this method.
     * @param pitch The value that is higher or lower than the original local voice within a range from -12 to 12. The default value is 0, Unchanged.
     *        The difference in pitch between two adjacent values within the value range is a semitone, with positive values indicating an ascending tone and negative values indicating a descending tone, and the larger the absolute value set, the more the pitch is raised or lowered.
     *        Out of the value range, the setting fails and triggers [onWarning](85533#onwarning) callback, indicating `WARNING_CODE_SET_SCREEN_STREAM_INVALID_VOICE_PITCH` for invalid value setting with WarningCode.
     * @returns + 0: Success
     * + < 0: Failure.
     */
    setLocalVoicePitch(pitch) {
        if (utils_1.isNull(pitch)) {
            return utils_1.errorFeedback("setLocalVoicePitch");
        }
        return this.instance.setLocalVoicePitch(pitch);
    }
    /**
     * @brief Enables automatic speech recognition service.
     * @param asr_config Check information.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes This method converts the recognized user's voice into text and calls it back to the user through the [onMessage](85533#onmessage) Event.
     */
    startASR(asr_config) {
        if (utils_1.isNull(asr_config) ||
            !asr_config.app_id ||
            !asr_config.user_id ||
            !asr_config.access_token ||
            !asr_config.secret_key) {
            return utils_1.errorFeedback("startASR");
        }
        const tempAsrConfig = {
            cluster: "",
        };
        return this.instance.startASR({
            ...tempAsrConfig,
            ...asr_config,
        });
    }
    /**
     * @brief  Turn off speech recognition service
     * @returns + 0: Success
     * + < 0: Failure.
     */
    stopASR() {
        return this.instance.stopASR();
    }
    /**
     * @brief This method records the audio & video data during the call to a local file.
     * @param type Stream attribute, specify whether to record mainstream or screen stream.
     * @param config Local recording parameter configuration.
     * @param recording_type Recording stored file format
     * @returns + 0: normal
     * + -1: Parameter setting exception
     * + -2: The current version of the SDK does not support this Feature, please contact technical support staff
     * @notes + After calling this method, you will receive an [onRecordingStateUpdate](85533#onrecordingstateupdate) callback.
     * + If the recording is normal, the system will notify the recording progress through [onRecordingProgressUpdate](85533#onrecordingprogressupdate) callback every second.
     */
    startFileRecording(type, config, recording_type) {
        if (utils_1.isNull(type) ||
            utils_1.isNull(config) ||
            utils_1.isNull(config.dir_path) ||
            utils_1.isNull(config.file_type) ||
            utils_1.isNull(recording_type)) {
            return utils_1.errorFeedback("startFileRecording");
        }
        console.log("startFileRecording in ts: ", type, config, recording_type);
        console.log("startFileRecording in ts: ", typeof type, typeof config, typeof recording_type);
        return this.instance.startFileRecording(type, config, recording_type);
    }
    /**
     * @brief Stop local recording
     * @param type Stream attribute, specify to stop mainstream or screen stream recording.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + Call [startFileRecording](#startfilerecording) After starting local recording, you must call this method to stop recording.
     * + After calling this method, you will receive an [onRecordingStateUpdate](85533#onrecordingstateupdate) callback prompting you to record the result.
     */
    stopFileRecording(type) {
        if (utils_1.isNull(type)) {
            return utils_1.errorFeedback("stopFileRecording");
        }
        return this.instance.stopFileRecording(type);
    }
    /**
     * @brief Sets the fallback option for published audio & video streams. You can call this API to set whether to automatically lower the resolution you set of the published streams under limited network conditions.
     * @param option Fallback option
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + This API only works after you call [enableSimulcastMode](#enablesimulcastmode) to enable the mode of publishing multiple streams.
     * + You must call this API before entering the room.
     * + After you allow video stream to fallback, your stream subscribers will receive [onSimulcastSubscribeFallback](85533#onsimulcastsubscribefallback) when the resolution of your published stream are lowered or restored.
     * + You can alternatively set fallback options with distrubutions from server side, which is of higher priority.
     */
    setPublishFallbackOption(option) {
        if (utils_1.isNull(option)) {
            return utils_1.errorFeedback("setPublishFallbackOption");
        }
        return this.instance.setPublishFallbackOption(option);
    }
    /**
     * @brief Sets the fallback option for subscribed RTC streams.   You can call this API to set whether to lower the resolution of currently subscribed stream under limited network conditions.
     * @param option Fallback option
     * @returns + 0: Success
     * + < 0: Failure.
     *  @notes + You must call this API before enterting the room.
     * + After you enables the fallback, you will receive [onSimulcastSubscribeFallback](85533#onsimulcastsubscribefallback) and [onRemoteVideoSizeChanged](85533#onremotevideosizechanged) when the resolution of your subscribed stream is lowered or restored.
     * + You can alternatively set fallback options with distrubutions from server side, which is of higher priority.
     */
    setSubscribeFallbackOption(option) {
        if (utils_1.isNull(option)) {
            return utils_1.errorFeedback("setSubscribeFallbackOption");
        }
        return this.instance.setSubscribeFallbackOption(option);
    }
    /**
     * @brief  Set user priority
     * @param room_id 房间 ID
     * @param user_id Remote user's ID
     * @param priority Remote user's requirement priority.
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + 1. This method is used with [setSubscribeFallbackOption](#setsubscribefallbackoption).
     * + 2. If the subscription flow fallback option is turned on, weak connections or insufficient performance will give priority to ensuring the quality of the flow received by high-priority users.
     * + 3. This method can be used before and after entering the room, and the priority of the remote user can be modified.
     */
    setRemoteUserPriority(room_id, user_id, priority) {
        if (utils_1.isNull(room_id) || utils_1.isNull(user_id) || utils_1.isNull(priority)) {
            return utils_1.errorFeedback("setRemoteUserPriority");
        }
        return this.instance.setRemoteUserPriority(room_id, user_id, priority);
    }
    /**
     * @brief Pre-call network detection
     * @param is_test_uplink Whether to detect uplink bandwidth
     * @param expected_uplink_bitrate Expected uplink bandwidth, unit: kbpsRange: {0, [100-10000]}, `0`: Auto, that RTC will set the highest bite rate.
     * @param is_test_downlink Whether to detect downlink bandwidth
     * @param expected_downlink_biterate Expected downlink bandwidth, unit: kbpsRange: {0, [100-10000]}, `0`: Auto, that RTC will set the highest bite rate.
     * @returns + 0: Network probing enabled successfully.
     * + 1: Failed to start probing. Parameter error, both uplink and downlink probes are 'false ', or the expected bandwidth exceeds the range [100,10000]
     * + 2: Failed to start probing. The reason for the failure is that the local push-pull flow has started.
     * + 3: Detection has started, no need to open it again.
     * + 4: Do not support this feature.
     * @notes + After calling this interface, you will receive [onNetworkDetectionResult](85533#onnetworkdetectionresult) within 3s and every 2s thereafter notifying the probe result;
     * + If the probe stops, you will receive [onNetworkDetectionStopped](85533#onnetworkdetectionstopped) notify that probing has stopped.
     */
    startNetworkDetection(is_test_uplink, expected_uplink_bitrate, is_test_downlink, expected_downlink_biterate) {
        return this.instance.startNetworkDetection(is_test_uplink, expected_uplink_bitrate, is_test_downlink, expected_downlink_biterate);
    }
    /**
     * @brief Stop pre-call network probe
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes After calling this interface, you will receive [onNetworkDetectionStopped](85533#onnetworkdetectionstopped) notifying that the the probing has stopped.
     */
    stopNetworkDetection() {
        return this.instance.stopNetworkDetection();
    }
    /////////////////////////////////////////////////////////////////////////////////////////////////
    /////////////////////////////////////////////////////////////////////////////////////////////////
    /////////////////////////////////////////////////////////////////////////////////////////////////
    /////////////////////////////////////////////////////////////////////////////////////////////////
    /////////////////////////////////////////////////////////////////////////////////////////////////
    /////////////////////////////////////////////////////////////////////////////////////////////////
    /**
     * @brief  Remove the background
     * @returns + 0: Success
     * + < 0: Failure.
     */
    disableBackground() {
        return this.instance.disableBackground();
    }
    /**
     * @brief Set the original background to a specified image or a solid color. To disable this effect, set the modelPath parameter to null.
     * @param model_path Set the path of virtual background effects.
     * @param source Set the local path of background images.
     * @returns + 0: Success
     * + 1000：The BytePlus Effects SDK is not integrated.
     * + 1001：This feature is not supported in the BytePlus Effects SDK.
     * + < 0：Other errors. See [error codes](https://www.volcengine.com/docs/5889/61813).
     * @notes Before calling this method, you should call [checkLicense](#checklicense), [setAlgoModelPath](#setaigomodelpath), and [enableEffect](#enableeffect) in order.
     */
    setBackgroundSticker(model_path, source) {
        if (utils_1.isNull(source.source_path)) {
            source.source_path = "";
        }
        if (utils_1.isNull(model_path)) {
            model_path = "";
        }
        return this.instance.setBackgroundSticker(model_path, source);
    }
    /**
     * @brief Adds watermark to designated video stream.
     * @param stream_index The index of the target stream.
     * @param image_path File path of the watermark image. You can use the absolute path or the asset path(/assets/xx.png). The path should be less than 512 bytes.
     *        The watermark image should be in PNG or JPG format.
     * @param config Watermark configurations
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes + Call [clearVideoWatermark](#clearvideowatermark) to remove the watermark from the designated video stream.
     * + You can only add one watermark to one video stream. The newly added watermark replaces the previous one. You can call this API multiple times to add watermarks to different streams.
     * + If you mirror the preview, or the preview and the published stream, the watermark will also be mirrored locally, but the published watermark will not be mirrored.
     * + When you enable simulcast mode, the watermark will be added to all video streams, and it will be scaled down to smaller encoding configurations accordingly.
     */
    setVideoWatermark(stream_index, image_path, config) {
        if (utils_1.isNull(image_path) || utils_1.isNull(config)) {
            return utils_1.errorFeedback("setVideoWatermark");
        }
        return this.instance.setVideoWatermark(stream_index, image_path, config);
    }
    /**
     * @brief Removes video watermark from designated video stream.
     * @param stream_index Targeting stream index of the watermark.
     * @return + 0: Succeed.
     * + 1000: Integrating CV SDK failed.
     * + 1001: Invalid SDK version
     * + <0: Failed.
     */
    clearVideoWatermark(stream_index) {
        return this.instance.clearVideoWatermark(stream_index);
    }
    //////////////////////////////////////////////
    // JS Render Frame
    /**
     * @brief Set the view for the local video.
     * @param view View
     * @param room_id Room ID
     * @param render_options Render options
     * @returns + 0: Success
     * + < 0: Failure.
     */
    setupLocalVideo(view, room_id, render_options = {
        render_mode: types_1.RenderMode.FIT,
        mirror: false,
    }) {
        var _a;
        let ret = -1;
        do {
            if (!view) {
                logger.warn("setupLocalVideo, view is null");
                break;
            }
            if (room_id) {
                let user = (_a = data_1.default.get(room_id)) === null || _a === void 0 ? void 0 : _a.localUser;
                if (user) {
                    user.renderOptions = render_options;
                    if (user.videoRender) {
                        user.videoRender.destroy();
                    }
                    user.videoRender = new yuv_render_1.YUVRender(view, render_options.render_mode, render_options.mirror);
                }
            }
            else {
                //预览
                let user = this.previewUser;
                user.renderOptions = render_options;
                if (user.videoRender) {
                    user.videoRender.destroy();
                }
                user.videoRender = new yuv_render_1.YUVRender(view, render_options.render_mode, render_options.mirror);
            }
            ret = 0;
        } while (false);
        return ret;
    }
    /**
     * @brief Unbind the local video from the view.
     * @param room_id Room ID
     * @returns + 0: Success
     * + < 0: Failure.
     */
    removeLocalVideo(room_id) {
        var _a;
        if (room_id) {
            let user = (_a = data_1.default.get(room_id)) === null || _a === void 0 ? void 0 : _a.localUser;
            if (user && user.videoRender) {
                user.videoRender.destroy();
                user.videoRender = null;
            }
        }
        else {
            let user = this.previewUser;
            if (user && user.videoRender) {
                user.videoRender.destroy();
                user.videoRender = null;
            }
        }
        return 0;
    }
    /**
     * @brief Set the view for the remote video.
     * @param user_id User ID
     * @param room_id Room ID
     * @param view View
     * @param render_options Render options
     * @returns + 0: Success
     * + < 0: Failure.
     */
    setupRemoteVideo(user_id, room_id, view, render_options = {
        render_mode: types_1.RenderMode.FIT,
        mirror: false,
    }) {
        if (utils_1.isNull(user_id) || utils_1.isNull(room_id) || !view) {
            return utils_1.errorFeedback("setupRemoteVideo");
        }
        let ret = -1;
        do {
            if (!view) {
                logger.warn("SetupRemoteVideo, view is null");
                break;
            }
            let user = this.findUser(user_id, room_id);
            if (user) {
                if (user.videoRender) {
                    user.videoRender.destroy();
                }
                user.videoRender = new yuv_render_1.YUVRender(view, render_options.render_mode, render_options.mirror);
            }
            ret = 0;
        } while (false);
        return ret;
    }
    /**
     * @brief Unbind the remote video from the view
     * @param user_id User ID
     * @param room_id Room ID
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes Call this API after stopping receiving the remote video.
     */
    removeRemoteVideo(user_id, room_id) {
        if (utils_1.isNull(user_id) || utils_1.isNull(room_id)) {
            return utils_1.errorFeedback("removeRemoteVideo");
        }
        let user = this.findUser(user_id, room_id);
        if (user && user.videoRender) {
            user.videoRender.destroy();
            user.videoRender = null;
        }
        return 0;
    }
    /**
     * @brief Unbind all remote videos from the views
     * @param room_id Room ID
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes Call this API after stopping receiving the remote video.
     */
    removeAllRemoteVideo(room_id) {
        var _a, _b;
        if (utils_1.isNull(room_id)) {
            return utils_1.errorFeedback("removeAllRemoteVideo");
        }
        (_b = (_a = data_1.default
            .get(room_id)) === null || _a === void 0 ? void 0 : _a.remoteUsers) === null || _b === void 0 ? void 0 : _b.forEach((user) => {
            if (user && user.videoRender) {
                user.videoRender.destroy();
                user.videoRender = null;
            }
        });
        return 0;
    }
    /**
     * @brief Set the view for the local screening sharing stream
     * @param view View
     * @param room_id Room ID
     * @param render_options
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes Call this API before starting screen sharing.
     */
    setupLocalScreen(view, room_id, render_options = {
        render_mode: types_1.RenderMode.FIT,
        mirror: false,
    }) {
        var _a;
        if (!view || utils_1.isNull(room_id)) {
            return utils_1.errorFeedback("setupLocalScreen");
        }
        let ret = -1;
        do {
            if (!view) {
                logger.warn("SetupLocalScreen, view is null");
                break;
            }
            let user = (_a = data_1.default.get(room_id)) === null || _a === void 0 ? void 0 : _a.localUser;
            if (user) {
                if (user.screenRender) {
                    user.screenRender.destroy();
                }
                user.screenRender = new yuv_render_1.YUVRender(view, render_options.render_mode, render_options.mirror);
            }
            ret = 0;
        } while (false);
        return ret;
    }
    /**
     * @brief Unbind the screen sharing stream from the view
     * @param room_id Room ID
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes Call this API after stopping screen sharing.
     */
    removeLocalScreen(roomId) {
        var _a;
        if (utils_1.isNull(roomId)) {
            return utils_1.errorFeedback("removeLocalScreen");
        }
        let user = (_a = data_1.default.get(roomId)) === null || _a === void 0 ? void 0 : _a.localUser;
        if (user && user.screenRender) {
            user.screenRender.destroy();
            user.screenRender = null;
        }
        return 0;
    }
    /**
     * @brief Set the view for the remote screening sharing stream
     * @param user_id User ID
     * @param room_id Room ID
     * @param view View
     * @param render_options Render options
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes Call this API before receiving a remote screen sharing stream.
     */
    setupRemoteScreen(user_id, room_id, view, render_options = {
        render_mode: types_1.RenderMode.FIT,
        mirror: false,
    }) {
        if (utils_1.isNull(room_id) || utils_1.isNull(user_id) || !view) {
            return utils_1.errorFeedback("setupRemoteScreen");
        }
        let ret = -1;
        do {
            if (!view) {
                logger.warn("SetupRemoteScreen, view is null");
                break;
            }
            let user = this.findUser(user_id, room_id);
            if (user) {
                if (user.screenRender) {
                    user.screenRender.destroy();
                }
                user.screenRender = new yuv_render_1.YUVRender(view, render_options.render_mode, render_options.mirror);
            }
            ret = 0;
        } while (false);
        return ret;
    }
    /**
     * @brief Unbind the remote screen sharing stream from the view
     * @param user_id ID of the remote user
     * @param room_id Room ID
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes Call this API after stopping receiving screen sharing.
     */
    removeRemoteScreen(user_id, room_id) {
        if (utils_1.isNull(user_id) || utils_1.isNull(room_id)) {
            return utils_1.errorFeedback("removeRemoteScreen");
        }
        let user = this.findUser(user_id, room_id);
        if (user && user.screenRender) {
            user.screenRender.destroy();
            user.screenRender = null;
        }
        return 0;
    }
    /**
     * @brief Assign a internal render view to the public stream.
     * @param stream_id ID of the public stream
     * @param view Internal render view
     * @param renderOptions Options for rendering
     * @return
     *        + 0: Success<br>
     *        + !0: Failure<br>
     */
    setupPublicStreamVideo(stream_id, view, renderOptions = {
        render_mode: types_1.RenderMode.FIT,
        mirror: false,
    }) {
        if (!stream_id || !view) {
            return utils_1.errorFeedback("setupRemoteScreen");
        }
        let streamRender = this.publicStreamViews.get(stream_id);
        if (streamRender) {
            streamRender.destroy();
        }
        streamRender = new yuv_render_1.YUVRender(view, renderOptions.render_mode, renderOptions.mirror);
        this.publicStreamViews.set(stream_id, streamRender);
        return 0;
    }
    /**
     * @brief Unbind the public stream from the view
     * @param streamId ID of the public stream
     * @returns + 0: Success
     * + < 0: Failure.
     * @notes Call this API after stopping receiving public stream.
     */
    removePublicStreamVideo(streamId) {
        if (!streamId) {
            return utils_1.errorFeedback("removePublicStreamVideo");
        }
        let streamRender = this.publicStreamViews.get(streamId);
        if (streamRender) {
            streamRender.destroy();
            this.publicStreamViews.delete(streamId);
        }
        return 0;
    }
    ////////////////////////////////////////////////////////////////////////////////////////////////
    // RTCVIDEOCALLBACK
    /**
     * @private
     */
    onLocalVideoFrame(obj) {
        const { Object } = obj;
        if (this.previewUser.videoRender) {
            let frame = yuv_render_1.YUVRender.buildYUVFrame(Object);
            this.previewUser.videoRender.renderFrame(frame);
        }
        data_1.default.forEach((roomInfo) => {
            let user = roomInfo.localUser;
            if (user.videoRender) {
                let frame = yuv_render_1.YUVRender.buildYUVFrame(Object);
                user.videoRender.renderFrame(frame);
            }
        });
    }
    /**
     * @private
     */
    onLocalScreenFrame(obj) {
        const { Object } = obj;
        data_1.default.forEach((roomInfo) => {
            let user = roomInfo.localUser;
            if (user.screenRender) {
                let frame = yuv_render_1.YUVRender.buildYUVFrame(Object);
                user.screenRender.renderFrame(frame);
            }
        });
    }
    /**
     * @private
     */
    onRemoteVideoFrame(obj) {
        var _a, _b;
        const { Object } = obj;
        const userId = Object.user_id;
        const roomId = Object.channel_id;
        let user = (_a = data_1.default
            .get(roomId)) === null || _a === void 0 ? void 0 : _a.remoteUsers.get(userId);
        if ((_b = user) === null || _b === void 0 ? void 0 : _b.videoRender) {
            let frame = yuv_render_1.YUVRender.buildYUVFrame(Object);
            user.videoRender.renderFrame(frame);
        }
    }
    /**
     * @private
     */
    onPublicStreamVideoFrame(obj) {
        const { Object } = obj;
        const streamId = Object.public_stream_id;
        const streamRender = this.publicStreamViews.get(streamId);
        if (streamRender) {
            const frame = yuv_render_1.YUVRender.buildYUVFrame(Object);
            streamRender.renderFrame(frame);
        }
    }
    /**
     * @private
     */
    onRemoteScreenFrame(obj) {
        var _a, _b, _c;
        const { Object } = obj;
        const userId = Object.user_id;
        const roomId = Object.channel_id;
        let user = (_b = (_a = data_1.default
            .get(roomId)) === null || _a === void 0 ? void 0 : _a.remoteUsers) === null || _b === void 0 ? void 0 : _b.get(userId);
        if ((_c = user) === null || _c === void 0 ? void 0 : _c.screenRender) {
            let frame = yuv_render_1.YUVRender.buildYUVFrame(Object);
            user.screenRender.renderFrame(frame);
        }
    }
    /**
     * @private
     */
    clearLocalVideoCanvas(userId, roomId) {
        let user = this.findUser(userId, roomId);
        if (user && user.videoRender) {
            user.videoRender.clearFrame();
        }
    }
    /**
     * @private
     */
    clearLocalScreenCanvas(userId, roomId) {
        let user = this.findUser(userId, roomId);
        if (user && user.screenRender) {
            user.screenRender.clearFrame();
        }
    }
    /**
     * @private
     */
    clearRemoteVideoCanvas(userId, roomId) {
        var _a, _b;
        let user = (_b = (_a = data_1.default
            .get(roomId)) === null || _a === void 0 ? void 0 : _a.remoteUsers) === null || _b === void 0 ? void 0 : _b.get(userId);
        if (user && user.videoRender) {
            user.videoRender.clearFrame();
        }
    }
    /**
     * @private
     */
    clearAllRemoteVideoCanvas(roomId) {
        var _a;
        const remoteUsers = (_a = data_1.default.get(roomId)) === null || _a === void 0 ? void 0 : _a.remoteUsers;
        if (!remoteUsers) {
            return;
        }
        remoteUsers.forEach((user) => {
            if (user && user.videoRender) {
                user.videoRender.clearFrame();
            }
        });
    }
    /**
     * @private
     */
    clearRemoteScreenCanvas(userId, roomId) {
        var _a, _b;
        const remoteUsers = (_a = data_1.default.get(roomId)) === null || _a === void 0 ? void 0 : _a.remoteUsers;
        let user = (_b = remoteUsers) === null || _b === void 0 ? void 0 : _b.get(userId);
        if (user && user.screenRender) {
            user.screenRender.clearFrame();
        }
    }
    /**
     * @private
     */
    cbEngine(obj) {
        this.processRTCVIDEOCALLBACK(obj);
    }
    /**
     * @private
     */
    fire(event, ...args) {
        setImmediate(() => {
            this.emit(event, ...args);
        });
    }
    /**
     * @private
     */
    processRTCVIDEOCALLBACK(obj) {
        let type = obj.Type;
        let data = obj.Object;
        switch (type) {
            case "onLocalScreenFrame":
                {
                    this.convertYUVBuffer(obj);
                    this.onLocalScreenFrame(obj);
                    this.fire("onLocalScreenFrame", data);
                }
                break;
            case "onLocalVideoFrame":
                {
                    this.convertYUVBuffer(obj);
                    this.onLocalVideoFrame(obj);
                    this.fire("onLocalVideoFrame", data);
                }
                break;
            case "onRemoteScreenFrame":
                {
                    this.convertYUVBuffer(obj);
                    this.onRemoteScreenFrame(obj);
                    this.fire("onRemoteScreenFrame", data);
                }
                break;
            case "onRemoteVideoFrame":
                {
                    this.convertYUVBuffer(obj);
                    this.onRemoteVideoFrame(obj);
                    this.fire("onRemoteVideoFrame", data);
                }
                break;
            case "onPublicStreamVideoFrame":
                {
                    this.convertYUVBuffer(obj);
                    this.onPublicStreamVideoFrame(obj);
                    this.fire("onPublicStreamVideoFrame", data);
                }
                break;
            case "onPlayPublicStreamResult":
                {
                    const { public_stream_id, error_code } = data;
                    this.fire("onPlayPublicStreamResult", public_stream_id, error_code);
                }
                break;
            case "onPublicStreamSEIMessageReceived":
                {
                    const { public_stream_id, message } = data;
                    this.fire("onPublicStreamSEIMessageReceived", public_stream_id, message);
                }
                break;
            case "onFirstPublicStreamVideoFrameDecoded":
                {
                    const { room_id, public_stream_id, video_frame_info } = data;
                    this.fire("onFirstPublicStreamVideoFrameDecoded", room_id, public_stream_id, video_frame_info);
                }
                break;
            case "onPushPublicStreamResult":
                {
                    const { room_id, public_stream_id, error_code } = data;
                    this.fire("onPushPublicStreamResult", room_id, public_stream_id, error_code);
                }
                break;
            case "onFirstPublicStreamAudioFrame":
                {
                    const { public_stream_id } = data;
                    this.fire("onFirstPublicStreamAudioFrame", public_stream_id);
                }
                break;
            case "onWarning":
                {
                    const { code } = data;
                    this.fire("onWarning", code);
                }
                break;
            case "onError":
                {
                    const { error_code, error_message } = data;
                    this.fire("onError", error_code, error_message);
                }
                break;
            // case "onAudioMixingFinished":
            //   {
            //     this.fire("onAudioMixingFinished");
            //   }
            //   break;
            case "onAudioMixingStateChanged":
                {
                    this.fire("onAudioMixingStateChanged", data.mix_id, data.state, data.error);
                }
                break;
            case "onLogReport":
                {
                    this.fire("onLogReport", data.log_type, data.log_content);
                }
                break;
            case "onConnectionStateChanged":
                {
                    this.fire("onConnectionStateChanged", data.state);
                }
                break;
            case "onNetworkTypeChanged":
                {
                    this.fire("onNetworkTypeChanged", data.type);
                }
                break;
            case "onPerformanceAlarms":
                {
                    this.fire("onPerformanceAlarms", data.mode, data.room_id, data.reason, data.data);
                }
                break;
            case "onSysStats":
                {
                    let sysStats = data;
                    this.fire("onSysStats", sysStats);
                }
                break;
            case "onUserStartAudioCapture":
                {
                    this.fire("onUserStartAudioCapture", data.room_id, data.user_id);
                }
                break;
            case "onUserStopAudioCapture":
                {
                    this.fire("onUserStopAudioCapture", data.room_id, data.user_id);
                }
                break;
            case "onFirstLocalAudioFrame":
                {
                    this.fire("onFirstLocalAudioFrame", data.index);
                }
                break;
            case "onFirstRemoteAudioFrame":
                {
                    let remoteKey = data;
                    this.fire("onFirstRemoteAudioFrame", remoteKey);
                }
                break;
            case "onStreamRemove":
                {
                    this.fire("onStreamRemove", data.stream, data.reason);
                }
                break;
            case "onSimulcastSubscribeFallback":
                {
                    let streamSwitch = data;
                    this.fire("onSimulcastSubscribeFallback", streamSwitch);
                }
                break;
            case "onFirstLocalVideoFrameCaptured":
                {
                    let videoFrameInfo = data.info;
                    this.fire("onFirstLocalVideoFrameCaptured", data.index, videoFrameInfo);
                }
                break;
            case "onLocalVideoSizeChanged":
                {
                    let videoFrameInfo = data.info;
                    this.fire("onLocalVideoSizeChanged", data.index, videoFrameInfo);
                }
                break;
            case "onRemoteVideoSizeChanged":
                {
                    let videoFrameInfo = data.info;
                    this.fire("onRemoteVideoSizeChanged", data.key, videoFrameInfo);
                }
                break;
            case "onFirstRemoteVideoFrameRendered":
                {
                    let videoFrameInfo = data.info;
                    this.fire("onFirstRemoteVideoFrameRendered", data.key, videoFrameInfo);
                }
                break;
            case "onFirstRemoteVideoFrameDecoded":
                {
                    let videoFrameInfo = data.info;
                    this.fire("onFirstRemoteVideoFrameDecoded", data.key, videoFrameInfo);
                }
                break;
            case "onUserStartVideoCapture":
                {
                    this.fire("onUserStartVideoCapture", data.room_id, data.user_id);
                }
                break;
            case "onUserStopVideoCapture":
                {
                    this.fire("onUserStopVideoCapture", data.room_id, data.user_id);
                }
                break;
            case "onLocalAudioStateChanged":
                {
                    let state = data.state;
                    let error = data.error;
                    this.fire("onLocalAudioStateChanged", state, error);
                }
                break;
            case "onRemoteAudioStateChanged":
                {
                    let state = data.state;
                    let reason = data.reason;
                    this.fire("onRemoteAudioStateChanged", data.key, state, reason);
                }
                break;
            case "onLocalVideoStateChanged":
                {
                    let state = data.state;
                    let error = data.error;
                    this.fire("onLocalVideoStateChanged", data.streamIndex, state, error);
                }
                break;
            case "onRemoteVideoStateChanged":
                {
                    let state = data.state;
                    let reason = data.reason;
                    this.fire("onRemoteVideoStateChanged", data.key, state, reason);
                }
                break;
            case "onAudioFrameSendStateChanged":
                {
                    let user = data.user;
                    let state = data.state;
                    this.fire("onAudioFrameSendStateChanged", data.room_id, user, state);
                }
                break;
            case "onVideoFrameSendStateChanged":
                {
                    let user = data.user;
                    let state = data.state;
                    this.fire("onVideoFrameSendStateChanged", data.room_id, user, state);
                }
                break;
            case "onScreenVideoFrameSendStateChanged":
                {
                    let user = data.user;
                    let state = data.state;
                    this.fire("onScreenVideoFrameSendStateChanged", data.room_id, user, state);
                }
                break;
            case "onAudioFramePlayStateChanged":
                {
                    let user = data.user;
                    let state = data.state;
                    this.fire("onAudioFramePlayStateChanged", data.room_id, user, state);
                }
                break;
            case "onVideoFramePlayStateChanged":
                {
                    let user = data.user;
                    let state = data.state;
                    this.fire("onVideoFramePlayStateChanged", data.room_id, user, state);
                }
                break;
            case "onScreenVideoFramePlayStateChanged":
                {
                    let user = data.user;
                    let state = data.state;
                    this.fire("onScreenVideoFramePlayStateChanged", data.room_id, user, state);
                }
                break;
            // message
            case "onSEIMessageReceived":
                {
                    let streamKey = data.stream_key;
                    this.fire("onSEIMessageReceived", streamKey, data.message);
                }
                break;
            case "onStreamMixingEvent":
                {
                    this.fire("onStreamMixingEvent", data.event, data.task_id, data.error, data.mix_type);
                }
                break;
            case "onRecordingStateUpdate":
                {
                    let type = data.type;
                    let info = data.info;
                    this.fire("onRecordingStateUpdate", type, data.state, data.error_code, info);
                }
                break;
            case "onRecordingProgressUpdate":
                {
                    let type = data.type;
                    let process = data.process;
                    let info = data.info;
                    this.fire("onRecordingProgressUpdate", type, process, info);
                }
                break;
            case "onRecordAudioFrame":
                {
                    let audioFrame = data.audio_frame;
                    this.fire("onRecordAudioFrame", audioFrame);
                }
                break;
            case "onPlaybackAudioFrame":
                {
                    let audioFrame = data.audio_frame;
                    this.fire("onPlaybackAudioFrame", audioFrame);
                }
                break;
            case "onMixedAudioFrame":
                {
                    let audioFrame = data.audio_frame;
                    this.fire("onMixedAudioFrame", audioFrame);
                }
                break;
            case "onLoginResult":
                {
                    this.fire("onLoginResult", data.uid, data.error_code, data.elapsed);
                }
                break;
            case "onLogout":
                {
                    this.fire("onLogout");
                }
                break;
            case "onServerParamsSetResult":
                {
                    this.fire("onServerParamsSetResult", data.error);
                }
                break;
            case "onGetPeerOnlineStatus":
                {
                    this.fire("onGetPeerOnlineStatus", data.peer_user_id, data.status);
                }
                break;
            case "onUserMessageReceivedOutsideRoom":
                {
                    this.fire("onUserMessageReceivedOutsideRoom", data.uid, data.message);
                }
                break;
            case "onUserBinaryMessageReceivedOutsideRoom":
                {
                    this.fire("onUserBinaryMessageReceivedOutsideRoom", data.uid, data.message);
                }
                break;
            case "onUserMessageSendResultOutsideRoom":
                {
                    this.fire("onUserMessageSendResultOutsideRoom", data.msgid, data.error);
                }
                break;
            case "onAudioMixingPlayingProgress":
                {
                    this.fire("onAudioMixingPlayingProgress", data.mix_id, data.progress);
                }
                break;
            case "onServerMessageSendResult":
                {
                    this.fire("onServerMessageSendResult", data.msgid, data.error, data.message);
                }
                break;
            case "onASRSuccess":
                {
                    this.fire("onASRSuccess");
                }
                break;
            case "onMessage":
                {
                    this.fire("onMessage", data.message);
                }
                break;
            case "onASRError":
                {
                    this.fire("onASRError", data.errorCode, data.errorMessage);
                }
                break;
            case "onNetworkDetectionResult":
                {
                    this.fire("onNetworkDetectionResult", data.type, data.quality, data.rtt, data.lost_rate, data.bit_rate, data.jitter);
                }
                break;
            case "onNetworkDetectionStopped":
                {
                    this.fire("onNetworkDetectionStopped", data.reason);
                }
                break;
            case "onLocalAudioPropertiesReport":
                {
                    let AudioPropertiesInfo = data.audio_properties_infos;
                    this.fire("onLocalAudioPropertiesReport", AudioPropertiesInfo, data.audio_properties_info_number);
                }
                break;
            case "onRemoteAudioPropertiesReport":
                {
                    let AudioPropertiesInfo = data.audio_properties_infos;
                    this.fire("onRemoteAudioPropertiesReport", AudioPropertiesInfo, data.audio_properties_info_number, data.total_remote_volume);
                }
                break;
            case "onEchoTestResult":
                {
                    this.fire("onEchoTestResult", data.result);
                }
                break;
            case "onVideoDeviceStateChanged":
                {
                    this.fire("onVideoDeviceStateChanged", data.device_id, data.device_type, data.device_state, data.device_error);
                }
                break;
            case "onAudioDeviceStateChanged":
                {
                    this.fire("onAudioDeviceStateChanged", data.device_id, data.device_type, data.device_state, data.device_error);
                }
                break;
            case "onAudioPlaybackDeviceTestVolume":
                {
                    this.fire("onAudioPlaybackDeviceTestVolume", data.volume);
                }
                break;
            case "onActiveSpeaker":
                {
                    this.fire("onActiveSpeaker", data.room_id, data.uid);
                }
                break;
            case "onStreamPushEvent":
                {
                    this.fire("onStreamPushEvent", data.event, data.task_id, data.error);
                }
                break;
            default:
                {
                }
                break;
        }
    }
    /**
     * @private
     */
    convertYUVBuffer(obj) {
        const bufferY = Buffer.from(obj.Object.plane_y);
        const bufferU = Buffer.from(obj.Object.plane_u);
        const bufferV = Buffer.from(obj.Object.plane_v);
        obj.Object.plane_y = null;
        obj.Object.plane_u = null;
        obj.Object.plane_v = null;
        obj.Object.plane_y = bufferY;
        obj.Object.plane_u = bufferU;
        obj.Object.plane_v = bufferV;
    }
    /**
     * @private
     */
    findUser(userId, roomId) {
        var _a, _b, _c, _d;
        let ret = undefined;
        const localUser = (_a = data_1.default.get(roomId)) === null || _a === void 0 ? void 0 : _a.localUser;
        const remoteUsers = (_b = data_1.default.get(roomId)) === null || _b === void 0 ? void 0 : _b.remoteUsers;
        if (userId === ((_c = localUser) === null || _c === void 0 ? void 0 : _c.userId)) {
            ret = localUser;
        }
        else {
            ret = (_d = remoteUsers) === null || _d === void 0 ? void 0 : _d.get(userId);
        }
        return ret;
    }
}
__decorate([
    checkInit
], veRTCVideo.prototype, "destroyRTCVideo", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "feedback", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "getErrorDescription", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setBusinessId", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setRuntimeParameters", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "startAudioCapture", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "enumerateAudioPlaybackDevices", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "enumerateAudioCaptureDevices", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setAudioPlaybackDevice", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setAudioCaptureDevice", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "getAudioPlaybackDevice", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "getAudioCaptureDevice", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setAudioPlaybackDeviceVolume", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "getAudioPlaybackDeviceVolume", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setAudioCaptureDeviceVolume", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "getAudioCaptureDeviceVolume", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setAudioPlaybackDeviceMute", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "getAudioPlaybackDeviceMute", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setAudioCaptureDeviceMute", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "getAudioCaptureDeviceMute", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setCaptureVolume", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setPlaybackVolume", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setRemoteAudioPlaybackVolume", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "muteAudioPlayback", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "stopAudioPlaybackDeviceTest", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setAudioProfile", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "startAudioPlaybackDeviceTest", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "startEchoTest", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "stopEchoTest", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "initAudioPlaybackDeviceForTest", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "initAudioCaptureDeviceForTest", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "enableAudioPropertiesReport", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "enableVocalInstrumentBalance", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "startVideoCapture", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "stopVideoCapture", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "enumerateVideoCaptureDevices", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "followSystemPlaybackDevice", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "followSystemCaptureDevice", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setVideoCaptureDevice", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "getVideoCaptureDevice", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setMaxVideoEncoderConfig", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setLocalVideoMirrorType", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "enableSimulcastMode", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "checkLicense", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "getAuthMessage", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "enableEffect", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "enableEffectBeauty", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setAlgoModelPath", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setEffectNodes", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "updateNode", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setColorFilter", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setColorFilterIntensity", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "startScreenAudioCapture", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "startMacScreenAudioCapture", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "startScreenVideoCapture", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "stopScreenAudioCapture", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "stopScreenVideoCapture", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "updateScreenCaptureRegion", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "updateScreenCaptureHighlightConfig", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "updateScreenCaptureMouseCursor", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "updateScreenCaptureFilterConfig", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "getScreenCaptureSourceList", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "getThumbnail", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "getWindowAppIcon", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setScreenAudioStreamIndex", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setScreenVideoEncoderConfig", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "login", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "logout", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "updateLoginToken", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setServerParams", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "getPeerOnlineStatus", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "sendUserMessageOutsideRoom", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "sendUserBinaryMessageOutsideRoom", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "sendServerMessage", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "sendServerBinaryMessage", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "sendSEIMessage", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setVideoCaptureConfig", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "startAudioMixing", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "stopAudioMixing", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "pauseAudioMixing", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "resumeAudioMixing", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setAudioMixingVolume", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "getAudioMixingDuration", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "getAudioMixingCurrentPosition", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setAudioMixingPosition", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setAudioMixingDualMonoMode", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setAudioMixingPitch", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setAudioMixingPlaybackSpeed", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setAudioMixingLoudness", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setAudioMixingProgressInterval", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "getAudioTrackCount", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "selectAudioTrack", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setLocalVoicePitch", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setPublishFallbackOption", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setRemoteUserPriority", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "startNetworkDetection", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "stopNetworkDetection", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "disableBackground", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setupLocalVideo", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "removeLocalVideo", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setupRemoteVideo", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "removeRemoteVideo", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "removeAllRemoteVideo", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setupLocalScreen", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "removeLocalScreen", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setupRemoteScreen", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "removeRemoteScreen", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "setupPublicStreamVideo", null);
__decorate([
    checkInit
], veRTCVideo.prototype, "removePublicStreamVideo", null);
///////////////////////////////////////////////////////////////////
exports.default = veRTCVideo;
//# sourceMappingURL=video.js.map