"use strict";
/*
 * Copyright 2022 BytePlus Pte. Ltd.
 * SPDX-License-Identifier: MIT
 */
Object.defineProperty(exports, "__esModule", { value: true });
//////////////////////////////////////////////////////////////////////////
// VRTCEngine here
/**
 * @brief Video rendering scale mode
 */
var RenderMode;
(function (RenderMode) {
    /**
     * @brief Fit.
     *        The video frame is scaled with fixed aspect ratio, until it fits just within the canvas. Other part of the canvas is filled with the background color.
     */
    RenderMode[RenderMode["FIT"] = 1] = "FIT";
    /**
     * @brief Fill and Crop.
     *        The video frame is scaled with fixed aspect ratio, until it completely fills the canvas. The region of the video exceeding the canvas will be cropped.
     */
    RenderMode[RenderMode["HIDDEN"] = 2] = "HIDDEN";
})(RenderMode = exports.RenderMode || (exports.RenderMode = {}));
/**
 * @brief Subscription status of media streams
 */
var SubscribeState;
(function (SubscribeState) {
    /**
     * @brief Successfully changed the subscription status
     */
    SubscribeState[SubscribeState["kSubscribeStateSuccess"] = 0] = "kSubscribeStateSuccess";
    /**
     * @brief Failed to change the subscription status, because you were not in the room.
     */
    SubscribeState[SubscribeState["kSubscribeStateFailedNotInRoom"] = 1] = "kSubscribeStateFailedNotInRoom";
    /**
     * @brief Failed to change the subscription status, because the target audio/video stream was not found.
     */
    SubscribeState[SubscribeState["kSubscribeStateFailedStreamNotFound"] = 2] = "kSubscribeStateFailedStreamNotFound";
    /**
     * @brief Failed to change the subscription status, because the number of streams you have subscribed to has exceeded the limit.
     */
    SubscribeState[SubscribeState["kSubscribeStateFailedOverLimit"] = 3] = "kSubscribeStateFailedOverLimit";
})(SubscribeState = exports.SubscribeState || (exports.SubscribeState = {}));
/**
 * @brief  Video frame scale mode
 */
var ScaleMode;
(function (ScaleMode) {
    /**
     * @brief Auto mode, default to FitWithCropping.
     */
    ScaleMode[ScaleMode["Auto"] = 0] = "Auto";
    /**
     * @brief Stretch the video frame until the video frame and the window have the same resolution. The video frame's aspect ratio can be changed as it is automatically stretched to fill the window, but the whole image is visible.
     */
    ScaleMode[ScaleMode["Stretch"] = 1] = "Stretch";
    /**
     * @brief  Fit the window with cropping
     *         Scale the video frame uniformly until the window is filled. If the video frame's aspect ratio is different from that of the window, the extra part of the video frame will be cropped.
     *         After the scaling process is completed, the width or height of the video frame will be consistent with that of the window, and the other dimension will be greater than or equal to that of the window.
     */
    ScaleMode[ScaleMode["FitWithCropping"] = 2] = "FitWithCropping";
    /**
     * @brief  Fit the window with filling
     *         Scale the video frame uniformly until its width or height reaches the boundary of the window. If the video frame's aspect ratio is different from that of the window, the area that is not filled will be black.
     *         After the scaling process is completed, the width or height of the video frame will be consistent with that of the window, and the other dimension will be less than or equal to that of the window.
     */
    ScaleMode[ScaleMode["FitWithFilling"] = 3] = "FitWithFilling";
})(ScaleMode = exports.ScaleMode || (exports.ScaleMode = {}));
/**
 * @brief Video encoder type
 */
var VideoCodecType;
(function (VideoCodecType) {
    /**
     * @brief Unknown
     */
    VideoCodecType[VideoCodecType["kVideoCodecUnknown"] = 0] = "kVideoCodecUnknown";
    /**
     * @brief H264
     */
    VideoCodecType[VideoCodecType["kVideoCodecH264"] = 1] = "kVideoCodecH264";
    /**
     * @hidden
     * @brief
     */
    VideoCodecType[VideoCodecType["kVideoCodecByteVC1"] = 2] = "kVideoCodecByteVC1";
})(VideoCodecType = exports.VideoCodecType || (exports.VideoCodecType = {}));
/**
 * @brief  Video encoding mode
 */
var CodecMode;
(function (CodecMode) {
    /**
     * @brief Automatic
     */
    CodecMode[CodecMode["AutoMode"] = 0] = "AutoMode";
    /**
     * @brief Hardware encoding
     */
    CodecMode[CodecMode["HardwareMode"] = 1] = "HardwareMode";
    /**
     * @brief Software encoding
     */
    CodecMode[CodecMode["SoftwareMode"] = 2] = "SoftwareMode";
})(CodecMode = exports.CodecMode || (exports.CodecMode = {}));
/**
 * @brief Auto
 */
exports.SEND_KBPS_AUTO_CALCULATE = -1;
/**
 * @brief Disable
 */
exports.SEND_KBPS_DISABLE_VIDEO_SEND = 0;
/**
 * @brief Audio frame type
 */
var AudioFrameType;
(function (AudioFrameType) {
    /**
     * @brief PCM 16bit
     */
    AudioFrameType[AudioFrameType["kFrameTypePCM16"] = 0] = "kFrameTypePCM16";
})(AudioFrameType = exports.AudioFrameType || (exports.AudioFrameType = {}));
var AudioChannel;
(function (AudioChannel) {
    AudioChannel[AudioChannel["kAudioChannelAuto"] = -1] = "kAudioChannelAuto";
    AudioChannel[AudioChannel["kAudioChannelMono"] = 1] = "kAudioChannelMono";
    AudioChannel[AudioChannel["kAudioChannelStereo"] = 2] = "kAudioChannelStereo";
})(AudioChannel = exports.AudioChannel || (exports.AudioChannel = {}));
var AudioSampleRate;
(function (AudioSampleRate) {
    AudioSampleRate[AudioSampleRate["kAudioSampleRateAuto"] = -1] = "kAudioSampleRateAuto";
    AudioSampleRate[AudioSampleRate["kAudioSampleRate8000"] = 8000] = "kAudioSampleRate8000";
    AudioSampleRate[AudioSampleRate["kAudioSampleRate16000"] = 16000] = "kAudioSampleRate16000";
    AudioSampleRate[AudioSampleRate["kAudioSampleRate32000"] = 32000] = "kAudioSampleRate32000";
    AudioSampleRate[AudioSampleRate["kAudioSampleRate44100"] = 44100] = "kAudioSampleRate44100";
    AudioSampleRate[AudioSampleRate["kAudioSampleRate48000"] = 48000] = "kAudioSampleRate48000";
})(AudioSampleRate = exports.AudioSampleRate || (exports.AudioSampleRate = {}));
/**
 * @brief SDK  Connection status with the signaling server.
 */
var ConnectionState;
(function (ConnectionState) {
    /**
     * @brief Disconnected for 12s, SDK will try to reconnect automatically.
     */
    ConnectionState[ConnectionState["kConnectionStateDisconnected"] = 1] = "kConnectionStateDisconnected";
    /**
     * @brief The first request to connect to the server. Connecting.
     */
    ConnectionState[ConnectionState["kConnectionStateConnecting"] = 2] = "kConnectionStateConnecting";
    /**
     * @brief The first connection was successful.
     */
    ConnectionState[ConnectionState["kConnectionStateConnected"] = 3] = "kConnectionStateConnected";
    /**
     * @brief The code includes the following status:
     *        + The first connection is not successful for 10s.
     *        + The connection has been lost for 10s. Auto reconnecting.
     */
    ConnectionState[ConnectionState["kConnectionStateReconnecting"] = 4] = "kConnectionStateReconnecting";
    /**
     * @brief Successful reconnection after disconnection.
     */
    ConnectionState[ConnectionState["kConnectionStateReconnected"] = 5] = "kConnectionStateReconnected";
    /**
     * @brief In status `kConnectionStateDisconnected` for more than 10s without a successful reconnection. SDK will still continue to try to reconnect.
     */
    ConnectionState[ConnectionState["kConnectionStateLost"] = 6] = "kConnectionStateLost";
})(ConnectionState = exports.ConnectionState || (exports.ConnectionState = {}));
/**
 * @brief Reason to leave the room
 */
var UserOfflineReasonType;
(function (UserOfflineReasonType) {
    /**
     * @brief The remote client calls [leaveRoom](85532#leaveroom) to leave the room.
     */
    UserOfflineReasonType[UserOfflineReasonType["kUserOfflineReasonQuit"] = 0] = "kUserOfflineReasonQuit";
    /**
     * @brief The remote client is disconnected because of poor network connection or expired Token.
     */
    UserOfflineReasonType[UserOfflineReasonType["kUserOfflineReasonDropped"] = 1] = "kUserOfflineReasonDropped";
    /**
     * @brief The remote client calls [setUserVisibility](#rtcroom#setuservisibility) to turn invisible.
     */
    UserOfflineReasonType[UserOfflineReasonType["kUserOfflineReasonSwitchToInvisible"] = 2] = "kUserOfflineReasonSwitchToInvisible";
    /**
     * @brief The remote user has been removed from the room by the administrator via a OpenAPI call.
     */
    UserOfflineReasonType[UserOfflineReasonType["kUserOfflineReasonKickedByAdmin"] = 3] = "kUserOfflineReasonKickedByAdmin";
})(UserOfflineReasonType = exports.UserOfflineReasonType || (exports.UserOfflineReasonType = {}));
var MediaDeviceType;
(function (MediaDeviceType) {
    MediaDeviceType[MediaDeviceType["kMediaDeviceTypeAudioRenderDevice"] = 0] = "kMediaDeviceTypeAudioRenderDevice";
    MediaDeviceType[MediaDeviceType["kMediaDeviceTypeAudioCaptureDevice"] = 1] = "kMediaDeviceTypeAudioCaptureDevice";
    MediaDeviceType[MediaDeviceType["kMediaDeviceTypeVideoRenderDevice"] = 2] = "kMediaDeviceTypeVideoRenderDevice";
    MediaDeviceType[MediaDeviceType["kMediaDeviceTypeVideoCaptureDevice"] = 3] = "kMediaDeviceTypeVideoCaptureDevice";
})(MediaDeviceType = exports.MediaDeviceType || (exports.MediaDeviceType = {}));
var MediaDeviceNotification;
(function (MediaDeviceNotification) {
    MediaDeviceNotification[MediaDeviceNotification["kMediaDeviceNotificationActive"] = 1] = "kMediaDeviceNotificationActive";
    MediaDeviceNotification[MediaDeviceNotification["kMediaDeviceNotificationDisabled"] = 2] = "kMediaDeviceNotificationDisabled";
    MediaDeviceNotification[MediaDeviceNotification["kMediaDeviceNotificationNotPresent"] = 4] = "kMediaDeviceNotificationNotPresent";
    MediaDeviceNotification[MediaDeviceNotification["kMediaDeviceNotificationUnplugged"] = 8] = "kMediaDeviceNotificationUnplugged";
})(MediaDeviceNotification = exports.MediaDeviceNotification || (exports.MediaDeviceNotification = {}));
/**
 * @brief Type of the screen capture object
 */
var ScreenCaptureSourceType;
(function (ScreenCaptureSourceType) {
    /**
     * @brief Type unknown
     */
    ScreenCaptureSourceType[ScreenCaptureSourceType["kScreenCaptureSourceTypeUnknown"] = 0] = "kScreenCaptureSourceTypeUnknown";
    /**
     * @brief Application window
     */
    ScreenCaptureSourceType[ScreenCaptureSourceType["kScreenCaptureSourceTypeWindow"] = 1] = "kScreenCaptureSourceTypeWindow";
    /**
     * @brief Desktop
     */
    ScreenCaptureSourceType[ScreenCaptureSourceType["kScreenCaptureSourceTypeScreen"] = 2] = "kScreenCaptureSourceTypeScreen";
})(ScreenCaptureSourceType = exports.ScreenCaptureSourceType || (exports.ScreenCaptureSourceType = {}));
/**
 * @brief Priority of the publisher. When a user encounters performance insufficiency of either the network or the device, the media stream  will fall back in the ascending order of `RemoteUserPriority`.
 */
var RemoteUserPriority;
(function (RemoteUserPriority) {
    /**
     * @brief Low, the default
     */
    RemoteUserPriority[RemoteUserPriority["kRemoteUserPriorityLow"] = 0] = "kRemoteUserPriorityLow";
    /**
     * @brief Medium
     */
    RemoteUserPriority[RemoteUserPriority["kRemoteUserPriorityMedium"] = 100] = "kRemoteUserPriorityMedium";
    /**
     * @brief High
     */
    RemoteUserPriority[RemoteUserPriority["kRemoteUserPriorityHigh"] = 200] = "kRemoteUserPriorityHigh";
})(RemoteUserPriority = exports.RemoteUserPriority || (exports.RemoteUserPriority = {}));
/**
 * @brief Rendering mode
 */
var PublicStreamRenderMode;
(function (PublicStreamRenderMode) {
    /**
     * @brief Fill and Crop.
     *        The video frame is scaled with fixed aspect ratio, and completely fills the canvas. The region of the video exceeding the canvas will be cropped.
     */
    PublicStreamRenderMode[PublicStreamRenderMode["kRenderModeHidden"] = 1] = "kRenderModeHidden";
    /**
     * @brief Fit.
     *        The video frame is scaled with fixed aspect ratio, and is shown completely in the canvas. The region of the canvas not filled with video frame, is filled with `background`.
     */
    PublicStreamRenderMode[PublicStreamRenderMode["kRenderModeFit"] = 2] = "kRenderModeFit";
    /**
     *  @brief Fill the canvas.
     *         The video frame is scaled to fill the canvas. During the process, the aspect ratio may change.
     */
    PublicStreamRenderMode[PublicStreamRenderMode["kRenderModeFill"] = 3] = "kRenderModeFill";
})(PublicStreamRenderMode = exports.PublicStreamRenderMode || (exports.PublicStreamRenderMode = {}));
/**
 * @brief State and errors for publishing or subscribing public streams
 */
var PublicStreamErrorCode;
(function (PublicStreamErrorCode) {
    /**
     * @brief Published or subscribed successfully.
     */
    PublicStreamErrorCode[PublicStreamErrorCode["kPublicStreamOK"] = 0] = "kPublicStreamOK";
    /**
     * @brief Invalid parameter(s). Please revise the paramter(s) and retry.
     */
    PublicStreamErrorCode[PublicStreamErrorCode["kPublicStreamPushInvalidParam"] = 1191] = "kPublicStreamPushInvalidParam";
    /**
     * @brief Error for the task at the server side. The server will retry automatically.
     */
    PublicStreamErrorCode[PublicStreamErrorCode["kPublicStreamPushInvalidStatus"] = 1192] = "kPublicStreamPushInvalidStatus";
    /**
     * @brief Unrecoverable error of publishing the public stream. Please start the task again.
     */
    PublicStreamErrorCode[PublicStreamErrorCode["kPublicStreamPushInternalError"] = 1193] = "kPublicStreamPushInternalError";
    /**
     * @brief Failed to publish the public stream. The SDK  will retry that you have no need to handle.
     */
    PublicStreamErrorCode[PublicStreamErrorCode["kPublicStreamPushFailed"] = 1195] = "kPublicStreamPushFailed";
    /**
     * @brief Time-out error of publishing the public stream. The SDK will retry in 10 s. The SDK will stop trying again after three times of failures.
     */
    PublicStreamErrorCode[PublicStreamErrorCode["kPublicStreamPushTimeout"] = 1196] = "kPublicStreamPushTimeout";
})(PublicStreamErrorCode = exports.PublicStreamErrorCode || (exports.PublicStreamErrorCode = {}));
/**
 * @brief Types of streams to be mixed
 */
var TranscoderContentControlType;
(function (TranscoderContentControlType) {
    /**
     * @brief Audio and video
     */
    TranscoderContentControlType[TranscoderContentControlType["kHasAudioAndVideo"] = 0] = "kHasAudioAndVideo";
    /**
     * @brief Audio only
     */
    TranscoderContentControlType[TranscoderContentControlType["kHasAudioOnly"] = 1] = "kHasAudioOnly";
    /**
     * @brief Video only
     */
    TranscoderContentControlType[TranscoderContentControlType["kHasVideoOnly"] = 2] = "kHasVideoOnly";
})(TranscoderContentControlType = exports.TranscoderContentControlType || (exports.TranscoderContentControlType = {}));
/**
 * @brief Video encoding format
 */
var TranscoderVideoCodecProfile;
(function (TranscoderVideoCodecProfile) {
    /**
     * @brief H264 baseline profile
     */
    TranscoderVideoCodecProfile[TranscoderVideoCodecProfile["kByteH264ProfileBaseline"] = 0] = "kByteH264ProfileBaseline";
    /**
     * @brief H264 main profile
     */
    TranscoderVideoCodecProfile[TranscoderVideoCodecProfile["kByteH264ProfileMain"] = 1] = "kByteH264ProfileMain";
    /**
     * @brief H264 high profile
     */
    TranscoderVideoCodecProfile[TranscoderVideoCodecProfile["kByteH264ProfileHigh"] = 2] = "kByteH264ProfileHigh";
    /**
     * @brief Custom baseline profile
     */
    TranscoderVideoCodecProfile[TranscoderVideoCodecProfile["kByteVC1ProfileBaseline"] = 3] = "kByteVC1ProfileBaseline";
    /**
     * @brief Custom main profile
     */
    TranscoderVideoCodecProfile[TranscoderVideoCodecProfile["kByteVC1ProfileMain"] = 4] = "kByteVC1ProfileMain";
    /**
     * @brief Custom high profile
     */
    TranscoderVideoCodecProfile[TranscoderVideoCodecProfile["kByteVC1ProfileHigh"] = 5] = "kByteVC1ProfileHigh";
})(TranscoderVideoCodecProfile = exports.TranscoderVideoCodecProfile || (exports.TranscoderVideoCodecProfile = {}));
/**
 * @brief AAC profile. Defaults to `0`.
 */
var TranscoderAudioCodecProfile;
(function (TranscoderAudioCodecProfile) {
    /**
     * @brief Low-Complexity profile (AAC-LC)
     */
    TranscoderAudioCodecProfile[TranscoderAudioCodecProfile["kByteAACProfileLC"] = 0] = "kByteAACProfileLC";
    TranscoderAudioCodecProfile[TranscoderAudioCodecProfile["kByteAACProfileMain"] = 1] = "kByteAACProfileMain";
    /**
     * @brief HE-AAC profile (AAC LC with SBR)
     */
    TranscoderAudioCodecProfile[TranscoderAudioCodecProfile["kByteAACProfileHEv1"] = 2] = "kByteAACProfileHEv1";
    /**
     * @brief HE-AAC v2 profile (AAC LC with SBR and Parametric Stereo)
     */
    TranscoderAudioCodecProfile[TranscoderAudioCodecProfile["kByteAACProfileHEv2"] = 3] = "kByteAACProfileHEv2";
})(TranscoderAudioCodecProfile = exports.TranscoderAudioCodecProfile || (exports.TranscoderAudioCodecProfile = {}));
/**
 * @brief Video rendering scale mode
 */
var TranscoderRenderMode;
(function (TranscoderRenderMode) {
    /**
     * @hidden
     */
    TranscoderRenderMode[TranscoderRenderMode["kRenderUnknown"] = 0] = "kRenderUnknown";
    /**
     * @brief Fill and Crop.
     *        The video frame is scaled with fixed aspect ratio, until it completely fills the canvas. The region of the video exceeding the canvas will be cropped.
     */
    TranscoderRenderMode[TranscoderRenderMode["kRenderHidden"] = 1] = "kRenderHidden";
    /**
     * @brief Fit.
     *        The video frame is scaled with fixed aspect ratio, until it fits just within the canvas. Other part of the canvas is filled with the background color.
     */
    TranscoderRenderMode[TranscoderRenderMode["kRenderFit"] = 2] = "kRenderFit";
    /**
     * @brief Fill the canvas.
     *        The video frame is scaled to fill the canvas. During the process, the aspect ratio may change.
     */
    TranscoderRenderMode[TranscoderRenderMode["kRenderAdaptive"] = 3] = "kRenderAdaptive";
})(TranscoderRenderMode = exports.TranscoderRenderMode || (exports.TranscoderRenderMode = {}));
/**
 * @brief Media streaming network quality.
 */
var NetworkQuality;
(function (NetworkQuality) {
    /**
     * @brief Network quality unknown.
     */
    NetworkQuality[NetworkQuality["kNetworkQualityUnknown"] = 0] = "kNetworkQualityUnknown";
    /**
     * @brief The network quality is excellent.
     */
    NetworkQuality[NetworkQuality["kNetworkQualityExcellent"] = 1] = "kNetworkQualityExcellent";
    /**
     * @brief The subjective feeling is similar to kNetworkQualityExcellent, but the bit rate may be slightly lower.
     */
    NetworkQuality[NetworkQuality["kNetworkQualityGood"] = 2] = "kNetworkQualityGood";
    /**
     * @brief Subjective feelings are flawed but do not affect communication.
     */
    NetworkQuality[NetworkQuality["kNetworkQualityPoor"] = 3] = "kNetworkQualityPoor";
    /**
     * @brief Can barely communicate but not smoothly.
     */
    NetworkQuality[NetworkQuality["kNetworkQualityBad"] = 4] = "kNetworkQualityBad";
    /**
     * @brief The quality of the network is very poor and communication is basically impossible.
     */
    NetworkQuality[NetworkQuality["kNetworkQualityVbad"] = 5] = "kNetworkQualityVbad";
})(NetworkQuality = exports.NetworkQuality || (exports.NetworkQuality = {}));
/**
 * @detail 85534
 * @brief Result of sending messages and the reason of failure if it fails.
 */
var MessageSendResultCode;
(function (MessageSendResultCode) {
    /**
     * @brief The P2P message has been sent successfully.
     */
    MessageSendResultCode[MessageSendResultCode["MESSAGE_CODE_SUCCESS"] = 0] = "MESSAGE_CODE_SUCCESS";
    /**
     * @brief The room-wide broadcasting message has been sent successfully.
     */
    MessageSendResultCode[MessageSendResultCode["MESSAGE_CODE_ROOM_SUCCESS"] = 200] = "MESSAGE_CODE_ROOM_SUCCESS";
    /**
     * @brief Failure. Sending timeout.
     */
    MessageSendResultCode[MessageSendResultCode["MESSAGE_CODE_ERROR_TIMEOUT"] = 1] = "MESSAGE_CODE_ERROR_TIMEOUT";
    /**
     * @brief Failure. Channel disconnected.
     */
    MessageSendResultCode[MessageSendResultCode["MESSAGE_CODE_ERROR_BROKEN"] = 2] = "MESSAGE_CODE_ERROR_BROKEN";
    /**
     * @brief Failure. Recipient not found.
     */
    MessageSendResultCode[MessageSendResultCode["MESSAGE_CODE_ERROR_NOT_RECEIVER"] = 3] = "MESSAGE_CODE_ERROR_NOT_RECEIVER";
    /**
     * @brief Failure. The sender of the message did not join the room
     */
    MessageSendResultCode[MessageSendResultCode["MESSAGE_CODE_ERROR_NOT_JOIN"] = 100] = "MESSAGE_CODE_ERROR_NOT_JOIN";
    /**
     * @brief Failure. No data transmission channel connection available
     */
    MessageSendResultCode[MessageSendResultCode["MESSAGE_CODE_ERROR_NO_CONNECTION"] = 102] = "MESSAGE_CODE_ERROR_NO_CONNECTION";
    /**
     * @brief Failure. Message exceeds the range of the permitted size, 64 KB.
     */
    MessageSendResultCode[MessageSendResultCode["MESSAGE_CODE_ERROR_EXCEED_MAX_LENGTH"] = 103] = "MESSAGE_CODE_ERROR_EXCEED_MAX_LENGTH";
    /**
     * @brief Failure. The id of the recipient is empty
     */
    MessageSendResultCode[MessageSendResultCode["MESSAGE_CODE_ERROR_EMPTY_USER"] = 104] = "MESSAGE_CODE_ERROR_EMPTY_USER";
    /**
     * @brief Failure. Unknown error
     */
    MessageSendResultCode[MessageSendResultCode["MESSAGE_CODE_ERROR_UNKNOWN"] = 1000] = "MESSAGE_CODE_ERROR_UNKNOWN";
})(MessageSendResultCode = exports.MessageSendResultCode || (exports.MessageSendResultCode = {}));
/**
 * @brief Audio mix file playback status.
 */
var AudioMixingState;
(function (AudioMixingState) {
    /**
     * @brief Mix loaded
     */
    AudioMixingState[AudioMixingState["kAudioMixingStatePreloaded"] = 0] = "kAudioMixingStatePreloaded";
    /**
     * @brief Mix is playing
     */
    AudioMixingState[AudioMixingState["kAudioMixingStatePlaying"] = 1] = "kAudioMixingStatePlaying";
    /**
     * @brief Mix Pause
     */
    AudioMixingState[AudioMixingState["kAudioMixingStatePaused"] = 2] = "kAudioMixingStatePaused";
    /**
     * @brief Mixing stopped
     */
    AudioMixingState[AudioMixingState["kAudioMixingStateStopped"] = 3] = "kAudioMixingStateStopped";
    /**
     * @brief Mix playback failed
     */
    AudioMixingState[AudioMixingState["kAudioMixingStateFailed"] = 4] = "kAudioMixingStateFailed";
    /**
     * @brief End of mixing
     */
    AudioMixingState[AudioMixingState["kAudioMixingStateFinished"] = 5] = "kAudioMixingStateFinished";
})(AudioMixingState = exports.AudioMixingState || (exports.AudioMixingState = {}));
/**
 * @detail 85534
 * @brief Error code for audio mixing
 */
var AudioMixingError;
(function (AudioMixingError) {
    /**
     * @brief OK
     */
    AudioMixingError[AudioMixingError["kAudioMixingErrorOk"] = 0] = "kAudioMixingErrorOk";
    /**
     * @brief Preload failed. Invalid path or the length exceeds 20s.
     */
    AudioMixingError[AudioMixingError["kAudioMixingErrorPreloadFailed"] = 1] = "kAudioMixingErrorPreloadFailed";
    /**
     * @brief Mixing failed. Invalid path or fail to open the file.
     */
    AudioMixingError[AudioMixingError["kAudioMixingErrorStartFailed"] = 2] = "kAudioMixingErrorStartFailed";
    /**
     * @brief Invalid mixID
     */
    AudioMixingError[AudioMixingError["kAudioMixingErrorIdNotFound"] = 3] = "kAudioMixingErrorIdNotFound";
    /**
     * @brief Invalid position
     */
    AudioMixingError[AudioMixingError["kAudioMixingErrorSetPositionFailed"] = 4] = "kAudioMixingErrorSetPositionFailed";
    /**
     * @brief Invalid volume. The range is [0, 400].
     */
    AudioMixingError[AudioMixingError["kAudioMixingErrorInValidVolume"] = 5] = "kAudioMixingErrorInValidVolume";
    /**
     * @brief Another file was preloaded for mixing. Call [unloadAudioMixing](#unloadaudiomixing) first.
     */
    AudioMixingError[AudioMixingError["kAudioMixingErrorLoadConflict"] = 6] = "kAudioMixingErrorLoadConflict";
    /**
     * @brief Do not support the mix type.
     */
    AudioMixingError[AudioMixingError["kAudioMixingErrorIdTypeNotMatch"] = 7] = "kAudioMixingErrorIdTypeNotMatch";
    /**
     * @brief Invalid pitch value.
     */
    AudioMixingError[AudioMixingError["kAudioMixingErrorInValidPitch"] = 8] = "kAudioMixingErrorInValidPitch";
    /**
     * @brief Invalid audio track.
     */
    AudioMixingError[AudioMixingError["kAudioMixingErrorInValidAudioTrack"] = 9] = "kAudioMixingErrorInValidAudioTrack";
    /**
     * @brief Mixing starting
     */
    AudioMixingError[AudioMixingError["kAudioMixingErrorIsStarting"] = 10] = "kAudioMixingErrorIsStarting";
    /**
     * @brief Invalid playback speed
     */
    AudioMixingError[AudioMixingError["kAudioMixingErrorInValidPlaybackSpeed"] = 11] = "kAudioMixingErrorInValidPlaybackSpeed";
})(AudioMixingError = exports.AudioMixingError || (exports.AudioMixingError = {}));
/**
 * @detail 85534
 * @brief Callback warning code. The warning code indicates that there is a problem within the SDK and is trying to recover. Warning codes only serve as notifications.
 */
var WarningCode;
(function (WarningCode) {
    /**
     * @brief Failed to enter the room.
     *        When you call the first time to join the room or disconnect and reconnect due to poor network conditions, the room entry fails due to a server error. The SDK automatically retries the room.
     */
    WarningCode[WarningCode["kWarningCodeJoinRoomFailed"] = -2001] = "kWarningCodeJoinRoomFailed";
    /**
     * @brief Release audio & video stream failed.
     *        When you publish audio & video streams in your room, the publication fails due to a server error. The SDK automatically retries the release.
     */
    WarningCode[WarningCode["kWarningCodePublishStreamFailed"] = -2002] = "kWarningCodePublishStreamFailed";
    /**
     * @brief Subscription to audio & video stream failed.
     *         The subscription failed because the audio & video stream for the subscription could not be found in the current room. The SDK will automatically retry the subscription. If the subscription fails, it is recommended that you exit the retry.
     */
    WarningCode[WarningCode["kWarningCodeSubscribeStreamFailed404"] = -2003] = "kWarningCodeSubscribeStreamFailed404";
    /**
     * @brief Subscription to audio & video stream failed.
     *        When you subscribe to audio & video streams in your room, the subscription fails due to a server error. The SDK automatically retries the subscription.
     */
    WarningCode[WarningCode["kWarningCodeSubscribeStreamFailed5xx"] = -2004] = "kWarningCodeSubscribeStreamFailed5xx";
    /**
     * @brief This warning is triggered when you call `setUserVisibility` to set yourself unvisible to others and then try to publish the flow.
     */
    WarningCode[WarningCode["kWarningCodePublishStreamForbiden"] = -2009] = "kWarningCodePublishStreamForbiden";
    /**
     * @brief Sending a custom broadcast message failed, you are not currently in the room.
     */
    WarningCode[WarningCode["kWarningCodeSendCustomMessage"] = -2011] = "kWarningCodeSendCustomMessage";
    /**
     * @brief When the number of people in the room exceeds 500, stop sending `onUserJoined` and `onUserLeave` callbacks to existing users in the room, and prompt all users in the room via broadcast.
     */
    WarningCode[WarningCode["kWarningCodeUserNotifyStop"] = -2013] = "kWarningCodeUserNotifyStop";
    /**
     * @brief user had published in other room or had published public stream.
     */
    WarningCode[WarningCode["kWarningCodeUserInPublish"] = -2014] = "kWarningCodeUserInPublish";
    /**
     * @brief user had published in other room or had published public stream.
     */
    WarningCode[WarningCode["kWarningCodeOldRoomBeenReplaced"] = -2016] = "kWarningCodeOldRoomBeenReplaced";
    /**
     * @brief The old room has been replaced by new room with the same roomId
     */
    WarningCode[WarningCode["kWarningCodeInEchoTestMode"] = -2017] = "kWarningCodeInEchoTestMode";
    /**
     * @brief The camera permission is abnormal, and the current application does not obtain the camera permission.
     */
    WarningCode[WarningCode["kWarningCodeNoCameraPermission"] = -5001] = "kWarningCodeNoCameraPermission";
    /**
     * @hidden
     * @brief Setting the screen audio capture type with `setScreenAudioSourceType` after calling `publishScreen` is not supported, please set before `publishScreen`.
     */
    WarningCode[WarningCode["kWarningCodeSetScreenAudioSourceTypeFailed"] = -5009] = "kWarningCodeSetScreenAudioSourceTypeFailed";
    /**
     * @brief Setting the audio capture method for screen sharing via `setScreenAudioStreamIndex` after calling `publishScreen` is not supported.
     */
    WarningCode[WarningCode["kWarningCodeSetScreenAudioStreamIndexFailed"] = -5010] = "kWarningCodeSetScreenAudioStreamIndexFailed";
    /**
     * @brief Invalid pitch value setting
     */
    WarningCode[WarningCode["kWarningCodeInvalidVoicePitch"] = -5011] = "kWarningCodeInvalidVoicePitch";
    /**
     * @brief Invalid audio format setting
     */
    WarningCode[WarningCode["kWarningCodeInvalidAudioFormat"] = -5012] = "kWarningCodeInvalidAudioFormat";
    /**
     * @brief Mixed use of old and new interfaces for external audio sources
     */
    WarningCode[WarningCode["kWarningCodeInvalidCallForExtAudio"] = -5013] = "kWarningCodeInvalidCallForExtAudio";
    /**
     * @brief The specified internal rendering canvas handle is invalid.
     *        This callback is triggered when you specify an invalid canvas handle when you call [setupLocalVideo(85532#setuplocalvideo) or [setupRemoteVideo](85532#setupremotevideo).
     */
    WarningCode[WarningCode["kWarningCodeInvalidCanvasHandle"] = -6001] = "kWarningCodeInvalidCanvasHandle";
    /**
     * @brief The authentication file is invalid. When checking the status of the authentication file, if the local file is inconsistent with the remote file, a
     *        second warning will be triggered.
     */
    WarningCode[WarningCode["kWarningLicenseFileExpired"] = -7001] = "kWarningLicenseFileExpired";
})(WarningCode = exports.WarningCode || (exports.WarningCode = {}));
/**
 * @detail 85534
 * @brief Callback error code.
 *        When an unrecoverable error is encountered inside the SDK, the user is notified via the `onError` callback.
 */
var ErrorCode;
(function (ErrorCode) {
    /**
     * @brief Token  is invalid.
     *        The Token used when joining the room is invalid or expired. The user is required to retrieve the token and call the `updateToken` to update the token.
     */
    ErrorCode[ErrorCode["kErrorCodeInvalidToken"] = -1000] = "kErrorCodeInvalidToken";
    /**
     * @brief Join room error.
     *        An unknown error occurred while joining the room, which caused the joining room to fail. Users are required to rejoin the room.
     */
    ErrorCode[ErrorCode["kErrorCodeJoinRoom"] = -1001] = "kErrorCodeJoinRoom";
    /**
     * @brief No permission to publish audio & video streams.
     *        The user failed to publish the audio & video stream in the room. The reason for the failure is that the user does not have permission to publish the stream.
     */
    ErrorCode[ErrorCode["kErrorCodeNoPublishPermission"] = -1002] = "kErrorCodeNoPublishPermission";
    /**
     * @brief No subscription permissions for audio & video streams.
     *        The user failed to subscribe to the audio & video stream in the room where the user is located. The reason for the failure is that the user does not have permission to subscribe to the stream.
     */
    ErrorCode[ErrorCode["kErrorCodeNoSubscribePermission"] = -1003] = "kErrorCodeNoSubscribePermission";
    /**
     * @brief The user has been removed from the room because the same user joined the room on the other client.
     */
    ErrorCode[ErrorCode["kErrorCodeDuplicateLogin"] = -1004] = "kErrorCodeDuplicateLogin";
    /**
     * @brief The user has been removed from the room by the administrator via a OpenAPI call.
     */
    ErrorCode[ErrorCode["kErrorCodeKickedOut"] = -1006] = "kErrorCodeKickedOut";
    /**
     * @brief When calling `createRTCRoom`, if the roomid is illegal, it will return null and throw the error
     */
    ErrorCode[ErrorCode["kRoomErrorCodeRoomIdIllegal"] = -1007] = "kRoomErrorCodeRoomIdIllegal";
    /**
     * @brief Token expired. Call `joinRoom` to rejoin with a valid Token.
     */
    ErrorCode[ErrorCode["kRoomErrorTokenExpired"] = -1009] = "kRoomErrorTokenExpired";
    /**
     * @brief The Token you provided when calling `updateToken` is invalid.
     */
    ErrorCode[ErrorCode["kRoomErrorUpdateTokenWithInvalidToken"] = -1010] = "kRoomErrorUpdateTokenWithInvalidToken";
    /**
     * @brief Users have been removed from the room because the administrator dismissed the room by calling OpenAPI.
     */
    ErrorCode[ErrorCode["kErrorCodeRoomDismiss"] = -1011] = "kErrorCodeRoomDismiss";
    /**
     * @brief Join room error.
     *        The LICENSE billing account does not use the LICENSE_AUTHENTICATE SDK while entering the room, which caused the joining room to fail.
     */
    ErrorCode[ErrorCode["kErrorCodeJoinRoomWithoutLicenseAuthenticateSDK"] = -1012] = "kErrorCodeJoinRoomWithoutLicenseAuthenticateSDK";
    /**
     * @brief there is a room with the same roomId，whose room id is the same with echo test
     */
    ErrorCode[ErrorCode["kErrorCodeRoomAlreadyExist"] = -1013] = "kErrorCodeRoomAlreadyExist";
    /**
     * @brief Subscription to audio & video stream failed, the total number of subscribed audio & video streams exceeded the upper limit.
     *        In the game scenario, in order to ensure the performance and quality of audio & video calls, the server will limit the total number of audio & video streams subscribed by the user. When the total number of audio & video streams subscribed by the user has reached the maximum, continuing to subscribe to more streams will fail, and the user will receive this error notification.
     */
    ErrorCode[ErrorCode["kErrorCodeOverStreamSubscribeLimit"] = -1070] = "kErrorCodeOverStreamSubscribeLimit";
    /**
     * @brief Publishing flow failed, the total number of publishing flows exceeds the upper limit. The
     *        RTC system limits the total number of streams published in a single room, including video streams, audio streams, and screen streams. Local users will fail to publish streams to the room when the maximum number of published streams in the room has been reached, and will receive this error notification.
     */
    ErrorCode[ErrorCode["kErrorCodeOverStreamPublishLimit"] = -1080] = "kErrorCodeOverStreamPublishLimit";
    /**
     * @brief Publishing the screen stream failed, and the total number of publishing streams exceeded the upper limit. The
     *        RTC system limits the total number of streams published in a single room, including video streams, audio streams, and screen streams. Local users will fail to publish streams to the room when the maximum number of published streams in the room has been reached, and will receive this error notification.
     */
    ErrorCode[ErrorCode["kErrorCodeOverScreenPublishLimit"] = -1081] = "kErrorCodeOverScreenPublishLimit";
    /**
     * @brief The total number of published video streams exceeds the upper limit.
     *        The RTC system limits the number of video streams posted in a single room. If the maximum number of video streams posted in the room has been reached, local users will fail to post video streams to the room again and will receive this error notification.
     */
    ErrorCode[ErrorCode["kErrorCodeOverVideoPublishLimit"] = -1082] = "kErrorCodeOverVideoPublishLimit";
    /**
     * @brief A/V synchronization failed.
     *        Current source audio ID has been set by other video publishers in the same room.
     *        One single audio source cannot be synchronized with multiple video sources at the same time.
     */
    ErrorCode[ErrorCode["kErrorCodeInvalidAudioSyncUidRepeated"] = -1083] = "kErrorCodeInvalidAudioSyncUidRepeated";
    /**
     * @brief The user has been removed from the room due to the abnormal status of server.
     *        SDK  is disconnected with the signaling server. It will not reconnect automatically. Please contact technical support.
     */
    ErrorCode[ErrorCode["kErrorCodeAbnormalServerStatus"] = -1084] = "kErrorCodeAbnormalServerStatus";
})(ErrorCode = exports.ErrorCode || (exports.ErrorCode = {}));
/**
 * @brief SDK  Network connection type.
 */
var NetworkType;
(function (NetworkType) {
    /**
     * @brief Network connection type unknown.
     */
    NetworkType[NetworkType["kNetworkTypeUnknown"] = -1] = "kNetworkTypeUnknown";
    /**
     * @brief The network connection has been disconnected.
     */
    NetworkType[NetworkType["kNetworkTypeDisconnected"] = 0] = "kNetworkTypeDisconnected";
    /**
     * @brief The network connection type is LAN.
     */
    NetworkType[NetworkType["kNetworkTypeLAN"] = 1] = "kNetworkTypeLAN";
    /**
     * @brief The network connection type is Wi-Fi (including hotspots).
     */
    NetworkType[NetworkType["kNetworkTypeWIFI"] = 2] = "kNetworkTypeWIFI";
    /**
     * @brief The network connection type is 2G mobile network.
     */
    NetworkType[NetworkType["kNetworkTypeMobile2G"] = 3] = "kNetworkTypeMobile2G";
    /**
     * @brief The network connection type is 3G mobile network.
     */
    NetworkType[NetworkType["kNetworkTypeMobile3G"] = 4] = "kNetworkTypeMobile3G";
    /**
     * @brief The network connection type is 4G mobile network.
     */
    NetworkType[NetworkType["kNetworkTypeMobile4G"] = 5] = "kNetworkTypeMobile4G";
    /**
     * @brief The network connection type is 5G mobile network.
     */
    NetworkType[NetworkType["kNetworkTypeMobile5G"] = 6] = "kNetworkTypeMobile5G";
})(NetworkType = exports.NetworkType || (exports.NetworkType = {}));
/**
 * @brief Audio & video quality feedback problem
 */
var ProblemFeedbackOption;
(function (ProblemFeedbackOption) {
    /**
     * @brief Every thing is OK.
     */
    ProblemFeedbackOption[ProblemFeedbackOption["kProblemFeedbackOptionNone"] = 0] = "kProblemFeedbackOptionNone";
    /**
     * @brief Issues not included in the list
     */
    ProblemFeedbackOption[ProblemFeedbackOption["kProblemFeedbackOptionOtherMessage"] = 1] = "kProblemFeedbackOptionOtherMessage";
    /**
     * @brief Unclear voice
     */
    ProblemFeedbackOption[ProblemFeedbackOption["kProblemFeedbackOptionAudioNotClear"] = 2] = "kProblemFeedbackOptionAudioNotClear";
    /**
     * @brief Unclear video
     */
    ProblemFeedbackOption[ProblemFeedbackOption["kProblemFeedbackOptionVideoNotClear"] = 3] = "kProblemFeedbackOptionVideoNotClear";
    /**
     * @brief Audio & video out of sync
     */
    ProblemFeedbackOption[ProblemFeedbackOption["kProblemFeedbackOptionNotSync"] = 4] = "kProblemFeedbackOptionNotSync";
    /**
     * @brief Audio stall
     */
    ProblemFeedbackOption[ProblemFeedbackOption["kProblemFeedbackOptionAudioLagging"] = 5] = "kProblemFeedbackOptionAudioLagging";
    /**
     * @brief Video stall
     */
    ProblemFeedbackOption[ProblemFeedbackOption["kProblemFeedbackOptionVideoLagging"] = 6] = "kProblemFeedbackOptionVideoLagging";
    /**
     * @brief Connection failed
     */
    ProblemFeedbackOption[ProblemFeedbackOption["kProblemFeedbackOptionDisconnected"] = 7] = "kProblemFeedbackOptionDisconnected";
    /**
     * @brief No sound
     */
    ProblemFeedbackOption[ProblemFeedbackOption["kProblemFeedbackOptionNoAudio"] = 8] = "kProblemFeedbackOptionNoAudio";
    /**
     * @brief No picture
     */
    ProblemFeedbackOption[ProblemFeedbackOption["kProblemFeedbackOptionNoVideo"] = 9] = "kProblemFeedbackOptionNoVideo";
    /**
     * @brief Too little sound
     */
    ProblemFeedbackOption[ProblemFeedbackOption["kProblemFeedbackOptionAudioStrength"] = 10] = "kProblemFeedbackOptionAudioStrength";
    /**
     * @brief Echo noise
     */
    ProblemFeedbackOption[ProblemFeedbackOption["kProblemFeedbackOptionEcho"] = 11] = "kProblemFeedbackOptionEcho";
    /**
     * @brief High latency for the ear monitor
     */
    ProblemFeedbackOption[ProblemFeedbackOption["KFeedbackOptionEarBackDelay"] = 12] = "KFeedbackOptionEarBackDelay";
})(ProblemFeedbackOption = exports.ProblemFeedbackOption || (exports.ProblemFeedbackOption = {}));
/**
 * @brief Whether to turn on release performance fallback
 */
var PerformanceAlarmMode;
(function (PerformanceAlarmMode) {
    /**
     * @brief Not enabled Release performance fallback
     */
    PerformanceAlarmMode[PerformanceAlarmMode["kPerformanceAlarmModeNormal"] = 0] = "kPerformanceAlarmModeNormal";
    /**
     * @brief Open Release Performance Rollback
     */
    PerformanceAlarmMode[PerformanceAlarmMode["kPerformanceAlarmModeSimulcast"] = 1] = "kPerformanceAlarmModeSimulcast";
})(PerformanceAlarmMode = exports.PerformanceAlarmMode || (exports.PerformanceAlarmMode = {}));
/**
 * @brief Reasons of performance-related alarms
 */
var PerformanceAlarmReason;
(function (PerformanceAlarmReason) {
    /**
     * @brief The poor network causes the transmission performance to fall back. This reason is only received when sending performance fallback is turned on.
     */
    PerformanceAlarmReason[PerformanceAlarmReason["kPerformanceAlarmReasonBandwidthFallbacked"] = 0] = "kPerformanceAlarmReasonBandwidthFallbacked";
    /**
     * @brief Network performance recovery, transmission performance rollback recovery. This reason is only received when sending performance fallback is turned on.
     */
    PerformanceAlarmReason[PerformanceAlarmReason["kPerformanceAlarmReasonBandwidthResumed"] = 1] = "kPerformanceAlarmReasonBandwidthResumed";
    /**
     * @brief If the send performance fallback is not turned on, when receiving this alarm, it means that the performance is insufficient;
     *        If the send performance fallback is turned on, when receiving this alarm, it means that the performance is insufficient and the send performance fallback has occurred.
     */
    PerformanceAlarmReason[PerformanceAlarmReason["kPerformanceAlarmReasonPerformanceFallbacked"] = 2] = "kPerformanceAlarmReasonPerformanceFallbacked";
    /**
     * @brief If the send performance fallback is not turned on, when receiving this alarm, it means that the performance shortage has been restored;
     *         If the send performance fallback is turned on, when receiving this alarm, it means that the performance shortage has been restored and the send performance fallback has occurred. Recovery.
     */
    PerformanceAlarmReason[PerformanceAlarmReason["kPerformanceAlarmReasonPerformanceResumed"] = 3] = "kPerformanceAlarmReasonPerformanceResumed";
})(PerformanceAlarmReason = exports.PerformanceAlarmReason || (exports.PerformanceAlarmReason = {}));
var MediaDeviceError;
(function (MediaDeviceError) {
    MediaDeviceError[MediaDeviceError["kMediaDeviceErrorOK"] = 0] = "kMediaDeviceErrorOK";
    MediaDeviceError[MediaDeviceError["kMediaDeviceErrorDeviceNoPermission"] = 1] = "kMediaDeviceErrorDeviceNoPermission";
    MediaDeviceError[MediaDeviceError["kMediaDeviceErrorDeviceBusy"] = 2] = "kMediaDeviceErrorDeviceBusy";
    MediaDeviceError[MediaDeviceError["kMediaDeviceErrorDeviceFailure"] = 3] = "kMediaDeviceErrorDeviceFailure";
    MediaDeviceError[MediaDeviceError["kMediaDeviceErrorDeviceNotFound"] = 4] = "kMediaDeviceErrorDeviceNotFound";
    MediaDeviceError[MediaDeviceError["kMediaDeviceErrorDeviceDisconnected"] = 5] = "kMediaDeviceErrorDeviceDisconnected";
})(MediaDeviceError = exports.MediaDeviceError || (exports.MediaDeviceError = {}));
var JoinRoomType;
(function (JoinRoomType) {
    JoinRoomType[JoinRoomType["kJoinRoomTypeFirst"] = 0] = "kJoinRoomTypeFirst";
    JoinRoomType[JoinRoomType["kJoinRoomTypeReconnected"] = 1] = "kJoinRoomTypeReconnected";
})(JoinRoomType = exports.JoinRoomType || (exports.JoinRoomType = {}));
var MuteState;
(function (MuteState) {
    MuteState[MuteState["kMuteStateOff"] = 0] = "kMuteStateOff";
    MuteState[MuteState["kMuteStateOn"] = 1] = "kMuteStateOn";
})(MuteState = exports.MuteState || (exports.MuteState = {}));
/**
 * @brief Stream type.
 */
var StreamIndex;
(function (StreamIndex) {
    /**
     * @brief Main stream which includes video captured by cameras or audio captured by microphone
     */
    StreamIndex[StreamIndex["kStreamIndexMain"] = 0] = "kStreamIndexMain";
    /**
     * @brief Screen stream to be shared
     * Screen recording stream or sounds coming from the sound card
     */
    StreamIndex[StreamIndex["kStreamIndexScreen"] = 1] = "kStreamIndexScreen";
})(StreamIndex = exports.StreamIndex || (exports.StreamIndex = {}));
/**
 * @brief Events during pushing streams to CDN
 */
var StreamMixingEvent;
(function (StreamMixingEvent) {
    /**
     * @brief Request to start pushing streams to CDN
     */
    StreamMixingEvent[StreamMixingEvent["kStreamMixingStart"] = 1] = "kStreamMixingStart";
    /**
     * @brief ask to push streams to CDN started
     */
    StreamMixingEvent[StreamMixingEvent["kStreamMixingStartSuccess"] = 2] = "kStreamMixingStartSuccess";
    /**
     * @brief Failed to start the task to push streams to CDN
     */
    StreamMixingEvent[StreamMixingEvent["kStreamMixingStartFailed"] = 3] = "kStreamMixingStartFailed";
    /**
     * @brief Request to update the configuration for the task to push streams to CDN
     */
    StreamMixingEvent[StreamMixingEvent["kStreamMixingUpdate"] = 4] = "kStreamMixingUpdate";
    /**
     * @brief Successfully update the configuration for the task to push streams to CDN
     */
    StreamMixingEvent[StreamMixingEvent["kStreamMixingUpdateSuccess"] = 5] = "kStreamMixingUpdateSuccess";
    /**
     * @brief Failed to update the configuration for the task to push streams to CDN
     */
    StreamMixingEvent[StreamMixingEvent["kStreamMixingUpdateFailed"] = 6] = "kStreamMixingUpdateFailed";
    /**
     * @brief Request to stop the task to push streams to CDN
     */
    StreamMixingEvent[StreamMixingEvent["kStreamMixingStop"] = 7] = "kStreamMixingStop";
    /**
     * @brief The task to push streams to CDN stopped
     */
    StreamMixingEvent[StreamMixingEvent["kStreamMixingStopSuccess"] = 8] = "kStreamMixingStopSuccess";
    /**
     * @brief Failed to stop the task to push streams to CDN
     */
    StreamMixingEvent[StreamMixingEvent["kStreamMixingStopFailed"] = 9] = "kStreamMixingStopFailed";
    /**
     * @brief Timeout for the request to update the configuration for the task to push streams to CDN.
     */
    StreamMixingEvent[StreamMixingEvent["kStreamMixingChangeMixType"] = 10] = "kStreamMixingChangeMixType";
    /**
     * @brief Got the first frame of the mixed audio stream by client.
     */
    StreamMixingEvent[StreamMixingEvent["kStreamMixingFirstAudioFrameByClientMix"] = 11] = "kStreamMixingFirstAudioFrameByClientMix";
    /**
     * @brief Got the first frame of the mixed video stream by client.
     */
    StreamMixingEvent[StreamMixingEvent["kStreamMixingFirstVideoFrameByClientMix"] = 12] = "kStreamMixingFirstVideoFrameByClientMix";
    /**
     * @brief Timeout for the request to update the configuration for the task to push streams to CDN
     */
    StreamMixingEvent[StreamMixingEvent["kStreamMixingUpdateTimeout"] = 13] = "kStreamMixingUpdateTimeout";
    /**
     * @brief Timeout for the request to start the task to push streams to CDN
     */
    StreamMixingEvent[StreamMixingEvent["kStreamMixingStartTimeout"] = 14] = "kStreamMixingStartTimeout";
    /**
     * @brief Error in the parameters of the request for the task to push streams to CDN
     */
    StreamMixingEvent[StreamMixingEvent["kStreamMixingRequestParamError"] = 15] = "kStreamMixingRequestParamError";
    /**
     * @brief Mixing image.
     */
    StreamMixingEvent[StreamMixingEvent["kStreamMixingMixImageEvent"] = 16] = "kStreamMixingMixImageEvent";
})(StreamMixingEvent = exports.StreamMixingEvent || (exports.StreamMixingEvent = {}));
/**
 * @brief Events during pushing streams to CDN
 */
var SingleStreamPushEvent;
(function (SingleStreamPushEvent) {
    /**
     * @brief Starting pushing a single stream to CDN.
     */
    SingleStreamPushEvent[SingleStreamPushEvent["kSingleStreamPushStart"] = 1] = "kSingleStreamPushStart";
    /**
     * @brief Successfully pushed a single stream to CDN.
     */
    SingleStreamPushEvent[SingleStreamPushEvent["kSingleStreamPushSuccess"] = 2] = "kSingleStreamPushSuccess";
    /**
     * @brief Failed to push a single stream to CDN.
     */
    SingleStreamPushEvent[SingleStreamPushEvent["kSingleStreamPushFailed"] = 3] = "kSingleStreamPushFailed";
    /**
     * @brief Stop pushing a single stream to CDN.
     */
    SingleStreamPushEvent[SingleStreamPushEvent["kSingleStreamPushStop"] = 4] = "kSingleStreamPushStop";
    /**
     * @brief Request timed out. Please check network status and retry.
     */
    SingleStreamPushEvent[SingleStreamPushEvent["kSingleStreamPushTimeout"] = 5] = "kSingleStreamPushTimeout";
    /**
     * @brief Request failed due to invalid parameter.
     */
    SingleStreamPushEvent[SingleStreamPushEvent["kSingleStreamPushParamError"] = 6] = "kSingleStreamPushParamError";
})(SingleStreamPushEvent = exports.SingleStreamPushEvent || (exports.SingleStreamPushEvent = {}));
/**
 * @brief Stream mixing type
 */
var StreamMixingType;
(function (StreamMixingType) {
    /**
     * @brief Server-side stream mixing
     */
    StreamMixingType[StreamMixingType["kStreamMixingTypeByServer"] = 0] = "kStreamMixingTypeByServer";
    /**
     * @brief Intelligent stream mixing. The SDK will intelligently decide that a stream mixing task would be done on the client or the server.
     */
    StreamMixingType[StreamMixingType["kStreamMixingTypeByClient"] = 1] = "kStreamMixingTypeByClient";
})(StreamMixingType = exports.StreamMixingType || (exports.StreamMixingType = {}));
var RecordingType;
(function (RecordingType) {
    /**
     * @brief 只录制音频
     */
    RecordingType[RecordingType["kRecordAudioOnly"] = 0] = "kRecordAudioOnly";
    /**
     * @brief 只录制视频
     */
    RecordingType[RecordingType["kRecordVideoOnly"] = 1] = "kRecordVideoOnly";
    /**
     * @brief 同时录制音频和视频
     */
    RecordingType[RecordingType["kRecordVideoAndAudio"] = 2] = "kRecordVideoAndAudio";
})(RecordingType = exports.RecordingType || (exports.RecordingType = {}));
var StreamRemoveReason;
(function (StreamRemoveReason) {
    StreamRemoveReason[StreamRemoveReason["kStreamRemoveReasonUnpublish"] = 0] = "kStreamRemoveReasonUnpublish";
    StreamRemoveReason[StreamRemoveReason["kStreamRemoveReasonPublishFailed"] = 1] = "kStreamRemoveReasonPublishFailed";
    StreamRemoveReason[StreamRemoveReason["kStreamRemoveReasonKeepLiveFailed"] = 2] = "kStreamRemoveReasonKeepLiveFailed";
    StreamRemoveReason[StreamRemoveReason["kStreamRemoveReasonClientDisconnected"] = 3] = "kStreamRemoveReasonClientDisconnected";
    StreamRemoveReason[StreamRemoveReason["kStreamRemoveReasonRepublish"] = 4] = "kStreamRemoveReasonRepublish";
    StreamRemoveReason[StreamRemoveReason["kStreamRemoveReasonOther"] = 5] = "kStreamRemoveReasonOther";
})(StreamRemoveReason = exports.StreamRemoveReason || (exports.StreamRemoveReason = {}));
/**
 * @brief Reason of the Fallback or reverting from a Fallback of the subscribed stream or the publishing stream
 */
var FallbackOrRecoverReason;
(function (FallbackOrRecoverReason) {
    /**
     * @brief The default: Fallback due to an unknown reason that is neither infufficienclt bandwidth of the network nor poor-performance of the device
     */
    FallbackOrRecoverReason[FallbackOrRecoverReason["kFallbackOrRecoverReasonUnknown"] = -1] = "kFallbackOrRecoverReasonUnknown";
    /**
     * @brief Fallback of the subscribed stream due to insufficient bandwidth of the network
     */
    FallbackOrRecoverReason[FallbackOrRecoverReason["kFallbackOrRecoverReasonSubscribeFallbackByBandwidth"] = 0] = "kFallbackOrRecoverReasonSubscribeFallbackByBandwidth";
    /**
     * @brief Fallback of the subscribed stream for poor-performance of the device
     */
    FallbackOrRecoverReason[FallbackOrRecoverReason["kFallbackOrRecoverReasonSubscribeFallbackByPerformance"] = 1] = "kFallbackOrRecoverReasonSubscribeFallbackByPerformance";
    /**
     * @brief Reverting from a Fallback of the subscribed stream due to the recovery of the network bandwidth
     */
    FallbackOrRecoverReason[FallbackOrRecoverReason["kFallbackOrRecoverReasonSubscribeRecoverByBandwidth"] = 2] = "kFallbackOrRecoverReasonSubscribeRecoverByBandwidth";
    /**
     * @brief Reverting from a Fallback of the subscribed stream due to the amelioration of the device performance
     */
    FallbackOrRecoverReason[FallbackOrRecoverReason["kFallbackOrRecoverReasonSubscribeRecoverByPerformance"] = 3] = "kFallbackOrRecoverReasonSubscribeRecoverByPerformance";
    /**
     * @brief Fallback of the publishing stream due to Insufficient bandwidth of the network
     */
    FallbackOrRecoverReason[FallbackOrRecoverReason["kFallbackOrRecoverReasonPublishFallbackByBandwidth"] = 4] = "kFallbackOrRecoverReasonPublishFallbackByBandwidth";
    /**
     * @brief Fallback of the publishing stream due to poor-performance of the device
     */
    FallbackOrRecoverReason[FallbackOrRecoverReason["kFallbackOrRecoverReasonPublishFallbackByPerformance"] = 5] = "kFallbackOrRecoverReasonPublishFallbackByPerformance";
    /**
     * @brief Reverting from a Fallback of the publishing stream due to the recovery of the network bandwidth
     */
    FallbackOrRecoverReason[FallbackOrRecoverReason["kFallbackOrRecoverReasonPublishRecoverByBandwidth"] = 6] = "kFallbackOrRecoverReasonPublishRecoverByBandwidth";
    /**
     * @brief Reverting from a Fallback of the publishing stream due to the amelioration of the device performance
     */
    FallbackOrRecoverReason[FallbackOrRecoverReason["kFallbackOrRecoverReasonPublishRecoverByPerformance"] = 7] = "kFallbackOrRecoverReasonPublishRecoverByPerformance";
})(FallbackOrRecoverReason = exports.FallbackOrRecoverReason || (exports.FallbackOrRecoverReason = {}));
/**
 * @brief Information on video frame rotation angle
 */
var VideoRotation;
(function (VideoRotation) {
    /**
     * @brief Video does not rotate
     */
    VideoRotation[VideoRotation["kVideoRotation0"] = 0] = "kVideoRotation0";
    /**
     * @brief Video rotates 90 degrees clockwise
     */
    VideoRotation[VideoRotation["kVideoRotation90"] = 90] = "kVideoRotation90";
    /**
     * @brief Video rotates 180 degrees clockwise
     */
    VideoRotation[VideoRotation["kVideoRotation180"] = 180] = "kVideoRotation180";
    /**
     * @brief Video rotates 270 degrees clockwise
     */
    VideoRotation[VideoRotation["kVideoRotation270"] = 270] = "kVideoRotation270";
})(VideoRotation = exports.VideoRotation || (exports.VideoRotation = {}));
var VirtualBackgroundSourceType;
(function (VirtualBackgroundSourceType) {
    VirtualBackgroundSourceType[VirtualBackgroundSourceType["kVirtualBackgroundSourceColor"] = 0] = "kVirtualBackgroundSourceColor";
    VirtualBackgroundSourceType[VirtualBackgroundSourceType["kVirtualBackgroundSourceImage"] = 1] = "kVirtualBackgroundSourceImage";
})(VirtualBackgroundSourceType = exports.VirtualBackgroundSourceType || (exports.VirtualBackgroundSourceType = {}));
/**
 * @brief Local audio stream status.
 *        SDK callbacks local audio stream status via `onLocalAudioStateChanged`
 */
var LocalAudioStreamState;
(function (LocalAudioStreamState) {
    /**
     * @brief The default initial state of the local audio.
     *         Callback to this state when the microphone stops working, corresponding to the error code kLocalAudioStreamErrorOk
     */
    LocalAudioStreamState[LocalAudioStreamState["kLocalAudioStreamStateStopped"] = 0] = "kLocalAudioStreamStateStopped";
    /**
     * @brief The local audio recording device started successfully.
     *         Callback to the state when the first frame of audio is collected, corresponding to the error code kLocalAudioStreamErrorOk
     */
    LocalAudioStreamState[LocalAudioStreamState["kLocalAudioStreamStateRecording"] = 1] = "kLocalAudioStreamStateRecording";
    /**
     * @brief The first frame of the local audio was successfully encoded.
     *         Callback to the state when the audio first frame encoding is successful, corresponding to the error code kLocalAudioStreamErrorOk
     */
    LocalAudioStreamState[LocalAudioStreamState["kLocalAudioStreamStateEncoding"] = 2] = "kLocalAudioStreamStateEncoding";
    /**
     * @brief The local audio startup failed, and the status is called back at the following times:
     *        + The local recording device failed to start, corresponding to the error code kLocalAudioStreamErrorRecordFailure
     *        + No recording device permission was detected, corresponding to the error code kLocalAudioStreamErrorDeviceNoPermission
     *        + The audio encoding failed, corresponding to the error code kLocalAudioStreamErrorEncodeFailure
     */
    LocalAudioStreamState[LocalAudioStreamState["kLocalAudioStreamStateFailed"] = 3] = "kLocalAudioStreamStateFailed";
})(LocalAudioStreamState = exports.LocalAudioStreamState || (exports.LocalAudioStreamState = {}));
/**
 * @detail 85534
 * @brief Error code when the local audio state changes
 *        SDK informs you via [onLocalAudioStateChanged](85533#onlocalaudiostatechanged).
 */
var LocalAudioStreamError;
(function (LocalAudioStreamError) {
    /**
     * @brief Local audio status is normal
     */
    LocalAudioStreamError[LocalAudioStreamError["kLocalAudioStreamErrorOk"] = 0] = "kLocalAudioStreamErrorOk";
    /**
     * @brief Local audio error cause unknown
     */
    LocalAudioStreamError[LocalAudioStreamError["kLocalAudioStreamErrorFailure"] = 1] = "kLocalAudioStreamErrorFailure";
    /**
     * @brief No permission to start local audio recording device
     */
    LocalAudioStreamError[LocalAudioStreamError["kLocalAudioStreamErrorDeviceNoPermission"] = 2] = "kLocalAudioStreamErrorDeviceNoPermission";
    /**
     * @hidden
     * @brief The local audio recording device is already in use
     * The error code is not yet in use
     */
    LocalAudioStreamError[LocalAudioStreamError["kLocalAudioStreamErrorDeviceBusy"] = 3] = "kLocalAudioStreamErrorDeviceBusy";
    /**
     * @brief Local audio recording failed, it is recommended that you check whether the recording device is working properly
     */
    LocalAudioStreamError[LocalAudioStreamError["kLocalAudioStreamErrorRecordFailure"] = 4] = "kLocalAudioStreamErrorRecordFailure";
    /**
     * @brief Local audio encoding failed
     */
    LocalAudioStreamError[LocalAudioStreamError["kLocalAudioStreamErrorEncodeFailure"] = 5] = "kLocalAudioStreamErrorEncodeFailure";
    /**
     * @brief No audio recording equipment available
     */
    LocalAudioStreamError[LocalAudioStreamError["kLocalAudioStreamErrorNoRecordingDevice"] = 6] = "kLocalAudioStreamErrorNoRecordingDevice";
})(LocalAudioStreamError = exports.LocalAudioStreamError || (exports.LocalAudioStreamError = {}));
/**
 * @brief Remote audio stream state.
 *         Users can learn about this status through `onRemoteAudioStateChanged`.
 */
var RemoteAudioState;
(function (RemoteAudioState) {
    /**
     * @brief The remote audio stream is not received.
     *        The callback [onRemoteAudioStateChanged](85533#onremoteaudiostatechanged) triggers:
     *        + Local users stop receiving remote audio streams due to kRemoteAudioStateChangeReasonLocalMuted
     *        + The remote user stops sending audio streams due to kRemoteAudioStateChangeReasonRemoteMuted
     *        + The remote user left the room, the corresponding reason is: kRemoteAudioStateChangeReasonRemoteOffline
     */
    RemoteAudioState[RemoteAudioState["kRemoteAudioStateStopped"] = 0] = "kRemoteAudioStateStopped";
    /**
     * @brief Start receiving the remote audio stream header.
     *        Just received the remote audio stream header will trigger a callback [onRemoteAudioStateChanged](85533#onremoteaudiostatechanged),
     *         The corresponding reason is: RemoteAudioStateChangeReason in "kRemoteAudioStateChangeReasonLocalUnmuted"
     */
    RemoteAudioState[RemoteAudioState["kRemoteAudioStateStarting"] = 1] = "kRemoteAudioStateStarting";
    /**
     * @brief The remote audio stream is decoding and playing normally.
     *          A callback is triggered in the following cases: [onRemoteAudioStateChanged](85533#onremoteaudiostatechanged):
     *        + The remote audio first frame was successfully decoded, and the corresponding reason is: 'kRemoteAudioStateChangeReasonLocalUnmuted' in RemoteAudioStateChangeReason
     *        + The network returned to normal from blocking, and the corresponding reason is: "kRemoteAudioStateChangeReasonNetworkRecovery ' in RemoteAudioStateChangeReason
     *        + Local users resume receiving remote audio streams, and the corresponding reason is 'kRemoteAudioStateChangeReasonLocalUnmuted ' RemoteAudioStateChangeReason
     *        + Remote users resume sending audio streams, and the corresponding reason is 'kRemoteAudioStateChangeReasonRemoteUnmuted' in RemoteAudioStateChangeReason
     */
    RemoteAudioState[RemoteAudioState["kRemoteAudioStateDecoding"] = 2] = "kRemoteAudioStateDecoding";
    /**
     * @brief Remote audio streaming card.
     *         A callback is triggered when the network is blocked and the packet loss rate is greater than 40%. `onRemoteAudioStateChanged`,
     *         The corresponding reason is: "kRemoteAudioStateChangeReasonNetworkCongestion" in RemoteAudioStateChangeReasonNetworkCongestion}
     */
    RemoteAudioState[RemoteAudioState["kRemoteAudioStateFrozen"] = 3] = "kRemoteAudioStateFrozen";
    /**
     * @hidden
     * @brief The remote audio stream failed to play
     * @notes  The error code is not yet used
     */
    RemoteAudioState[RemoteAudioState["kRemoteAudioStateFailed"] = 4] = "kRemoteAudioStateFailed";
})(RemoteAudioState = exports.RemoteAudioState || (exports.RemoteAudioState = {}));
/**
 * @brief Receives the cause of the remote audio stream state change.
 *        Users can learn about this reason through `onRemoteAudioStateChanged`.
 */
var RemoteAudioStateChangeReason;
(function (RemoteAudioStateChangeReason) {
    /**
     * @brief Internal reasons
     */
    RemoteAudioStateChangeReason[RemoteAudioStateChangeReason["kRemoteAudioStateChangeReasonInternal"] = 0] = "kRemoteAudioStateChangeReasonInternal";
    /**
     * @brief Network blocking
     */
    RemoteAudioStateChangeReason[RemoteAudioStateChangeReason["kRemoteAudioStateChangeReasonNetworkCongestion"] = 1] = "kRemoteAudioStateChangeReasonNetworkCongestion";
    /**
     * @brief Network back to normal
     */
    RemoteAudioStateChangeReason[RemoteAudioStateChangeReason["kRemoteAudioStateChangeReasonNetworkRecovery"] = 2] = "kRemoteAudioStateChangeReasonNetworkRecovery";
    /**
     * @brief Local user stops receiving remote audio stream
     */
    RemoteAudioStateChangeReason[RemoteAudioStateChangeReason["kRemoteAudioStateChangeReasonLocalMuted"] = 3] = "kRemoteAudioStateChangeReasonLocalMuted";
    /**
     * @brief Local users resume receiving remote audio streams
     */
    RemoteAudioStateChangeReason[RemoteAudioStateChangeReason["kRemoteAudioStateChangeReasonLocalUnmuted"] = 4] = "kRemoteAudioStateChangeReasonLocalUnmuted";
    /**
     * @brief Remote user stops sending audio stream
     */
    RemoteAudioStateChangeReason[RemoteAudioStateChangeReason["kRemoteAudioStateChangeReasonRemoteMuted"] = 5] = "kRemoteAudioStateChangeReasonRemoteMuted";
    /**
     * @brief Remote user resumes sending audio stream
     */
    RemoteAudioStateChangeReason[RemoteAudioStateChangeReason["kRemoteAudioStateChangeReasonRemoteUnmuted"] = 6] = "kRemoteAudioStateChangeReasonRemoteUnmuted";
    /**
     * @brief Remote user leaves room
     */
    RemoteAudioStateChangeReason[RemoteAudioStateChangeReason["kRemoteAudioStateChangeReasonRemoteOffline"] = 7] = "kRemoteAudioStateChangeReasonRemoteOffline";
})(RemoteAudioStateChangeReason = exports.RemoteAudioStateChangeReason || (exports.RemoteAudioStateChangeReason = {}));
/**
 * @brief Local video stream status
 */
var LocalVideoStreamState;
(function (LocalVideoStreamState) {
    /**
     * @brief Local video capture stop state
     */
    LocalVideoStreamState[LocalVideoStreamState["kLocalVideoStreamStateStopped"] = 0] = "kLocalVideoStreamStateStopped";
    /**
     * @brief Local video capture device activated
     */
    LocalVideoStreamState[LocalVideoStreamState["kLocalVideoStreamStateRecording"] = 1] = "kLocalVideoStreamStateRecording";
    /**
     * @brief After local video capture, the first frame is encoded successfully
     */
    LocalVideoStreamState[LocalVideoStreamState["kLocalVideoStreamStateEncoding"] = 2] = "kLocalVideoStreamStateEncoding";
    /**
     * @brief Local video capture device failed to start
     */
    LocalVideoStreamState[LocalVideoStreamState["kLocalVideoStreamStateFailed"] = 3] = "kLocalVideoStreamStateFailed";
})(LocalVideoStreamState = exports.LocalVideoStreamState || (exports.LocalVideoStreamState = {}));
/**
 * @detail 85534
 * @brief Error Codes for the local video state changed
 */
var LocalVideoStreamError;
(function (LocalVideoStreamError) {
    /**
     * @brief Normal
     */
    LocalVideoStreamError[LocalVideoStreamError["kLocalVideoStreamErrorOk"] = 0] = "kLocalVideoStreamErrorOk";
    /**
     * @brief Local video stream publishing failed
     */
    LocalVideoStreamError[LocalVideoStreamError["kLocalVideoStreamErrorFailure"] = 1] = "kLocalVideoStreamErrorFailure";
    /**
     * @brief No access to the local video capture device
     */
    LocalVideoStreamError[LocalVideoStreamError["kLocalVideoStreamErrorDeviceNoPermission"] = 2] = "kLocalVideoStreamErrorDeviceNoPermission";
    /**
     * @brief Local video capture equipment is occupied
     */
    LocalVideoStreamError[LocalVideoStreamError["kLocalVideoStreamErrorDeviceBusy"] = 3] = "kLocalVideoStreamErrorDeviceBusy";
    /**
     * @brief Local video capture device does not exist
     */
    LocalVideoStreamError[LocalVideoStreamError["kLocalVideoStreamErrorDeviceNotFound"] = 4] = "kLocalVideoStreamErrorDeviceNotFound";
    /**
     * @brief Local video capture failed, it is recommended to check whether the acquisition device is working properly
     */
    LocalVideoStreamError[LocalVideoStreamError["kLocalVideoStreamErrorCaptureFailure"] = 5] = "kLocalVideoStreamErrorCaptureFailure";
    /**
     * @brief Local video encoding failed
     */
    LocalVideoStreamError[LocalVideoStreamError["kLocalVideoStreamErrorEncodeFailure"] = 6] = "kLocalVideoStreamErrorEncodeFailure";
    /**
     * @brief The local video capture device is disconnected. It is occupied by other programs during the call.
     */
    LocalVideoStreamError[LocalVideoStreamError["kLocalVideoStreamErrorDeviceDisconnected"] = 7] = "kLocalVideoStreamErrorDeviceDisconnected";
})(LocalVideoStreamError = exports.LocalVideoStreamError || (exports.LocalVideoStreamError = {}));
/**
 * @brief Remote video stream status. You will receive [onRemoteVideoStateChanged](85533#onremotevideostatechanged) callback when the state changes.
 */
var RemoteVideoState;
(function (RemoteVideoState) {
    /**
     * @brief The remote video stream defaults to the initial state, and the video has not yet started playing.
     */
    RemoteVideoState[RemoteVideoState["kRemoteVideoStateStopped"] = 0] = "kRemoteVideoStateStopped";
    /**
     * @brief Local user has received remote video stream header packet.
     */
    RemoteVideoState[RemoteVideoState["kRemoteVideoStateStarting"] = 1] = "kRemoteVideoStateStarting";
    /**
     * @brief The remote video stream is decoding and playing normally.
     */
    RemoteVideoState[RemoteVideoState["kRemoteVideoStateDecoding"] = 2] = "kRemoteVideoStateDecoding";
    /**
     * @brief Remote video streaming card, there may be network and other reasons.
     */
    RemoteVideoState[RemoteVideoState["kRemoteVideoStateFrozen"] = 3] = "kRemoteVideoStateFrozen";
    /**
     * @brief The remote video stream failed to play.
     */
    RemoteVideoState[RemoteVideoState["kRemoteVideoStateFailed"] = 4] = "kRemoteVideoStateFailed";
})(RemoteVideoState = exports.RemoteVideoState || (exports.RemoteVideoState = {}));
/**
 * @brief Cause of remote video stream state change
 */
var RemoteVideoStateChangeReason;
(function (RemoteVideoStateChangeReason) {
    /**
     * @brief Internal reasons
     */
    RemoteVideoStateChangeReason[RemoteVideoStateChangeReason["kRemoteVideoStateChangeReasonInternal"] = 0] = "kRemoteVideoStateChangeReasonInternal";
    /**
     * @brief Network blocking
     */
    RemoteVideoStateChangeReason[RemoteVideoStateChangeReason["kRemoteVideoStateChangeReasonNetworkCongestion"] = 1] = "kRemoteVideoStateChangeReasonNetworkCongestion";
    /**
     * @brief Network back to normal
     */
    RemoteVideoStateChangeReason[RemoteVideoStateChangeReason["kRemoteVideoStateChangeReasonNetworkRecovery"] = 2] = "kRemoteVideoStateChangeReasonNetworkRecovery";
    /**
     * @brief Local user stops receiving remote video stream or local user disables video module
     */
    RemoteVideoStateChangeReason[RemoteVideoStateChangeReason["kRemoteVideoStateChangeReasonLocalMuted"] = 3] = "kRemoteVideoStateChangeReasonLocalMuted";
    /**
     * @brief Local user resumes receiving remote video streams or local user enables video modules
     */
    RemoteVideoStateChangeReason[RemoteVideoStateChangeReason["kRemoteVideoStateChangeReasonLocalUnmuted"] = 4] = "kRemoteVideoStateChangeReasonLocalUnmuted";
    /**
     * @brief The remote user stops sending the video stream or the remote user disables the video module
     */
    RemoteVideoStateChangeReason[RemoteVideoStateChangeReason["kRemoteVideoStateChangeReasonRemoteMuted"] = 5] = "kRemoteVideoStateChangeReasonRemoteMuted";
    /**
     * @brief Remote user resumes sending video stream or remote user enables video module
     */
    RemoteVideoStateChangeReason[RemoteVideoStateChangeReason["kRemoteVideoStateChangeReasonRemoteUnmuted"] = 6] = "kRemoteVideoStateChangeReasonRemoteUnmuted";
    /**
     * @brief The remote user leaves the channel. State transition see `onUserUnPublishStream`.
     */
    RemoteVideoStateChangeReason[RemoteVideoStateChangeReason["kRemoteVideoStateChangeReasonRemoteOffline"] = 7] = "kRemoteVideoStateChangeReasonRemoteOffline";
})(RemoteVideoStateChangeReason = exports.RemoteVideoStateChangeReason || (exports.RemoteVideoStateChangeReason = {}));
/**
 * @brief First frame sending state
 */
var FirstFrameSendState;
(function (FirstFrameSendState) {
    /**
     * @brief Sending.
     */
    FirstFrameSendState[FirstFrameSendState["kFirstFrameSendStateSending"] = 0] = "kFirstFrameSendStateSending";
    /**
     * @brief Sent.
     */
    FirstFrameSendState[FirstFrameSendState["kFirstFrameSendStateSent"] = 1] = "kFirstFrameSendStateSent";
    /**
     * @brief Failed.
     */
    FirstFrameSendState[FirstFrameSendState["kFirstFrameSendStateEnd"] = 2] = "kFirstFrameSendStateEnd";
})(FirstFrameSendState = exports.FirstFrameSendState || (exports.FirstFrameSendState = {}));
/**
 * @brief First frame playback state
 */
var FirstFramePlayState;
(function (FirstFramePlayState) {
    /**
     * @brief Playing
     */
    FirstFramePlayState[FirstFramePlayState["kFirstFramePlayStatePlaying"] = 0] = "kFirstFramePlayStatePlaying";
    /**
     * @brief Play started.
     */
    FirstFramePlayState[FirstFramePlayState["kFirstFramePlayStatePlayed"] = 1] = "kFirstFramePlayStatePlayed";
    /**
     * @brief Failed.
     */
    FirstFramePlayState[FirstFramePlayState["kFirstFramePlayStateEnd"] = 2] = "kFirstFramePlayStateEnd";
})(FirstFramePlayState = exports.FirstFramePlayState || (exports.FirstFramePlayState = {}));
/**
 * @brief Mixing type
 */
var AudioMixingType;
(function (AudioMixingType) {
    /**
     * @brief Play at the local device only
     */
    AudioMixingType[AudioMixingType["kAudioMixingTypePlayout"] = 0] = "kAudioMixingTypePlayout";
    /**
     * @brief Send to the remote devices only
     */
    AudioMixingType[AudioMixingType["kAudioMixingTypePublish"] = 1] = "kAudioMixingTypePublish";
    /**
     * @brief Play and send to remote
     */
    AudioMixingType[AudioMixingType["kAudioMixingTypePlayoutAndPublish"] = 2] = "kAudioMixingTypePlayoutAndPublish";
})(AudioMixingType = exports.AudioMixingType || (exports.AudioMixingType = {}));
/**
 * @brief Stream fallback options of publisher
 */
var PublishFallbackOption;
(function (PublishFallbackOption) {
    /**
     * @brief Default setting. No fallback is allowed under limited network conditions.
     */
    PublishFallbackOption[PublishFallbackOption["kPublishFallbackOptionDisabled"] = 0] = "kPublishFallbackOptionDisabled";
    /**
     * @brief Under limited network conditions, the video streams that you published will degrade sequentially from the highest-quality stream to the lowest-quality stream until it can match current network conditions. See [Stream Fallback](https://docs.byteplus.com/byteplus-rtc/docs/70137) for details.
     */
    PublishFallbackOption[PublishFallbackOption["kPublishFallbackOptionSimulcast"] = 1] = "kPublishFallbackOptionSimulcast";
})(PublishFallbackOption = exports.PublishFallbackOption || (exports.PublishFallbackOption = {}));
/**
 * @brief  Room profile
 *        Choose an appropriate room-profile option to meet the requirement of the scenario for media encoding algorithm, video profiles, and network configurations.
 *        Call `setAudioProfile` to apply another audio quality option.
 */
var RoomProfileType;
(function (RoomProfileType) {
    /**
     * @brief General mode by default
     */
    RoomProfileType[RoomProfileType["kRoomProfileTypeCommunication"] = 0] = "kRoomProfileTypeCommunication";
    RoomProfileType[RoomProfileType["kRoomProfileTypeLiveBroadcasting"] = 1] = "kRoomProfileTypeLiveBroadcasting";
    /**
     * @brief Game voice mode. Low consumption of computing resources and network data
     *        Additional performance optimizations have been made for low-end devices:
     *             + Encodes frame length 40/60 for some low-end models.
     *             + Disables software 3A audio processing for some low-end models.
     *        Enhance iOS Compatibility with other screen recordings to avoid audio recordings being interrupted by RTC.
     */
    RoomProfileType[RoomProfileType["kRoomProfileTypeGame"] = 2] = "kRoomProfileTypeGame";
    /**
     * @brief Cloud game mode.
     *        Use this mode for game App requiring low latency.
     *        During poor network connection, communication experiences get worse with this mode.
     */
    RoomProfileType[RoomProfileType["kRoomProfileTypeCloudGame"] = 3] = "kRoomProfileTypeCloudGame";
    /**
     * @brief Cloud render mode featuring extra-low latency.
     *        Choose this mode if it is not a game App yet requires low latency.
     *        In this mode, latency will significantly decrease at the cost of lower audio quality as well as the bad performance with weak network signal.
     */
    RoomProfileType[RoomProfileType["kRoomProfileTypeLowLatency"] = 4] = "kRoomProfileTypeLowLatency";
    /**
     * @brief For 1 vs 1 video and audio calls
     */
    RoomProfileType[RoomProfileType["kRoomProfileTypeChat"] = 5] = "kRoomProfileTypeChat";
    /**
     * @brief For video and audio chat rooms of 3 or more people
     */
    RoomProfileType[RoomProfileType["kRoomProfileTypeChatRoom"] = 6] = "kRoomProfileTypeChatRoom";
    /**
     * @brief For scenarios such as "Watch together." and "Listen together." Multiple clients are capable of playing the same videos and audios synchronically.
     *        In these scenarios, RTC does not involve the transportation of the sharing media but only synchronizes video/music playback across multiple clients via signaling.
     */
    RoomProfileType[RoomProfileType["kRoomProfileTypeLwTogether"] = 7] = "kRoomProfileTypeLwTogether";
    /**
     * @brief For the game apps demanding high-resolution audio. In this mode, RTC plays audio using the media mode only.
     */
    RoomProfileType[RoomProfileType["kRoomProfileTypeGameHD"] = 8] = "kRoomProfileTypeGameHD";
    /**
     * @brief For the events of co-hosting in the live-streaming
     *        During a livestreaming using a CDN network, the host can invite another host to join the co-hosting event using RTC.
     */
    RoomProfileType[RoomProfileType["kRoomProfileTypeCoHost"] = 9] = "kRoomProfileTypeCoHost";
    /**
     * @brief For interactive podcasts that the host can have video and audio interactions with the audience. The voice mode is set to communication mode to avoid volume spiking and dipping acutely.
     */
    RoomProfileType[RoomProfileType["kRoomProfileTypeInteractivePodcast"] = 10] = "kRoomProfileTypeInteractivePodcast";
    /**
     * @brief For the online karaoke with high-quality audio and low latency
     *        In these scenarios, RTC transports the accompaniment and mixed audio, such as solo and non-realtime chorus.
     */
    RoomProfileType[RoomProfileType["kRoomProfileTypeKTV"] = 11] = "kRoomProfileTypeKTV";
    /**
     * @brief For the online-chorusing scenarios requiring high-quality audio and low latency. Contact our technical specialists before you apply it to your App.
     */
    RoomProfileType[RoomProfileType["kRoomProfileTypeChorus"] = 12] = "kRoomProfileTypeChorus";
    /**
     * @hidden
     * @brief For VR chat with support for 192 KHz audio sample rate and feature of 360 Reality AudioAudio
     */
    RoomProfileType[RoomProfileType["kRoomProfileTypeVRChat"] = 13] = "kRoomProfileTypeVRChat";
    /**
     * @brief For scenarios of streaming live videos to only one client on the LAN. It can be applied to devices on the Internet or LAN.
     */
    RoomProfileType[RoomProfileType["kRoomProfileTypeGameStreaming"] = 14] = "kRoomProfileTypeGameStreaming";
    /**
     * @brief For scenarios of streaming live videos to multiple clients within the LAN with the support of 60fps @8K video stream with the bitrate of 100 Mbps
     * A private media server is expected to be ready on the LAN.
     */
    RoomProfileType[RoomProfileType["kRoomProfileTypeLanLiveStreaming"] = 15] = "kRoomProfileTypeLanLiveStreaming";
    /**
     * @brief For meeting Apps installed on personal devices
     */
    RoomProfileType[RoomProfileType["kRoomProfileTypeMeeting"] = 16] = "kRoomProfileTypeMeeting";
    /**
     * @brief For meeting Apps installed on terminals of meeting rooms, such as Rooms.
     */
    RoomProfileType[RoomProfileType["kRoomProfileTypeMeetingRoom"] = 17] = "kRoomProfileTypeMeetingRoom";
    /**
     * @brief For the online classrooms and lectures that over 10 participants in the room are allowed to join the video chat.
     */
    RoomProfileType[RoomProfileType["kRoomProfileTypeClassroom"] = 18] = "kRoomProfileTypeClassroom";
})(RoomProfileType = exports.RoomProfileType || (exports.RoomProfileType = {}));
var SubscribeFallbackOption;
(function (SubscribeFallbackOption) {
    SubscribeFallbackOption[SubscribeFallbackOption["kSubscribeFallbackOptionDisable"] = 0] = "kSubscribeFallbackOptionDisable";
    SubscribeFallbackOption[SubscribeFallbackOption["kSubscribeFallbackOptionVideoStreamLow"] = 1] = "kSubscribeFallbackOptionVideoStreamLow";
    SubscribeFallbackOption[SubscribeFallbackOption["kSubscribeFallbackOptionAudioOnly"] = 2] = "kSubscribeFallbackOptionAudioOnly";
})(SubscribeFallbackOption = exports.SubscribeFallbackOption || (exports.SubscribeFallbackOption = {}));
var MirrorMode;
(function (MirrorMode) {
    MirrorMode[MirrorMode["kMirrorModeOff"] = 0] = "kMirrorModeOff";
    MirrorMode[MirrorMode["kMirrorModeOn"] = 1] = "kMirrorModeOn";
})(MirrorMode = exports.MirrorMode || (exports.MirrorMode = {}));
/**
 * @brief Mirror type
 */
var MirrorType;
(function (MirrorType) {
    /**
     * @brief The preview and the published video stream are not mirrored.
     */
    MirrorType[MirrorType["kMirrorTypeNone"] = 0] = "kMirrorTypeNone";
    /**
     * @brief The preview is mirrored. The published video stream is not mirrored.
     */
    MirrorType[MirrorType["kMirrorTypeRender"] = 1] = "kMirrorTypeRender";
    /**
     * @brief The preview and the published video stream are mirrored.
     */
    MirrorType[MirrorType["kMirrorTypeRenderAndEncoder"] = 3] = "kMirrorTypeRenderAndEncoder";
})(MirrorType = exports.MirrorType || (exports.MirrorType = {}));
/**
 * @brief Pause/resume receiving the remote media stream type.
 */
var PauseResumeControlMediaType;
(function (PauseResumeControlMediaType) {
    /**
     * @brief Audio only
     */
    PauseResumeControlMediaType[PauseResumeControlMediaType["kRTCPauseResumeControlMediaTypeAudio"] = 0] = "kRTCPauseResumeControlMediaTypeAudio";
    /**
     * @brief Video only
     */
    PauseResumeControlMediaType[PauseResumeControlMediaType["kRTCPauseResumeControlMediaTypeVideo"] = 1] = "kRTCPauseResumeControlMediaTypeVideo";
    /**
     * @brief Both video and audio
     */
    PauseResumeControlMediaType[PauseResumeControlMediaType["kRTCPauseResumeControlMediaTypeVideoAndAudio"] = 2] = "kRTCPauseResumeControlMediaTypeVideoAndAudio";
})(PauseResumeControlMediaType = exports.PauseResumeControlMediaType || (exports.PauseResumeControlMediaType = {}));
/**
 * @brief Whether to collect mouse information when collecting screen video stream internally
 */
var MouseCursorCaptureState;
(function (MouseCursorCaptureState) {
    /**
     * @brief Collect mouse information
     */
    MouseCursorCaptureState[MouseCursorCaptureState["kMouseCursorCaptureStateOn"] = 0] = "kMouseCursorCaptureStateOn";
    /**
     * @brief Do not collect mouse information
     */
    MouseCursorCaptureState[MouseCursorCaptureState["kMouseCursorCaptureStateOff"] = 1] = "kMouseCursorCaptureStateOff";
})(MouseCursorCaptureState = exports.MouseCursorCaptureState || (exports.MouseCursorCaptureState = {}));
/**
 * @brief Media stream type
 */
var MediaStreamType;
(function (MediaStreamType) {
    /**
     * @brief Audio only
     */
    MediaStreamType[MediaStreamType["kMediaStreamTypeAudio"] = 1] = "kMediaStreamTypeAudio";
    /**
     * @brief Video only
     */
    MediaStreamType[MediaStreamType["kMediaStreamTypeVideo"] = 2] = "kMediaStreamTypeVideo";
    /**
     * @brief Both audio and video
     */
    MediaStreamType[MediaStreamType["kMediaStreamTypeBoth"] = 3] = "kMediaStreamTypeBoth";
})(MediaStreamType = exports.MediaStreamType || (exports.MediaStreamType = {}));
/**
 * @brief Basic beauty effect.
 */
var EffectBeautyMode;
(function (EffectBeautyMode) {
    /**
     * @brief Brightness.
     */
    EffectBeautyMode[EffectBeautyMode["kEffectBeautyWhite"] = 0] = "kEffectBeautyWhite";
    /**
     * @brief Smoothness.
     */
    EffectBeautyMode[EffectBeautyMode["kEffectBeautySmooth"] = 1] = "kEffectBeautySmooth";
    /**
     * @brief Sharpness.
     */
    EffectBeautyMode[EffectBeautyMode["kEffectBeautySharpen"] = 2] = "kEffectBeautySharpen";
})(EffectBeautyMode = exports.EffectBeautyMode || (exports.EffectBeautyMode = {}));
/**
 * @brief Mix playback channel type
 */
var AudioMixingDualMonoMode;
(function (AudioMixingDualMonoMode) {
    /**
     * @brief Consistent with audio files
     */
    AudioMixingDualMonoMode[AudioMixingDualMonoMode["kAudioMixingDualMonoModeAuto"] = 0] = "kAudioMixingDualMonoModeAuto";
    /**
     * @brief Only the left channel audio in the audio file can be heard
     */
    AudioMixingDualMonoMode[AudioMixingDualMonoMode["kAudioMixingDualMonoModeL"] = 1] = "kAudioMixingDualMonoModeL";
    /**
     * @brief Only the right channel audio in the audio file can be heard
     */
    AudioMixingDualMonoMode[AudioMixingDualMonoMode["kAudioMixingDualMonoModeR"] = 2] = "kAudioMixingDualMonoModeR";
    /**
     * @brief Can hear the left and right audio channels in the audio file at the same time
     */
    AudioMixingDualMonoMode[AudioMixingDualMonoMode["kAudioMixingDualMonoModeMix"] = 3] = "kAudioMixingDualMonoModeMix";
})(AudioMixingDualMonoMode = exports.AudioMixingDualMonoMode || (exports.AudioMixingDualMonoMode = {}));
/**
 * @brief RTM message
 */
var MessageConfig;
(function (MessageConfig) {
    /**
     * @brief Low latency reliable and orderly message
     */
    MessageConfig[MessageConfig["kMessageConfigReliableOrdered"] = 0] = "kMessageConfigReliableOrdered";
    /**
     * @brief Ultra-low latency ordered message
     */
    MessageConfig[MessageConfig["kMessageConfigUnreliableOrdered"] = 1] = "kMessageConfigUnreliableOrdered";
    /**
     * @brief Ultra-low latency unordered message
     */
    MessageConfig[MessageConfig["kMessageConfigUnreliableUnordered"] = 2] = "kMessageConfigUnreliableUnordered";
})(MessageConfig = exports.MessageConfig || (exports.MessageConfig = {}));
/**
 * @brief A/V synchronization states
 */
var AVSyncState;
(function (AVSyncState) {
    /**
     * @brief A/V synchronization begins.
     */
    AVSyncState[AVSyncState["kAVSyncStateAVStreamSyncBegin"] = 0] = "kAVSyncStateAVStreamSyncBegin";
    /**
     * @brief The publisher stops publishing audio stream during the synchronization, which does not affect the sync relationship.
     */
    AVSyncState[AVSyncState["kAVSyncStateAudioStreamRemove"] = 1] = "kAVSyncStateAudioStreamRemove";
    /**
     * @brief The publisher stops publishing audio stream during the synchronization, which does not affect the sync relationship.
     */
    AVSyncState[AVSyncState["kAVSyncStateVdieoStreamRemove"] = 2] = "kAVSyncStateVdieoStreamRemove";
    /**
     * @hidden
     * @brief Subscriber settings synchronization
     */
    AVSyncState[AVSyncState["kAVSyncStateSetAVSyncStreamId"] = 3] = "kAVSyncStateSetAVSyncStreamId";
})(AVSyncState = exports.AVSyncState || (exports.AVSyncState = {}));
/**
 * @brief The state of the relaying for each room
 */
var ForwardStreamState;
(function (ForwardStreamState) {
    /**
     * @brief Idle
     *        + States of all the rooms turns to idle after you call `stopForwardStreamToRooms`.
     *        + States of the rooms turns to idle that you call `updateForwardStreamToRooms` to remove.
     */
    ForwardStreamState[ForwardStreamState["kForwardStreamStateIdle"] = 0] = "kForwardStreamStateIdle";
    /**
     * @brief Start relaying.
     *        + State of the rooms turn to this state after the relaying starts successfully by calling `startForwardStreamToRooms`.
     *        + State of the rooms added by calling `updateForwardStreamToRooms` turn to this state after the relaying start successfully.
     */
    ForwardStreamState[ForwardStreamState["kForwardStreamStateSuccess"] = 1] = "kForwardStreamStateSuccess";
    /**
     * @brief Relay fails. Refer to [ForwardStreamError](85534#forwardstreamerror) for more information for more information.
     *        Once the relaying fails, state of the room turns to this state after calling `startForwardStreamToRooms` or `updateForwardStreamToRooms`.
     */
    ForwardStreamState[ForwardStreamState["kForwardStreamStateFailure"] = 2] = "kForwardStreamStateFailure";
})(ForwardStreamState = exports.ForwardStreamState || (exports.ForwardStreamState = {}));
/**
 * @detail 85534
 * @brief Error codes during the relaying
 */
var ForwardStreamError;
(function (ForwardStreamError) {
    /**
     * @brief Normal
     */
    ForwardStreamError[ForwardStreamError["kForwardStreamErrorOK"] = 0] = "kForwardStreamErrorOK";
    /**
     * @brief Invalid argument
     */
    ForwardStreamError[ForwardStreamError["kForwardStreamErrorInvalidArgument"] = 1201] = "kForwardStreamErrorInvalidArgument";
    /**
     * @brief Invalid token
     */
    ForwardStreamError[ForwardStreamError["kForwardStreamErrorInvalidToken"] = 1202] = "kForwardStreamErrorInvalidToken";
    /**
     * @brief Error returning from server
     */
    ForwardStreamError[ForwardStreamError["kForwardStreamErrorResponse"] = 1203] = "kForwardStreamErrorResponse";
    /**
     * @brief Relaying aborts for the reason of that a User with the same user ID as that of the publisher joins.
     */
    ForwardStreamError[ForwardStreamError["kForwardStreamErrorRemoteKicked"] = 1204] = "kForwardStreamErrorRemoteKicked";
    /**
     * @brief Server denies.
     */
    ForwardStreamError[ForwardStreamError["kForwardStreamErrorNotSupport"] = 1205] = "kForwardStreamErrorNotSupport";
})(ForwardStreamError = exports.ForwardStreamError || (exports.ForwardStreamError = {}));
/**
 * @brief Events during the relaying
 */
var ForwardStreamEvent;
(function (ForwardStreamEvent) {
    /**
     * @brief Relaying pauses for the reason of network disconnecting.
     */
    ForwardStreamEvent[ForwardStreamEvent["kForwardStreamEventDisconnected"] = 0] = "kForwardStreamEventDisconnected";
    /**
     * @brief Relaying recovers from the disconnecting.
     */
    ForwardStreamEvent[ForwardStreamEvent["kForwardStreamEventConnected"] = 1] = "kForwardStreamEventConnected";
    /**
     * @brief Relaying aborts for the reason of that a User with the same user ID as that of the publisher joins.
     */
    ForwardStreamEvent[ForwardStreamEvent["kForwardStreamEventInterrupt"] = 2] = "kForwardStreamEventInterrupt";
    /**
     * @brief Target room list updates after you call `updateForwardStreamToRooms`.
     */
    ForwardStreamEvent[ForwardStreamEvent["kForwardStreamEventDstRoomUpdated"] = 3] = "kForwardStreamEventDstRoomUpdated";
    /**
     * @brief Wrong API-calling order. For example, call `updateForwardStreamToRooms` before calling `startForwardStreamToRooms`.
     */
    ForwardStreamEvent[ForwardStreamEvent["kForwardStreamEventUnExpectAPICall"] = 4] = "kForwardStreamEventUnExpectAPICall";
})(ForwardStreamEvent = exports.ForwardStreamEvent || (exports.ForwardStreamEvent = {}));
/**
 * @brief Volume Roll-off modes that a sound has in an audio source
 */
var AttenuationType;
(function (AttenuationType) {
    /**
     * @brief Disable Volume Attenuation
     */
    AttenuationType[AttenuationType["kAttenuationTypeNone"] = 0] = "kAttenuationTypeNone";
    /**
     * @brief Linear roll-off mode which lowers the volume of the sound over the distance
     */
    AttenuationType[AttenuationType["kAttenuationTypeLinear"] = 1] = "kAttenuationTypeLinear";
    /**
     * @brief Exponential roll-off mode which exponentially decreases the volume of the sound with the distance raising
     */
    AttenuationType[AttenuationType["kAttenuationTypeExponential"] = 2] = "kAttenuationTypeExponential";
})(AttenuationType = exports.AttenuationType || (exports.AttenuationType = {}));
/**
 * @brief Encoder preference
 */
var VideoEncodePreference;
(function (VideoEncodePreference) {
    /**
     * @brief No preference
     */
    VideoEncodePreference[VideoEncodePreference["kVideoEncodePreferenceDisabled"] = 0] = "kVideoEncodePreferenceDisabled";
    /**
     * @brief Frame rate first
     */
    VideoEncodePreference[VideoEncodePreference["kVideoEncodePreferenceFramerate"] = 1] = "kVideoEncodePreferenceFramerate";
    /**
     * @brief Quality first
     */
    VideoEncodePreference[VideoEncodePreference["kVideoEncodePreferenceQuality"] = 2] = "kVideoEncodePreferenceQuality";
    /**
     * @brief Balancing quality and frame rate
     */
    VideoEncodePreference[VideoEncodePreference["kVideoEncodePreferenceBalance"] = 3] = "kVideoEncodePreferenceBalance";
})(VideoEncodePreference = exports.VideoEncodePreference || (exports.VideoEncodePreference = {}));
/**
 * @brief Video capture preference
 */
var CapturePreference;
(function (CapturePreference) {
    /**
     * @brief (Default) Video capture preference: auto
     *        SDK determines the best video capture parameters referring to the camera output parameters and the encoder configuration.
     */
    CapturePreference[CapturePreference["KAuto"] = 0] = "KAuto";
    /**
     * @brief Video capture preference: manual
     *        Set the resolution and the frame rate manually.
     */
    CapturePreference[CapturePreference["KManual"] = 1] = "KManual";
    /**
     * @brief Video capture preference: encoder configuration
     *        The capture parameters are the same with the parameters set in [setVideoEncoderConfig](85532#setvideoencoderconfig).
     */
    CapturePreference[CapturePreference["KAutoPerformance"] = 2] = "KAutoPerformance";
})(CapturePreference = exports.CapturePreference || (exports.CapturePreference = {}));
var EchoTestResult;
(function (EchoTestResult) {
    /**
     * @brief 接收到采集的音视频的回放，通话回路检测成功
     */
    EchoTestResult[EchoTestResult["kTestSuccess"] = 0] = "kTestSuccess";
    /**
     * @brief 测试超过 60s 仍未完成，已自动停止
     */
    EchoTestResult[EchoTestResult["kTestTimeout"] = 1] = "kTestTimeout";
    /**
     * @brief 上一次测试结束和下一次测试开始之间的时间间隔少于 5s
     */
    EchoTestResult[EchoTestResult["kTestIntervalShort"] = 2] = "kTestIntervalShort";
    /**
     * @brief 音频采集异常
     */
    EchoTestResult[EchoTestResult["kAudioDeviceError"] = 3] = "kAudioDeviceError";
    /**
     * @brief 视频采集异常
     */
    EchoTestResult[EchoTestResult["kVideoDeviceError"] = 4] = "kVideoDeviceError";
    /**
     * @brief 音频接收异常
     */
    EchoTestResult[EchoTestResult["kAudioReceiveError"] = 5] = "kAudioReceiveError";
    /**
     * @brief 视频接收异常
     */
    EchoTestResult[EchoTestResult["kVideoReceiveError"] = 6] = "kVideoReceiveError";
    /**
     * @brief 内部错误，不可恢复
     */
    EchoTestResult[EchoTestResult["kInternalError"] = 7] = "kInternalError";
})(EchoTestResult = exports.EchoTestResult || (exports.EchoTestResult = {}));
//# sourceMappingURL=index.js.map